@@ -12,16 +12,17 @@ int main( int argc, char **argv )
     window->setCaption("Qt Example - Toggleaction");
     QToolBar * toolbar = new QToolBar( window );
 
-    QAction * labelonoffaction = new QAction( window, "labelonoff", TRUE );  
+    QAction * labelonoffaction = new QAction( window, "labelonoff" );
+    labelonoffaction->setToggleAction( TRUE );
 
-    labelonoffaction->setText( "labels on/off" ); 
+    labelonoffaction->setText( "labels on/off" );
     labelonoffaction->setAccel( Qt::ALT+Qt::Key_L );
-    labelonoffaction->setIconSet( (QPixmap) labelonoff_xpm );                                 
+    labelonoffaction->setIconSet( (QPixmap) labelonoff_xpm );
 
-    QObject::connect( labelonoffaction, SIGNAL( toggled( bool ) ), 
+    QObject::connect( labelonoffaction, SIGNAL( toggled( bool ) ),
                       window, SLOT( setUsesTextLabel( bool ) ) );
 
-    labelonoffaction->addTo( toolbar ); 
+    labelonoffaction->addTo( toolbar );
 
     app.setMainWidget( window );
     window->show();
