@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/main.cpp   3.3.2   edited May 27 2003 $
+** $Id: qt/main.cpp   3.3.3   edited Jun 21 12:45 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -34,7 +34,7 @@ int main( int argc, char **argv )
     header->setLabel( 0, QObject::tr( "Tiny" ), 40 );
     header->setLabel( 1, QObject::tr( "Checkboxes" ) );
     header->setLabel( 5, QObject::tr( "Combos" ) );
-    header->setMovingEnabled(TRUE);
+    table.setColumnMovingEnabled(TRUE);
 
     QImage img( qtlogo_xpm );
     QPixmap pix = img.scaleHeight( table.rowHeight(3) );
