@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qlocale_p.h   3.3.1   edited Jan 22 16:53 $
+** $Id: qt/qlocale_p.h   3.3.3   edited Mar 29 14:47 $
 **
 ** Declaration of the QLocalePrivate class
 **
@@ -69,22 +69,29 @@ public:
 
     bool isDigit(QChar d) const;
 
+    enum GroupSeparatorMode {
+    	FailOnGroupSeparators,
+	ParseGroupSeparators
+    };
+
     enum DoubleForm {
-	DFExponent = 0,
-	DFDecimal,
-	DFSignificantDigits,
+	DFExponent = 0,     	    	// %e or %E
+	DFDecimal,  	    	    	// %f or %F
+	DFSignificantDigits,	    	// %g or %G
 	_DFMax = DFSignificantDigits
     };
 
     enum Flags {
 	NoFlags	    	= 0,
+	
+	// These correspond to the options in a printf format string
 	Alternate           = 0x01,
 	ZeroPadded          = 0x02,
 	LeftAdjusted        = 0x04,
 	BlankBeforePositive = 0x08,
 	AlwaysShowSign      = 0x10,
 	ThousandsGroup      = 0x20,
-	CapitalEorX	    	= 0x40
+	CapitalEorX	    = 0x40 // %x, %e, %f, %g vs. %X, %E, %F, %G
     };
 
     QString doubleToString(double d,
@@ -100,11 +107,11 @@ public:
 				int base = 10,
 				int width = -1,
 				unsigned flags = NoFlags) const;
-    double stringToDouble(QString num, bool *ok) const;
-    Q_LLONG stringToLongLong(QString num, int base, bool *ok) const;
-    Q_ULLONG stringToUnsLongLong(QString num, int base, bool *ok) const;
-
-    QString &numberToCLocale(QString &locale_num) const;
+    double stringToDouble(QString num, bool *ok, GroupSeparatorMode group_sep_mode) const;
+    Q_LLONG stringToLongLong(QString num, int base, bool *ok, GroupSeparatorMode group_sep_mode) const;
+    Q_ULLONG stringToUnsLongLong(QString num, int base, bool *ok, GroupSeparatorMode group_sep_mode) const;
+    bool removeGroupSeparators(QString &num_str) const;
+    bool numberToCLocale(QString &locale_num, GroupSeparatorMode group_sep_mode) const;
 
     Q_UINT32 m_language_id, m_country_id;
 
