@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qrichtext_p.h   3.3.1   edited Nov 11 13:33 $
+** $Id: qt/qrichtext_p.h   3.3.3   edited Jul 27 14:02 $
 **
 ** Definition of internal rich text classes
 **
@@ -220,6 +220,7 @@ private:
     void checkBidi() const;
 
     QMemArray<QTextStringChar> data;
+    QString stringCache;
     uint bidiDirty : 1;
     uint bidi : 1; // true when the paragraph has right to left characters
     uint rightToLeft : 1;
@@ -242,7 +243,9 @@ inline bool QTextString::isRightToLeft() const
 
 inline QString QTextString::toString() const
 {
-    return toString( data );
+    if(bidiDirty)
+        checkBidi();
+    return stringCache;
 }
 
 inline QChar::Direction QTextString::direction() const
@@ -489,7 +492,7 @@ public:
     virtual bool down( QTextCursor *, QTextDocument *&doc, QTextParagraph *&parag, int &idx, int &ox, int &oy );
     virtual bool up( QTextCursor *, QTextDocument *&doc, QTextParagraph *&parag, int &idx, int &ox, int &oy );
 
-    void setParagraph( QTextParagraph *p ) { parag = p; }
+    virtual void setParagraph( QTextParagraph *p ) { parag = p; }
     QTextParagraph *paragraph() const { return parag; }
 
     QTextDocument *parent;
@@ -715,6 +718,7 @@ public:
     QPtrList<QTextTableCell> tableCells() const { return cells; }
 
     bool isStretching() const { return stretch; }
+    void setParagraph(QTextParagraph *p);
 
 private:
     void format( int w );
@@ -772,6 +776,7 @@ class Q_EXPORT QTextDocument : public QObject
     friend class QTextCursor;
     friend class QTextEdit;
     friend class QTextParagraph;
+    friend class QTextTable;
 
 public:
     enum SelectionIds {
@@ -1360,7 +1365,8 @@ private:
     QPtrList<QTextCustomItem> *mFloatingItems;
 #endif
     short utm, ubm, ulm, urm, uflm, ulinespacing;
-    short tabStopWidth, minwidth;
+    short tabStopWidth;
+    int minwidth;
     int *tArray;
     QTextParagraphData *eData;
     short list_val;
