@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qsettings_p.h   3.2.2   edited Jun 12 07:22 $
+** $Id: qt/qsettings_p.h   3.3.3   edited Dec 18 2003 $
 **
 ** Definition of QSettings related classes
 **
@@ -56,6 +56,7 @@
 #include "qvaluestack.h"
 #endif // QT_H
 
+#ifndef QT_NO_SETTINGS
 class QSettingsSysPrivate;
 
 // QSettingsGroup is a map of key/value pairs
@@ -138,6 +139,7 @@ public:
     void	sysInsertSearchPath( QSettings::System, const QString & );
     void	sysRemoveSearchPath( QSettings::System, const QString & );
 #endif
-};
 
+};
+#endif //QT_NO_SETTINGS
 #endif // QSETTINGS_P_H
