@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qdialog.h   3.2.1   edited May 13 09:08 $
+** $Id: qt/qdialog.h   3.3.3   edited Oct 8 2003 $
 **
 ** Definition of QDialog class
 **
@@ -88,6 +88,9 @@ public:
 
     void setModal( bool modal );
     bool isModal() const;
+#ifdef Q_OS_TEMP
+    bool	event( QEvent * );
+#endif
 
 public slots:
     int exec();
@@ -110,7 +113,12 @@ protected:
 
 private:
     void	setDefault( QPushButton * );
-    void		hideDefault();
+    void	setMainDefault( QPushButton * );
+    void	hideDefault();
+#ifdef Q_OS_TEMP
+    void	hideSpecial();
+#endif
+
     int		rescode;
     uint	did_move   : 1;
     uint	has_relpos : 1;
