@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfont.h   3.1.2   edited Nov 19 08:19 $
+** $Id: qt/qfont.h   3.3.3   edited Feb 20 13:59 $
 **
 ** Definition of QFont class
 **
@@ -61,15 +61,16 @@ public:
     };
 
     enum StyleStrategy {
-	PreferDefault = 0x0001,
-	PreferBitmap  = 0x0002,
-	PreferDevice  = 0x0004,
-	PreferOutline = 0x0008,
-	ForceOutline  = 0x0010,
-	PreferMatch   = 0x0020,
-	PreferQuality = 0x0040,
-	PreferAntialias = 0x0080,
-	NoAntialias = 0x0100
+	PreferDefault    = 0x0001,
+	PreferBitmap     = 0x0002,
+	PreferDevice     = 0x0004,
+	PreferOutline    = 0x0008,
+	ForceOutline     = 0x0010,
+	PreferMatch      = 0x0020,
+	PreferQuality    = 0x0040,
+	PreferAntialias  = 0x0080,
+	NoAntialias      = 0x0100,
+	OpenGLCompatible = 0x0200
     };
 
     enum Weight {
@@ -80,11 +81,28 @@ public:
 	Black	 = 87
     };
 
+    enum Stretch {
+	UltraCondensed =  50,
+	ExtraCondensed =  62,
+	Condensed      =  75,
+	SemiCondensed  =  87,
+	Unstretched    = 100,
+	SemiExpanded   = 112,
+	Expanded       = 125,
+	ExtraExpanded  = 150,
+	UltraExpanded  = 200
+    };
+
     // default font
     QFont();
     // specific font
+#ifdef Q_QDOC
     QFont( const QString &family, int pointSize = 12, int weight = Normal,
 	   bool italic = FALSE );
+#else
+    QFont( const QString &family, int pointSize = -1, int weight = -1,
+	   bool italic = FALSE );
+#endif
     // copy constructor
     QFont( const QFont & );
 
@@ -114,6 +132,9 @@ public:
     bool underline() const;
     void setUnderline( bool );
 
+    bool overline() const;
+    void setOverline( bool );
+
     bool strikeOut() const;
     void setStrikeOut( bool );
 
@@ -125,6 +146,9 @@ public:
     void setStyleHint( StyleHint, StyleStrategy = PreferDefault );
     void setStyleStrategy( StyleStrategy s );
 
+    int stretch() const;
+    void setStretch( int );
+
     // is raw mode still needed?
     bool rawMode() const;
     void setRawMode( bool );
@@ -164,14 +188,18 @@ public:
 #endif //QT_NO_STRINGLIST
     static void initialize();
     static void cleanup();
+#ifndef Q_WS_QWS
     static void cacheStatistics();
-
+#endif
 
 #if defined(Q_WS_QWS)
     void qwsRenderToDisk(bool all=TRUE);
 #endif
 
 
+    // a copy of this lives in qunicodetables.cpp, as we can't include
+    // qfont.h it in tools/. Do not modify without changing the script
+    // enum in qunicodetable_p.h aswell.
     enum Script {
 	// European Alphabetic Scripts
 	Latin,
@@ -234,28 +262,36 @@ public:
 
 	Unicode,
 
+	// some scripts added in Unicode 3.2
+	Tagalog,
+	Hanunoo,
+	Buhid,
+	Tagbanwa,
+
+	KatakanaHalfWidth,
+
+	// from Unicode 4.0
+	Limbu,
+	TaiLe,
+
 	// End
+#if !defined(Q_QDOC)
 	NScripts,
 	UnknownScript = NScripts,
 
 	NoScript,
 
 	// ----------------------------------------
-	// Dear User, you can see values > Unicode,
+	// Dear User, you can see values > NScript,
 	// but they are internal - do not touch.
 
-       	// only used on X11 to get some char displayed for all of the Han area.
-	HanX11,
-
-	LatinBasic = Latin,             // from ISO-8859-1
-	LatinExtendedA_2 = HanX11 + 1,  // from ISO-8859-2
-	LatinExtendedA_3,               // from ISO-8859-3
-	LatinExtendedA_4,               // from ISO-8859-4
-	LatinExtendedA_14,              // from ISO-8859-14
-	LatinExtendedA_15,              // from ISO-8859-15
-	KatakanaHalfWidth,		// from JIS X 0201
+	Han_Japanese,
+	Han_SimplifiedChinese,
+	Han_TraditionalChinese,
+	Han_Korean,
 
 	LastPrivateScript
+#endif
     };
 
     QString defaultFamily() const;
@@ -269,32 +305,21 @@ public:
 
 #endif // QT_NO_COMPAT
 
+    QFont resolve( const QFont & ) const;
 
 protected:
     // why protected?
     bool dirty() const;
     int deciPointSize() const;
 
-
 private:
-    QFont( QFontPrivate *, bool deep = TRUE );
     QFont( QFontPrivate *, QPaintDevice *pd );
 
     void detach();
 
-
 #if defined(Q_WS_MAC)
-    friend int do_text_task(const QFontPrivate *, QString, int, int, uchar, int, int, QPaintDevice *, const QRegion *,
-			    int, const QFontMetrics *);
     void macSetFont(QPaintDevice *);
-#endif
-
-
-#if defined(Q_WS_WIN)
-    void *textMetric() const;
-#endif
-
-#if defined(Q_WS_X11)
+#elif defined(Q_WS_X11)
     void x11SetScreen( int screen = -1 );
     int x11Screen() const;
 #endif
@@ -306,6 +331,9 @@ private:
     friend class QApplication;
     friend class QWidget;
     friend class QTextFormatCollection;
+    friend class QTextLayout;
+    friend class QTextItem;
+    friend class QGLContext;
 
 #ifndef QT_NO_DATASTREAM
     friend Q_EXPORT QDataStream &operator<<( QDataStream &, const QFont & );
