@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qlistview.h   3.2.2   edited May 13 09:08 $
+** $Id: qt/qlistview.h   3.3.3   edited Jan 21 2004 $
 **
 ** Definition of QListView widget class
 **
@@ -64,9 +64,6 @@ class Q_EXPORT QListViewItem : public Qt
 {
     friend class QListViewItemIterator;
     friend class QListViewToolTip;
-#if defined(Q_CC_MSVC)
-    friend class QListViewItem;
-#endif
 
 public:
     QListViewItem( QListView * parent );
@@ -436,6 +433,7 @@ protected slots:
 
 private slots:
     void changeSortColumn( int );
+    void handleIndexChange();
     void updateDirtyItems();
     void makeVisible();
     void handleSizeChange( int, int, int );
