@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qplatinumstyle.h   3.3.1   edited Jan 21 09:58 $
+** $Id: qt/qplatinumstyle.h   3.3.3   edited Apr 2 14:12 $
 **
 ** Definition of Platinum-like style class
 **
@@ -81,7 +81,11 @@ public:
 			     const QRect &r,
 			     const QColorGroup &cg,
 			     SFlags how = Style_Default,
+#ifdef Q_QDOC
+			     SCFlags sub = SC_All,
+#else
 			     SCFlags sub = (uint)SC_All,
+#endif
 			     SCFlags subActive = SC_None,
 			     const QStyleOption& = QStyleOption::Default ) const;
 
