@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qregion.h   3.1.2   edited Nov 7 16:55 $
+** $Id: qt/qregion.h   3.3.3   edited Oct 28 2003 $
 **
 ** Definition of QRegion class
 **
@@ -142,6 +142,8 @@ private:
     friend QRegionData *qt_mac_get_rgn_data();
     friend void qt_mac_free_rgn_data(QRegionData *);
     void rectifyRegion();
+#elif defined(Q_WS_WIN)
+    friend class QETWidget;
 #endif
 
 };
