@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qstylesheet.h   3.2.1   edited May 13 09:08 $
+** $Id: qt/qstylesheet.h   3.3.3   edited Oct 20 2003 $
 **
 ** Definition of the QStyleSheet class
 **
@@ -74,6 +74,9 @@ public:
 	DisplayInline,
 	DisplayListItem,
 	DisplayNone
+#ifndef Q_QDOC
+	, DisplayModeUndefined = -1
+#endif
     };
 
     DisplayMode displayMode() const;
@@ -127,7 +130,14 @@ public:
     bool isAnchor() const;
     void setAnchor(bool anc);
 
-    enum WhiteSpaceMode { WhiteSpaceNormal, WhiteSpacePre, WhiteSpaceNoWrap };
+    enum WhiteSpaceMode {
+	WhiteSpaceNormal,
+	WhiteSpacePre,
+	WhiteSpaceNoWrap
+#ifndef Q_QDOC
+	, WhiteSpaceModeUndefined = -1
+#endif
+    };
     WhiteSpaceMode whiteSpaceMode() const;
     void setWhiteSpaceMode(WhiteSpaceMode m);
 
@@ -140,6 +150,9 @@ public:
 	MarginAll,
 	MarginVertical,
 	MarginHorizontal
+#ifndef Q_QDOC
+	, MarginUndefined = -1
+#endif
     };
 
     int margin( Margin m) const;
@@ -152,6 +165,9 @@ public:
 	ListDecimal,
 	ListLowerAlpha,
 	ListUpperAlpha
+#ifndef Q_QDOC
+	, ListStyleUndefined = -1
+#endif
     };
 
     ListStyle listStyle() const;
