@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qwidget.h   3.3.2   edited Nov 7 11:52 $
+** $Id: qt/qwidget.h   3.3.3   edited Apr 29 14:07 $
 **
 ** Definition of QWidget class
 **
@@ -588,7 +588,7 @@ private:
     friend QWidget *qt_recursive_match(QWidget *widg, int x, int y);
     friend bool qt_paint_children(QWidget *,QRegion &, uchar ops);
     friend QMAC_PASCAL OSStatus qt_window_event(EventHandlerCallRef er, EventRef event, void *);
-    friend void qt_event_request_updates(QWidget *, const QRegion &, bool subtract=FALSE);
+    friend void qt_event_request_updates(QWidget *, const QRegion &, bool subtract);
     friend bool qt_window_rgn(WId, short, RgnHandle, bool);
     friend class QDragManager;
 #endif
