@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/pbuilder_pbx.cpp   3.3.2   edited Apr 19 08:40 $
+** $Id: qt/pbuilder_pbx.cpp   3.3.3   edited Jun 11 21:47 $
 **
 ** Implementation of ProjectBuilderMakefileGenerator class.
 **
@@ -467,7 +467,7 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
     }
 
     //PREPROCESS BUILDPHASE (just a makefile)
-    if(!project->isEmpty("UICIMPLS") || !project->isEmpty("SRCMOC") ||
+    if(!project->isEmpty("UICIMPLS") || !project->isEmpty("SRCMOC") || !project->isEmpty("IMAGES") ||
 	!project->isEmpty("YACCSOURCES") || !project->isEmpty("LEXSOURCES")) {
 	QString mkfile = pbx_dir + Option::dir_sep + "qt_preprocess.mak";
 	QFile mkf(mkfile);
@@ -634,11 +634,11 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
 			    break;
 			}
 		    }
-		} else if(opt == "-undefined") {
-		    ++it; //the next option is not a library..
 		} else if(opt.left(1) != "-") {
-		    remove = TRUE;
-		    library = opt;
+                    if(QFile::exists(opt)) {
+                        remove = TRUE;
+                        library = opt;
+                    }
 		}
 		if(!library.isEmpty()) {
 		    if(name.isEmpty()) {
@@ -1076,7 +1076,7 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
 	    if(ideType() == MAC_XCODE)
 		t << "\t\t\t" << "productType = \"com.apple.product-type.application\";" << "\n";
 	    else
-		t << "\t\t\t" << "isa = PBXApplicationReference;" << "\n";
+		t << "\t\t\t" << "isa = PBXApplicationTarget;" << "\n";
 	    t << "\t\t\t" << "productSettingsXML = \"";
             bool read_plist = false;
             if(QFile::exists("Info.plist")) {
