@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/makefile.cpp   3.3.2   edited Mar 25 09:35 $
+** $Id: qt/makefile.cpp   3.3.3   edited May 25 02:48 $
 **
 ** Implementation of MakefileGenerator class.
 **
@@ -1117,7 +1117,7 @@ MakefileGenerator::init()
 		    if( d == ".")
 			d = QDir::currentDirPath();
 		    d = fileFixify(d, QDir::currentDirPath(), Option::output_dir);
-		    if(includepath.contains(d))
+		    if(!includepath.contains(d))
 			includepath.append(d);
 		}
 		if(impl.isEmpty() && !project->isEmpty("UI_SOURCES_DIR"))
