@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/unixmake.cpp   3.3.2   edited Feb 20 20:39 $
+** $Id: qt/unixmake.cpp   3.3.3   edited Jul 27 01:34 $
 **
 ** Implementation of UnixMakefileGenerator class.
 **
@@ -495,7 +495,7 @@ UnixMakefileGenerator::findDependency(const QString &dep)
 		    QString out = tmp_out;
 		    QFileInfo fi(Option::fixPathToLocalOS((*input)));
 		    out.replace("${QMAKE_FILE_BASE}", fi.baseName());
-		    out.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		    out.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		    if(out.endsWith(dep))
 			return out;
 		}
@@ -826,8 +826,7 @@ UnixMakefileGenerator::defaultInstall(const QString &t)
 	QString src_targ = target;
 	if(!destdir.isEmpty())
 	    src_targ = Option::fixPathToTargetOS(destdir + target, FALSE);
-	QString dst_targ = root + fileFixify(targetdir + target, 
-					     QDir::currentDirPath(), Option::output_dir);
+	QString dst_targ = root + targetdir + target;
 	if(!ret.isEmpty())
 	    ret += "\n\t";
 	if(resource)
