@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/borland_bmake.cpp   3.3.1   edited Jan 30 09:28 $
+** $Id: qt/borland_bmake.cpp   3.3.3   edited Jul 21 20:07 $
 **
 ** NmakeMakefileGenerator of BorlandMakefileGenerator class.
 **
@@ -132,6 +132,8 @@ BorlandMakefileGenerator::writeBorlandParts(QTextStream &t)
     t << "MOVE  =       " << var("QMAKE_MOVE") << endl;
     t << "CHK_DIR_EXISTS =	" << var("QMAKE_CHK_DIR_EXISTS") << endl;
     t << "MKDIR		=	" << var("QMAKE_MKDIR") << endl;
+    t << "INSTALL_FILE= " << var("QMAKE_INSTALL_FILE") << endl;
+    t << "INSTALL_DIR = " << var("QMAKE_INSTALL_DIR") << endl;
     t << endl;
 
     t << "####### Files" << endl << endl;
@@ -148,7 +150,7 @@ BorlandMakefileGenerator::writeBorlandParts(QTextStream &t)
     if(!project->isEmpty("QMAKE_EXTRA_WIN_COMPILERS")) {
 	t << "OBJCOMP = " << varList("OBJCOMP") << endl;
 	extraCompilerDeps += " $(OBJCOMP) ";
-	
+
 	QStringList &comps = project->variables()["QMAKE_EXTRA_WIN_COMPILERS"];
 	for(QStringList::Iterator compit = comps.begin(); compit != comps.end(); ++compit) {
 	    QStringList &vars = project->variables()[(*compit) + ".variables"];
@@ -198,7 +200,7 @@ BorlandMakefileGenerator::writeBorlandParts(QTextStream &t)
     if(project->isActiveConfig("dll") && !project->variables()["DLLDESTDIR"].isEmpty()) {
 	QStringList dlldirs = project->variables()["DLLDESTDIR"];
 	for ( QStringList::Iterator dlldir = dlldirs.begin(); dlldir != dlldirs.end(); ++dlldir ) {
-	    t << "\n\t" << "-$(COPY_FILE) $(TARGET) " << *dlldir;
+	    t << "\n\t" << "-$(COPY_FILE) \"$(TARGET)\" " << *dlldir;
 	}
     }
     QString targetfilename = project->variables()["TARGET"].first();
@@ -290,7 +292,7 @@ BorlandMakefileGenerator::writeBorlandParts(QTextStream &t)
 		dep = (*dep_it);
 	    deps += " " + dep;
 	}
-	if(!project->variables()["QMAKE_NOFORCE"].isEmpty() && 
+	if(!project->variables()["QMAKE_NOFORCE"].isEmpty() &&
 	   project->variables()[(*it) + ".CONFIG"].findIndex("phony") != -1)
 	    deps += QString(" ") + "FORCE";
 	t << "\n\n" << targ << ":" << deps << "\n\t"
@@ -298,7 +300,7 @@ BorlandMakefileGenerator::writeBorlandParts(QTextStream &t)
     }
 
     t << endl << endl;
-   
+
     QStringList &quc = project->variables()["QMAKE_EXTRA_WIN_COMPILERS"];
     for(it = quc.begin(); it != quc.end(); ++it) {
 	QString tmp_out = project->variables()[(*it) + ".output"].first();
@@ -315,19 +317,19 @@ BorlandMakefileGenerator::writeBorlandParts(QTextStream &t)
 		QString in = Option::fixPathToTargetOS((*input), FALSE),
 		       out = tmp_out, cmd = tmp_cmd, deps;
 		out.replace("${QMAKE_FILE_BASE}", fi.baseName());
-		out.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		out.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		cmd.replace("${QMAKE_FILE_BASE}", fi.baseName());
 		cmd.replace("${QMAKE_FILE_OUT}", out);
-		cmd.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		cmd.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		for(QStringList::Iterator it3 = vars.begin(); it3 != vars.end(); ++it3)
 		    cmd.replace("$(" + (*it3) + ")", "$(QMAKE_COMP_" + (*it3)+")");
 		if(!tmp_dep.isEmpty()) {
 		    char buff[256];
 		    QString dep_cmd = tmp_dep;
-		    dep_cmd.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		    dep_cmd.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		    if(FILE *proc = QT_POPEN(dep_cmd.latin1(), "r")) {
 			while(!feof(proc)) {
-			    int read_in = fread(buff, 1, 255, proc);
+			    int read_in = int(fread(buff, 1, 255, proc));
 			    if(!read_in)
 				break;
 			    int l = 0;
@@ -376,6 +378,11 @@ BorlandMakefileGenerator::init()
 	return;
     }
 
+    if(project->isEmpty("QMAKE_INSTALL_FILE"))
+	project->variables()["QMAKE_INSTALL_FILE"].append("$(COPY_FILE)");
+    if(project->isEmpty("QMAKE_INSTALL_DIR"))
+	project->variables()["QMAKE_INSTALL_DIR"].append("$(COPY_DIR)");
+
     bool is_qt = (project->first("TARGET") == "qt"QTDLL_POSTFIX || project->first("TARGET") == "qtmt"QTDLL_POSTFIX);
     QStringList &configs = project->variables()["CONFIG"];
     if (project->isActiveConfig("shared"))
@@ -645,7 +652,7 @@ BorlandMakefileGenerator::init()
 		QString in = Option::fixPathToTargetOS((*input), FALSE),
 		    out = tmp_out;
 		out.replace("${QMAKE_FILE_BASE}", fi.baseName());
-		out.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		out.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		if(project->variables()[(*it) + ".CONFIG"].findIndex("no_link") == -1)
 		    project->variables()["OBJCOMP"] += out;
 	    }
