@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/mingw_make.cpp   3.3.2   edited Mar 31 10:36 $
+** $Id: qt/mingw_make.cpp   3.3.3   edited Jul 27 19:13 $
 **
 ** Implementation of MingwMakefileGenerator class.
 **
@@ -85,7 +85,10 @@ void createLdObjectScriptFile(const QString & fileName, QStringList & objList)
 	QTextStream t(&file);
 	t << "INPUT(" << endl;
 	for (QStringList::Iterator it = objList.begin(); it != objList.end(); ++it ) {
-	    t << *it << endl;
+	    if (QDir::isRelativePath(*it)) 
+		t << "./" << *it << endl;
+	    else
+		t << *it << endl;
 	}
 	t << ");" << endl;
 	file.close();
@@ -113,7 +116,7 @@ MingwMakefileGenerator::writeMingwParts(QTextStream &t)
     QStringList &incs = project->variables()["INCLUDEPATH"];
     for(QStringList::Iterator incit = incs.begin(); incit != incs.end(); ++incit) {
 	QString inc = (*incit);
-	inc.replace(QRegExp("\\\\$"), "\\\\");
+	inc.replace(QRegExp("\\\\$"), "");
 	inc.replace(QRegExp("\""), "");
 	t << " -I" << "\"" << inc << "\"";
     }
@@ -218,7 +221,6 @@ MingwMakefileGenerator::writeMingwParts(QTextStream &t)
     t << ".cpp.o:\n\t" << var("QMAKE_RUN_CXX_IMP") << endl << endl;
     t << ".cxx.o:\n\t" << var("QMAKE_RUN_CXX_IMP") << endl << endl;
     t << ".cc.o:\n\t" << var("QMAKE_RUN_CXX_IMP") << endl << endl;
-    t << ".C.o:\n\t" << var("QMAKE_RUN_CXX_IMP") << endl << endl;
     t << ".c.o:\n\t" << var("QMAKE_RUN_CC_IMP") << endl << endl;
 
     t << "####### Build rules" << endl << endl;
@@ -331,16 +333,16 @@ MingwMakefileGenerator::writeMingwParts(QTextStream &t)
 		QString in = Option::fixPathToTargetOS((*input), FALSE),
 		       out = tmp_out, cmd = tmp_cmd, deps;
 		out.replace("${QMAKE_FILE_BASE}", fi.baseName());
-		out.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		out.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		cmd.replace("${QMAKE_FILE_BASE}", fi.baseName());
 		cmd.replace("${QMAKE_FILE_OUT}", out);
-		cmd.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		cmd.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		for(QStringList::Iterator it3 = vars.begin(); it3 != vars.end(); ++it3)
 		    cmd.replace("$(" + (*it3) + ")", "$(QMAKE_COMP_" + (*it3)+")");
 		if(!tmp_dep.isEmpty()) {
 		    char buff[256];
 		    QString dep_cmd = tmp_dep;
-		    dep_cmd.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		    dep_cmd.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		    if(FILE *proc = QT_POPEN(dep_cmd.latin1(), "r")) {
 			while(!feof(proc)) {
 			    int read_in = int(fread(buff, 1, 255, proc));
@@ -422,8 +424,12 @@ MingwMakefileGenerator::init()
 	    if ( is_qt && !project->variables()["QMAKE_LIB_FLAG"].isEmpty() )
 		project->variables()["CONFIG"].append("dll");
 	}
-	if ( project->isActiveConfig("thread") )
-	    project->variables()[is_qt ? "PRL_EXPORT_DEFINES" : "DEFINES"].append("QT_THREAD_SUPPORT");
+	if ( project->isActiveConfig("thread") ) {
+            project->variables()[is_qt ? "PRL_EXPORT_DEFINES" : "DEFINES"].append("QT_THREAD_SUPPORT");
+            project->variables()["QMAKE_CFLAGS"] += project->variables()["QMAKE_CFLAGS_THREAD"];
+            project->variables()["QMAKE_CXXFLAGS"] += project->variables()["QMAKE_CXXFLAGS_THREAD"];
+            project->variables()["QMAKE_LFLAGS"] += project->variables()["QMAKE_LFLAGS_THREAD"];
+        }
 	if ( project->isActiveConfig("accessibility" ) )
 	    project->variables()[is_qt ? "PRL_EXPORT_DEFINES" : "DEFINES"].append("QT_ACCESSIBILITY_SUPPORT");
 	if ( project->isActiveConfig("tablet") )
@@ -680,7 +686,7 @@ MingwMakefileGenerator::init()
 		QString in = Option::fixPathToTargetOS((*input), FALSE),
 		       out = tmp_out;
 		out.replace("${QMAKE_FILE_BASE}", fi.baseName());
-		out.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		out.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		if(project->variables()[(*it) + ".CONFIG"].findIndex("no_link") == -1)
 		    project->variables()["OBJCOMP"] += out;
 	    }
