@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/msvc_nmake.cpp   3.3.2   edited Mar 31 10:37 $
+** $Id: qt/msvc_nmake.cpp   3.3.3   edited Jul 27 19:14 $
 **
 ** Implementation of NmakeMakefileGenerator class.
 **
@@ -375,16 +375,16 @@ NmakeMakefileGenerator::writeNmakeParts(QTextStream &t)
 		QString in = Option::fixPathToTargetOS((*input), FALSE),
 		       out = tmp_out, cmd = tmp_cmd, deps;
 		out.replace("${QMAKE_FILE_BASE}", fi.baseName());
-		out.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		out.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		cmd.replace("${QMAKE_FILE_BASE}", fi.baseName());
 		cmd.replace("${QMAKE_FILE_OUT}", out);
-		cmd.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		cmd.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		for(QStringList::Iterator it3 = vars.begin(); it3 != vars.end(); ++it3)
 		    cmd.replace("$(" + (*it3) + ")", "$(QMAKE_COMP_" + (*it3)+")");
 		if(!tmp_dep.isEmpty()) {
 		    char buff[256];
 		    QString dep_cmd = tmp_dep;
-		    dep_cmd.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		    dep_cmd.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		    if(FILE *proc = QT_POPEN(dep_cmd.latin1(), "r")) {
 			while(!feof(proc)) {
 			    int read_in = int(fread(buff, 1, 255, proc));
@@ -419,7 +419,7 @@ NmakeMakefileGenerator::writeNmakeParts(QTextStream &t)
     if(usePCH) {
 	QString precompRule = QString("-c -Yc -Fp%1 -Fo%2").arg(precompPch).arg(precompObj);
 	t << precompObj << ": " << precompH << " " << findDependencies(precompH).join(" \\\n\t\t")
-	  << "\n\t" << "$(CXX) " + precompRule +" $(CXXFLAGS) $(INCPATH) -TP " << precompH << endl << endl;
+	  << "\n\t" << ("$(CXX) " + precompRule + " $(CXXFLAGS) $(INCPATH) -TP ") << precompH << endl << endl;
     }
 }
 
@@ -778,7 +778,7 @@ NmakeMakefileGenerator::init()
 		QString in = Option::fixPathToTargetOS((*input), FALSE),
 		       out = tmp_out;
 		out.replace("${QMAKE_FILE_BASE}", fi.baseName());
-		out.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		out.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		if(project->variables()[(*it) + ".CONFIG"].findIndex("no_link") == -1)
 		    project->variables()["OBJCOMP"] += out;
 	    }
