@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/msvc_objectmodel.cpp   3.3.2   edited Mar 31 10:38 $
+** $Id: qt/msvc_objectmodel.cpp   3.3.3   edited Jul 27 19:17 $
 **
 ** Implementation of VCProject class.
 **
@@ -309,8 +309,10 @@ QTextStream &operator<<( QTextStream &strm, const SPair &prop )
 
 QTextStream &operator<<( QTextStream &strm, const XPair &prop )
 {
-    if ( !prop.value.isEmpty() )
-	strm << prop.name << prop.value.join(prop.sep).latin1() << "\"";
+    if ( !prop.value.isEmpty() ) {
+        QString outText = prop.value.join(prop.sep);
+        strm << prop.name << outText.replace('\"', "&quot;") << "\"";
+    }
     return strm;
 }
 
@@ -347,7 +349,7 @@ VCCLCompilerTool::VCCLCompilerTool()
 	OptimizeForProcessor( procOptimizeBlended ),
 	OptimizeForWindowsApplication( unset ),
 	ProgramDataBaseFileName( "" ),
-	RuntimeLibrary( rtMultiThreaded ),
+	RuntimeLibrary( rtSingleThreaded ),
 	RuntimeTypeInfo( unset ),
 	ShowIncludes( unset ),
 	SmallerTypeCheck( unset ),
@@ -1826,7 +1828,7 @@ VCFilter::VCFilter()
     useCompilerTool = FALSE;
 }
 
-void VCFilter::addMOCstage( QTextStream &strm, QString filename )
+void VCFilter::addMOCstage( QTextStream & /*strm*/, QString filename )
 {
     QString mocOutput = Project->findMocDestination( filename );
     QString mocApp = Project->var( "QMAKE_MOC" );
@@ -1850,7 +1852,7 @@ void VCFilter::addMOCstage( QTextStream &strm, QString filename )
     CustomBuildTool.Outputs += mocOutput;
 }
 
-void VCFilter::addUICstage( QTextStream &strm, QString str )
+void VCFilter::addUICstage( QTextStream & /*strm*/, QString str )
 {
     CustomBuildTool = VCCustomBuildTool();
     useCustomBuildTool = TRUE;
@@ -1904,7 +1906,7 @@ void VCFilter::addUICstage( QTextStream &strm, QString str )
 	uiHeaders + fname + ".h;" + uiSources + fname + ".cpp;" + mocDir + Option::h_moc_mod + fname + Option::h_moc_ext;
 }
 
-void VCFilter::modifyPCHstage( QTextStream &strm, QString str )
+void VCFilter::modifyPCHstage( QTextStream &/*strm*/, QString str )
 {
     bool isCFile = str.endsWith(".c");
     bool isHFile = (str.endsWith(".h") && str == Project->precompH);
@@ -1931,7 +1933,7 @@ void VCFilter::modifyPCHstage( QTextStream &strm, QString str )
     CompilerTool.ForcedIncludeFiles       = "$(NOINHERIT)";
 }
 
-bool VCFilter::addIMGstage( QTextStream &strm, QString str )
+bool VCFilter::addIMGstage( QTextStream &/*strm*/, QString str )
 {
     bool isCorH = FALSE;
     if (str.endsWith(".c") || str.endsWith(".rc"))
@@ -1983,6 +1985,41 @@ bool VCFilter::addIMGstage( QTextStream &strm, QString str )
     return TRUE;
 }
 
+bool VCFilter::addLexYaccStage( QTextStream &/*strm*/, QString str )
+{
+    bool doLex = str.endsWith(".l");
+    if (!doLex && !str.endsWith(".y"))
+        return FALSE;
+
+    QString fname = "$(InputName)";
+    if (doLex) {
+        fname += Option::lex_mod + Option::cpp_ext.first();
+	QString lexpath = Project->var("QMAKE_LEX")
+                        + Project->varGlue("QMAKE_LEXFLAGS", " ", " ", "") + " ";
+
+        CustomBuildTool.Description = "Lex'ing $(InputFileName)";
+        CustomBuildTool.CommandLine = lexpath + " $(InputFileName)";
+        CustomBuildTool.CommandLine += "del " + fname;
+        CustomBuildTool.CommandLine += "move lex.yy.c " + fname;
+        CustomBuildTool.Outputs = fname;
+    } else {
+        fname +=Option::yacc_mod;
+	QString yaccpath = Project->var("QMAKE_YACC")
+                         + Project->varGlue("QMAKE_YACCFLAGS", " ", " ", "") + " ";
+
+        CustomBuildTool.Description = "Yacc'ing $(InputFileName)";
+        CustomBuildTool.CommandLine = yaccpath + " $(InputFileName)";
+        CustomBuildTool.CommandLine += "del " + fname + Option::h_ext.first();
+        CustomBuildTool.CommandLine += "move y.tab.h " + fname + Option::h_ext.first();
+        CustomBuildTool.Outputs = fname + Option::h_ext.first();
+        CustomBuildTool.CommandLine += "del " + fname + Option::cpp_ext.first();
+        CustomBuildTool.CommandLine += "move y.tab.c " + fname + Option::cpp_ext.first();
+        CustomBuildTool.Outputs += fname + Option::cpp_ext.first();
+    }
+    useCustomBuildTool = TRUE;
+    return TRUE;
+}
+
 QTextStream &operator<<( QTextStream &strm, VCFilter &tool )
 {
     if ( tool.Files.count() == 0 )
@@ -2033,6 +2070,8 @@ QTextStream &operator<<( QTextStream &strm, VCFilter &tool )
 	    tool.addMOCstage( strm, *it );
 	else if ( tool.CustomBuild == uic )
 	    tool.addUICstage( strm, *it );
+	else if ( tool.CustomBuild == lexyacc )
+	    tool.addLexYaccStage( strm, *it );
 	else if ( tool.CustomBuild == resource ) {
 	    if (!resourceBuild)
 		resourceBuild = tool.addIMGstage(strm, *it);
