@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/msvc_vcproj.cpp   3.3.2   edited Mar 25 10:50 $
+** $Id: qt/msvc_vcproj.cpp   3.3.3   edited Jun 15 15:56 $
 **
 ** Implementation of VcprojGenerator class.
 **
@@ -190,8 +190,8 @@ QUuid VcprojGenerator::getProjectUUID(const QString &filename)
     // If still not valid, generate new one, and suggest adding to .pro
     if (uuid.isNull() || !validUUID) {
 	uuid = QUuid::createUuid();
-	fprintf(stderr, 
-	        "qmake couldn't create a GUID based on filepath, and we couldn't\nfind a valid GUID in the .pro file (Consider adding\n'GUID = %s'  to the .pro file)\n", 
+	fprintf(stderr,
+	        "qmake couldn't create a GUID based on filepath, and we couldn't\nfind a valid GUID in the .pro file (Consider adding\n'GUID = %s'  to the .pro file)\n",
 		uuid.toString().upper().latin1());
     }
 
@@ -241,7 +241,7 @@ void VcprojGenerator::writeSubDirs(QTextStream &t)
     QPtrList<VcsolutionDepend> solution_cleanup;
     solution_cleanup.setAutoDelete(TRUE);
 
-    
+
     QStringList subdirs = project->variables()["SUBDIRS"];
     QString oldpwd = QDir::currentDirPath();
 
@@ -358,7 +358,7 @@ nextfile:
     t << _slnSolutionConf;
     t << _slnProjDepBeg;
 
-    // Figure out dependencies 
+    // Figure out dependencies
     for(solution_cleanup.first(); solution_cleanup.current(); solution_cleanup.next()) {
 	if(solution_cleanup.current()->targetType == StaticLib)
 	    continue; // Shortcut, Static libs are not dep.
@@ -571,18 +571,26 @@ void VcprojGenerator::initConfiguration()
 	RConf.IntermediateDirectory =
 	RConf.compiler.AssemblerListingLocation =
 	RConf.compiler.ObjectFile = "Release\\";
-	RConf.librarian.OutputFile = 
+	RConf.librarian.OutputFile =
 	RConf.linker.OutputFile = RConf.IntermediateDirectory + "\\" + project->first("MSVCPROJ_TARGET");
 	RConf.linker.parseOptions(project->variables()["QMAKE_LFLAGS_RELEASE"]);
 	RConf.compiler.parseOptions(project->variables()["QMAKE_CFLAGS_RELEASE"]);
+	RConf.compiler.parseOptions(project->variables()["QMAKE_CXXFLAGS_RELEASE"]);
+        if (!project->variables()["QMAKE_CXXFLAGS_RELEASE"].contains("Gm")
+            && project->variables()["QMAKE_CXXFLAGS_DEBUG"].contains("Gm"))
+            RConf.compiler.parseOption("-Gm-");
+        if (RConf.compiler.PreprocessorDefinitions.findIndex("QT_NO_DEBUG") == -1)
+            RConf.compiler.PreprocessorDefinitions += "QT_NO_DEBUG";
     } else {
 	DConf.IntermediateDirectory =
 	DConf.compiler.AssemblerListingLocation =
 	DConf.compiler.ObjectFile = "Debug\\";
-	DConf.librarian.OutputFile = 
+	DConf.librarian.OutputFile =
 	DConf.linker.OutputFile = DConf.IntermediateDirectory + "\\" + project->first("MSVCPROJ_TARGET");
 	DConf.linker.DelayLoadDLLs.clear();
 	DConf.compiler.parseOptions(project->variables()["QMAKE_CFLAGS_DEBUG"]);
+        DConf.compiler.parseOptions(project->variables()["QMAKE_CXXFLAGS_DEBUG"]);
+        DConf.compiler.PreprocessorDefinitions.remove("QT_NO_DEBUG");
     }
 
     // Add Debug configuration to project
@@ -622,8 +630,6 @@ void VcprojGenerator::initCompilerTool()
 		RConf.compiler.parseOptions( project->variables()["QMAKE_CXXFLAGS_MT_DBG"] );
 	    else
 		RConf.compiler.parseOptions( project->variables()["QMAKE_CXXFLAGS_MT_DLLDBG"] );
-	} else {
-	    RConf.compiler.parseOptions( project->variables()["QMAKE_CXXFLAGS_MT_DBG"] );
 	}
     } else {
 	// Release version
@@ -636,8 +642,6 @@ void VcprojGenerator::initCompilerTool()
 		RConf.compiler.parseOptions( project->variables()["QMAKE_CXXFLAGS_MT"] );
 	    else
 		RConf.compiler.parseOptions( project->variables()["QMAKE_CXXFLAGS_MT_DLL"] );
-	} else {
-	    RConf.compiler.parseOptions( project->variables()["QMAKE_CXXFLAGS_MT"] );
 	}
     }
 
@@ -657,11 +661,11 @@ void VcprojGenerator::initCompilerTool()
     RConf.compiler.PreprocessorDefinitions += project->variables()["DEFINES"];
     RConf.compiler.PreprocessorDefinitions += project->variables()["PRL_EXPORT_DEFINES"];
     QStringList::iterator it;
-    for(it=RConf.compiler.PreprocessorDefinitions.begin(); 
-	it!=RConf.compiler.PreprocessorDefinitions.end(); 
+    for(it=RConf.compiler.PreprocessorDefinitions.begin();
+	it!=RConf.compiler.PreprocessorDefinitions.end();
 	++it)
 	(*it).replace('\"', "&quot;");
-    
+
     RConf.compiler.parseOptions( project->variables()["MSVCPROJ_INCPATH"] );
 }
 
