@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/winmakefile.cpp   3.3.2   edited Mar 9 15:07 $
+** $Id: qt/winmakefile.cpp   3.3.3   edited Aug 3 11:22 $
 **
 ** Implementation of Win32MakefileGenerator class.
 **
@@ -240,6 +240,7 @@ Win32MakefileGenerator::writeSubDirs(QTextStream &t)
 	t << "\n\n" << targ << ":" << deps << "\n\t"
 	  << cmd;
     }
+    t << endl << endl;
 
     if(project->variables()["QMAKE_NOFORCE"].isEmpty())
 	t << "FORCE:" << endl << endl;
@@ -300,7 +301,7 @@ Win32MakefileGenerator::findDependency(const QString &dep)
 		    QString out = tmp_out;
 		    QFileInfo fi(Option::fixPathToLocalOS((*input)));
 		    out.replace("${QMAKE_FILE_BASE}", fi.baseName());
-		    out.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		    out.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		    if(out.endsWith(dep)) 
 			return out;
 		}
