@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/project.cpp   3.3.1   edited Dec 9 17:45 $
+** $Id: qt/project.cpp   3.3.3   edited Jun 3 00:18 $
 **
 ** Implementation of QMakeProject class.
 **
@@ -284,7 +284,7 @@ QMakeProject::parse(const QString &t, QMap<QString, QStringList> &place)
 		if(invert_test)
 		    comp_scope = comp_scope.right(comp_scope.length()-1);
 		int lparen = comp_scope.find('(');
-		if(or_op || !scope_failed) {
+		if(or_op == scope_failed) {
 		    if(lparen != -1) { /* if there is an lparen in the scope, it IS a function */
 			int rparen = comp_scope.findRev(')');
 			if(rparen == -1) {
@@ -341,8 +341,6 @@ QMakeProject::parse(const QString &t, QMap<QString, QStringList> &place)
 	test_status = TestNone;
     else if(!else_line || test_status != TestFound)
 	test_status = (scope_failed ? TestSeek : TestFound);
-    if(scope_failed)
-	return TRUE; /* oh well */
     if(!*d) {
 	if(!var.stripWhiteSpace().isEmpty())
 	    qmake_error_msg("Parse Error ('" + s + "')");
@@ -368,7 +366,8 @@ QMakeProject::parse(const QString &t, QMap<QString, QStringList> &place)
 		 vals.latin1(), parser.file.latin1(), parser.line_no);
     }
     doVariableReplace(vals, place);
-
+    if(scope_failed)
+	return TRUE; /* oh well */
 #undef SKIP_WS
 
     if(!var.isEmpty() && Option::mkfile::do_preprocess) {
@@ -551,7 +550,8 @@ QMakeProject::read(uchar cmd)
 	    if(Option::mkfile::qmakespec.isEmpty()) {
 		for(QStringList::Iterator it = mkspec_roots.begin(); it != mkspec_roots.end(); ++it) {
 		    QString mkspec = (*it) + QDir::separator() + "default";
-		    if(QFile::exists(mkspec)) {
+                    QFileInfo default_info(mkspec);
+                    if(default_info.exists() && default_info.isSymLink()) {
 			Option::mkfile::qmakespec = mkspec;
 			break;
 		    }
@@ -1164,7 +1164,7 @@ QMakeProject::doVariableReplace(QString &str, const QMap<QString, QStringList> &
 		replacement = "$";
 	    else if(val == "LITERAL_HASH")
 		replacement = "#";
-	    else if(val == "PWD") 
+	    else if(val == "PWD")
 		replacement = QDir::currentDirPath();
 	    else if(val == "DIR_SEPARATOR")
 		replacement = Option::dir_sep;
@@ -1183,12 +1183,12 @@ QMakeProject::doVariableReplace(QString &str, const QMap<QString, QStringList> &
 		    if(arg_list.count() >= 2)
 			start = arg_list[1].toInt();
 		    if(start < 0)
-			start += var.count();
+			start += int(var.count());
 		    int end = start;
 		    if(arg_list.count() == 3)
 			end = arg_list[2].toInt();
 		    if(end < 0)
-			end += var.count();
+			end += int(var.count());
 		    if(end < start)
 			end = start;
 		    for(int i = start; i <= end && (int)var.count() >= i; i++) {
@@ -1225,7 +1225,7 @@ QMakeProject::doVariableReplace(QString &str, const QMap<QString, QStringList> &
 		    int di = file.findRev(Option::dir_sep);
 		    QDir sunworkshop42workaround = QDir::current();
 		    QString oldpwd = sunworkshop42workaround.currentDirPath();
-		    if(di != -1 && QDir::setCurrent(file.left(file.findRev(Option::dir_sep)))) 
+		    if(di != -1 && QDir::setCurrent(file.left(file.findRev(Option::dir_sep))))
 			file = file.right(file.length() - di - 1);
 		    parser_info pi = parser;
 		    int sb = scope_block;
@@ -1319,7 +1319,7 @@ QMakeProject::doVariableReplace(QString &str, const QMap<QString, QStringList> &
 		    char buff[256];
 		    FILE *proc = QT_POPEN(arg_list.join(" ").latin1(), "r");
 		    while(proc && !feof(proc)) {
-			int read_in = fread(buff, 1, 255, proc);
+			int read_in = int(fread(buff, 1, 255, proc));
 			if(!read_in)
 			    break;
 			for(int i = 0; i < read_in; i++) {
