@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfontdialog.cpp   3.3.2   edited Mar 8 12:40 $
+** $Id: qt/qfontdialog.cpp   3.3.3   edited Jun 7 09:23 $
 **
 ** Implementation of QFontDialog
 **
@@ -283,7 +283,6 @@ QFontDialog::QFontDialog( QWidget *parent, const char *name,
     if ( modal )
 	connect( d->ok, SIGNAL(clicked()), SLOT(accept()) );
     d->ok->setDefault( TRUE );
-    d->ok->setFixedWidth( 80 );
 
     buttonBox->addSpacing( 12 );
 
@@ -291,8 +290,6 @@ QFontDialog::QFontDialog( QWidget *parent, const char *name,
     d->cancel = new QPushButton( cancelt, this, "cancel/close" );
     buttonBox->addWidget( d->cancel );
     connect( d->cancel, SIGNAL(clicked()), SLOT(reject()) );
-    d->cancel->setFixedWidth( 80 );
-
 
     resize( 500, 360 );
 
