@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qaccel.cpp   3.3.2   edited Jan 15 21:03 $
+** $Id: qt/qaccel.cpp   3.3.3   edited Jul 27 10:55 $
 **
 ** Implementation of QAccel class
 **
@@ -873,7 +873,11 @@ QKeySequence QAccel::shortcutKey( const QString &str )
 	if ( str[p] != '&' ) {
 	    QChar c = str[p];
 	    if ( c.isPrint() ) {
-		c = c.upper();
+	        char ltr = c.upper().latin1();
+	        if ( ltr >= (char)Key_A && ltr <= (char)Key_Z )
+                    c = ltr;
+                else
+                    c = c.lower();
 		return QKeySequence( c.unicode() + ALT + UNICODE_ACCEL );
 	    }
 	}
