@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qclipboard_x11.cpp   3.3.2   edited Mar 24 09:45 $
+** $Id: qt/qclipboard_x11.cpp   3.3.3   edited Jul 26 15:14 $
 **
 ** Implementation of QClipboard class for X11
 **
@@ -1515,7 +1515,8 @@ void QClipboard::setData( QMimeSource* src, Mode mode )
     }
 
     Window prevOwner = XGetSelectionOwner( dpy, atom );
-    XSetSelectionOwner(dpy, atom, newOwner, d->timestamp);
+    // use qt_x_time, since d->timestamp == CurrentTime when clearing
+    XSetSelectionOwner(dpy, atom, newOwner, qt_x_time);
 
     if ( mode == Selection )
 	emit selectionChanged();
