@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qdragobject.cpp   3.3.2   edited Mar 15 15:37 $
+** $Id: qt/qdragobject.cpp   3.3.3   edited Jul 26 10:07 $
 **
 ** Implementation of Drag and Drop support
 **
@@ -1449,6 +1449,7 @@ QCString QUriDrag::unicodeUriToUri(const QString& uuri)
     QCString utf8 = uuri.utf8();
     QCString escutf8;
     int n = utf8.length();
+    bool isFile = uuri.startsWith("file://");
     for (int i=0; i<n; i++) {
 	if ( utf8[i] >= 'a' && utf8[i] <= 'z'
 	  || utf8[i] == '/'
@@ -1462,7 +1463,7 @@ QCString QUriDrag::unicodeUriToUri(const QString& uuri)
 	  || utf8[i] == '\''
 
 	  // Allow this through, so that all URI-references work.
-	  || utf8[i] == '#'
+          || (!isFile && utf8[i] == '#')
 
 	  || utf8[i] == ';'
 	  || utf8[i] == '?' || utf8[i] == ':'
