@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qevent.cpp   3.3.2   edited Jan 19 16:16 $
+** $Id: qt/qevent.cpp   3.3.3   edited Apr 22 14:40 $
 **
 ** Implementation of event classes
 **
@@ -113,9 +113,9 @@
     \value MouseMove  Mouse move, \l{QMouseEvent}.
     \value KeyPress  Key press (including Shift, for example), \l{QKeyEvent}.
     \value KeyRelease  Key release, \l{QKeyEvent}.
-    \value IMStart  The start of input method composition.
-    \value IMCompose  Input method composition is taking place.
-    \value IMEnd  The end of input method composition.
+    \value IMStart  The start of input method composition, \l{QIMEvent}.
+    \value IMCompose  Input method composition is taking place, \l{QIMEvent}.
+    \value IMEnd  The end of input method composition, \l{QIMEvent}.
     \value FocusIn  Widget gains keyboard focus, \l{QFocusEvent}.
     \value FocusOut  Widget loses keyboard focus, \l{QFocusEvent}.
     \value Enter  Mouse enters widget's boundaries.
@@ -1851,7 +1851,7 @@ QContextMenuEvent::QContextMenuEvent( Reason reason, const QPoint &pos, int stat
     \fn int QIMEvent::cursorPos() const
 
     Returns the current cursor position inside the composition string.
-    Will return 0 for IMStartEvent and IMEndEvent.
+    Will return -1 for IMStartEvent and IMEndEvent.
 */
 
 /*!
