@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfont_x11.cpp   3.3.2   edited Mar 8 14:33 $
+** $Id: qt/qfont_x11.cpp   3.3.3   edited May 27 17:18 $
 **
 ** Implementation of QFont, QFontMetrics and QFontInfo classes for X11
 **
@@ -510,7 +510,7 @@ void QFont::setRawName( const QString &name )
 
     if ( ! qt_fillFontDef( qt_fixXLFD( name.latin1() ), &d->request, d->screen ) ) {
 #ifdef QT_CHECK_STATE
-	qWarning("QFont::setRawMode(): Invalid XLFD: \"%s\"", name.latin1());
+	qWarning("QFont::setRawName(): Invalid XLFD: \"%s\"", name.latin1());
 #endif // QT_CHECK_STATE
 
 	setFamily( name );
