@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfontdata_p.h   3.3.0   edited Oct 28 17:34 $
+** $Id: qt/qfontdata_p.h   3.3.3   edited Feb 20 12:11 $
 **
 ** Definition of internal QFontData struct
 **
@@ -65,6 +65,9 @@ struct QFontDef
 	  styleHint( QFont::AnyStyle ), styleStrategy( QFont::PreferDefault ),
 	  weight( 50 ), italic( FALSE ), fixedPitch( FALSE ), stretch( 100 ),
 	  ignorePitch(TRUE)
+#ifdef Q_WS_MAC
+	  ,fixedPitchComputed(FALSE)
+#endif
     {
     }
 
