@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfontdatabase.cpp   3.3.2   edited Mar 26 09:21 $
+** $Id: qt/qfontdatabase.cpp   3.3.3   edited Jul 22 15:54 $
 **
 ** Implementation of font database class.
 **
@@ -322,9 +322,11 @@ struct QtFontFamily
 			UnSupported_Xft= 2, UnSupported_Xlfd = 4, UnSupported = 6 };
 
     QtFontFamily(const QString &n )
-	: fixedPitch( FALSE ),
+	:
 #ifdef Q_WS_X11
-	hasXft( FALSE ), xftScriptCheck( FALSE ), xlfdLoaded( FALSE ),
+        fixedPitch( TRUE ), hasXft( FALSE ), xftScriptCheck( FALSE ), xlfdLoaded( FALSE ),
+#else
+        fixedPitch( FALSE ),
 #endif
 #ifdef Q_WS_WIN
 	scriptCheck( FALSE ),
@@ -467,7 +469,7 @@ static const unsigned short sample_chars[QFont::LastPrivateScript] =
     // Ogham,
     0x1680,
     // SpacingModifiers,
-    0x02b0,
+    0x02c6,
     // CombiningMarks,
     0x0300,
 
@@ -543,15 +545,15 @@ static const unsigned short sample_chars[QFont::LastPrivateScript] =
     // LetterlikeSymbols,
     0x2122,
     // NumberForms,
-    0x215b,
+    0x2160,
     // MathematicalOperators,
     0x222b,
     // TechnicalSymbols,
-    0x2440,
+    0x2312,
     // GeometricSymbols,
     0x2500,
     // MiscellaneousSymbols,
-    0x2600,
+    0x2640,
     // EnclosedAndSquare,
     0x2460,
     // Braille,
@@ -597,7 +599,7 @@ static const unsigned short sample_chars[QFont::LastPrivateScript] =
 static inline bool requiresOpenType(QFont::Script s)
 {
     return (s >= QFont::Syriac && s <= QFont::Sinhala)
-		 || (s >= QFont::Tibetan && s <= QFont::Khmer);
+		 || (s >= QFont::Myanmar && s <= QFont::Khmer);
 }
 #endif
 
@@ -679,6 +681,45 @@ static QtFontStyle *bestStyle(QtFontFoundry *foundry, const QtFontStyle::Key &st
     return foundry->styles[best];
 }
 
+#if defined(Q_WS_X11)
+static QtFontEncoding *findEncoding(QFont::Script script, int styleStrategy,
+                                    QtFontSize *size, int force_encoding_id)
+{
+    QtFontEncoding *encoding = 0;
+
+    if (force_encoding_id >= 0) {
+        encoding = size->encodingID(force_encoding_id);
+        if (!encoding)
+            FM_DEBUG("            required encoding_id not available");
+        return encoding;
+    }
+
+    if (styleStrategy & (QFont::OpenGLCompatible | QFont::PreferBitmap)) {
+        FM_DEBUG("            PreferBitmap and/or OpenGL set, skipping Xft");
+    } else {
+        encoding = size->encodingID(-1); // -1 == prefer Xft
+        if (encoding) return encoding;
+    }
+
+    // Xft not available, find an XLFD font, trying the default encoding first
+    encoding = size->encodingID(QFontPrivate::defaultEncodingID);
+
+    if (!encoding || !scripts_for_xlfd_encoding[encoding->encoding][script]) {
+        // find the first encoding that supports the requested script
+        encoding = 0;
+        for (int x = 0; !encoding && x < size->count; ++x) {
+            const int enc = size->encodings[x].encoding;
+            if (scripts_for_xlfd_encoding[enc][script]) {
+                encoding = size->encodings + x;
+                break;
+            }
+        }
+    }
+
+    return encoding;
+}
+#endif // Q_WS_X11
+
 
 #if defined(Q_WS_X11) || defined(Q_WS_WIN)
 static
@@ -719,32 +760,61 @@ unsigned int bestFoundry( QFont::Script script, unsigned int score, int styleStr
 	// 1. see if we have an exact matching size
 	if (! (styleStrategy & QFont::ForceOutline)) {
 	    size = style->pixelSize(pixelSize);
-	    if (size) px = size->pixelSize;
+	    if (size) {
+                FM_DEBUG("          found exact size match (%d pixels)", size->pixelSize);
+                px = size->pixelSize;
+            }
 	}
 
 	// 2. see if we have a smoothly scalable font
 	if (! size && style->smoothScalable && ! (styleStrategy & QFont::PreferBitmap)) {
 	    size = style->pixelSize(SMOOTH_SCALABLE);
-	    if (size) px = pixelSize;
+	    if (size) {
+                FM_DEBUG("          found smoothly scalable font (%d pixels)", pixelSize);
+                px = pixelSize;
+            }
 	}
 
 	// 3. see if we have a bitmap scalable font
 	if (! size && style->bitmapScalable && (styleStrategy & QFont::PreferMatch)) {
 	    size = style->pixelSize(0);
-	    if (size) px = pixelSize;
+	    if (size) {
+                FM_DEBUG("          found bitmap scalable font (%d pixels)", pixelSize);
+                px = pixelSize;
+            }
 	}
 
+#ifdef Q_WS_X11
+        QtFontEncoding *encoding = 0;
+#endif
+
 	// 4. find closest size match
 	if (! size) {
 	    unsigned int distance = ~0u;
 	    for (int x = 0; x < style->count; ++x) {
+#ifdef Q_WS_X11
+                encoding =
+                    findEncoding(script, styleStrategy, style->pixelSizes + x, force_encoding_id);
+                if (!encoding) {
+                    FM_DEBUG("          size %3d does not support the script we want",
+                             style->pixelSizes[x].pixelSize);
+                    continue;
+                }
+#endif
+
 		unsigned int d = QABS(style->pixelSizes[x].pixelSize - pixelSize);
 		if (d < distance) {
 		    distance = d;
 		    size = style->pixelSizes + x;
+		    FM_DEBUG("          best size so far: %3d (%d)", size->pixelSize, pixelSize);
 		}
 	    }
 
+            if (!size) {
+                FM_DEBUG("          no size supports the script we want");
+                continue;
+            }
+
 	    if (style->bitmapScalable && ! (styleStrategy & QFont::PreferQuality) &&
 		(distance * 10 / pixelSize) >= 2) {
 		// the closest size is not close enough, go ahead and
@@ -757,40 +827,10 @@ unsigned int bestFoundry( QFont::Script script, unsigned int score, int styleStr
 	}
 
 #ifdef Q_WS_X11
-	QtFontEncoding *encoding = 0;
-	if ( force_encoding_id >= 0 ) {
-	    encoding = size->encodingID( force_encoding_id );
-	    if ( ! encoding ) {
-		FM_DEBUG( "            required encoding_id not available" );
-		continue;
-	    }
-	} else {
-	    encoding = size->encodingID( -1 ); // -1 == prefer Xft
-
-	    if ( encoding && ( styleStrategy & ( QFont::OpenGLCompatible |
-						 QFont::PreferBitmap ) ) ) {
-		FM_DEBUG( "            PreferBitmap and/or OpenGL set, skipping Xft" );
-		continue;
-	    }
-
-	    if ( ! encoding ) { // Xft not available, find an XLFD font
-		// try the default encoding first
-		encoding = size->encodingID( QFontPrivate::defaultEncodingID );
-
-		if ( ! encoding || ! scripts_for_xlfd_encoding[encoding->encoding][script] ) {
-		    // find the first encoding that supports the requested script
-		    encoding = 0;
-		    for (int x = 0; !encoding && x < size->count; ++x ) {
-			const int enc = size->encodings[x].encoding;
-			if ( scripts_for_xlfd_encoding[enc][script] ) {
-			    encoding = &size->encodings[x];
-			    break;
-			}
-		    }
-		}
-	    }
-	}
-
+        if (size) {
+            encoding = findEncoding(script, styleStrategy, size, force_encoding_id);
+            if (!encoding) size = 0;
+        }
 	if ( ! encoding ) {
 	    FM_DEBUG( "          foundry doesn't support the script we want" );
 	    continue;
@@ -798,32 +838,40 @@ unsigned int bestFoundry( QFont::Script script, unsigned int score, int styleStr
 #endif // Q_WS_X11
 
 	unsigned int this_score = 0x0000;
+        enum {
+            PitchMismatch       = 0x4000,
+            StyleMismatch       = 0x2000,
+            BitmapScaledPenalty = 0x1000,
+            EncodingMismatch    = 0x0002,
+            XLFDPenalty         = 0x0001
+        };
+
 #ifdef Q_WS_X11
 	if ( encoding->encoding != -1 ) {
-	    this_score += 1;
+	    this_score += XLFDPenalty;
 	    if ( encoding->encoding != QFontPrivate::defaultEncodingID )
-		this_score += 10;
+		this_score += EncodingMismatch;
 	}
  	if (pitch != '*') {
  	    if ( !( pitch == 'm' && encoding->pitch == 'c' ) && pitch != encoding->pitch )
- 		this_score += 200;
+ 		this_score += PitchMismatch;
  	}
 #else
 	if (pitch != '*') {
 	    if ((pitch == 'm' && !family->fixedPitch)
 		|| (pitch == 'p' && family->fixedPitch))
-		this_score += 200;
+		this_score += PitchMismatch;
 	}
 #endif
 	if ( styleKey != style->key )
-	    this_score += 100;
+	    this_score += StyleMismatch;
 	if ( !style->smoothScalable && px != size->pixelSize ) // bitmap scaled
-	    this_score += 50;
+	    this_score += BitmapScaledPenalty;
         if (px != pixelSize) // close, but not exact, size match
-            this_score += 20;
+            this_score += QABS(px - pixelSize);
 
 	if ( this_score < score ) {
-	    FM_DEBUG( "          found a match: score %u best score so far %u",
+	    FM_DEBUG( "          found a match: score %x best score so far %x",
 		      this_score, score );
 
 	    score = this_score;
@@ -834,7 +882,7 @@ unsigned int bestFoundry( QFont::Script script, unsigned int score, int styleStr
 	    *best_encoding = encoding;
 #endif // Q_WS_X11
 	} else {
-	    FM_DEBUG( "          score %u no better than best %u", this_score, score);
+	    FM_DEBUG( "          score %x no better than best %x", this_score, score);
 	}
     }
 
@@ -920,12 +968,14 @@ QFontDatabase::findFont( QFont::Script script, const QFontPrivate *fp,
 	      script, scriptName( script ).latin1(),
 	      request.weight, request.italic, request.stretch, request.pixelSize, pitch );
 
+    bool usesFontConfig = FALSE;
 #ifdef QT_XFT2
     if (family_name.isEmpty()
 	|| family_name == "Sans Serif"
 	|| family_name == "Serif"
 	|| family_name == "Monospace") {
 	fe = loadFontConfigFont(fp, request, script);
+        usesFontConfig = (fe != 0);
     }
     if (!fe)
 #endif
@@ -949,7 +999,7 @@ QFontDatabase::findFont( QFont::Script script, const QFontPrivate *fp,
 #ifdef Q_WS_WIN
 		 && ucstricmp( try_family->english_name, family_name ) != 0
 #endif
-		 )
+                )
 		continue;
 
 	    if ( family_name.isEmpty() )
@@ -969,7 +1019,7 @@ QFontDatabase::findFont( QFont::Script script, const QFontPrivate *fp,
 			override_script = QFont::Han_SimplifiedChinese;
 			score_adjust = 200;
 		    } else if (override_script == QFont::Han_SimplifiedChinese
-			&& (try_family->scripts[QFont::Han_TraditionalChinese] & QtFontFamily::Supported)) {
+                               && (try_family->scripts[QFont::Han_TraditionalChinese] & QtFontFamily::Supported)) {
 			override_script = QFont::Han_TraditionalChinese;
 			score_adjust = 200;
 		    } else {
@@ -978,20 +1028,20 @@ QFontDatabase::findFont( QFont::Script script, const QFontPrivate *fp,
 		    }
 		} else
 #endif
-		if (family_name.isEmpty()) {
-		    continue;
-		} else if (try_family->scripts[QFont::UnknownScript] & QtFontFamily::Supported) {
-		    // try with the unknown script (for a symbol font)
-		    override_script = QFont::UnknownScript;
+                    if (family_name.isEmpty()) {
+                        continue;
+                    } else if (try_family->scripts[QFont::UnknownScript] & QtFontFamily::Supported) {
+                        // try with the unknown script (for a symbol font)
+                        override_script = QFont::UnknownScript;
 #ifndef QT_XFT2
-		} else if (try_family->scripts[QFont::Unicode] & QtFontFamily::Supported) {
-		    // try with the unicode script instead
-		    override_script = QFont::Unicode;
+                    } else if (try_family->scripts[QFont::Unicode] & QtFontFamily::Supported) {
+                        // try with the unicode script instead
+                        override_script = QFont::Unicode;
 #endif
-		} else {
-		    // family not supported by unicode/unknown scripts
-		    continue;
-		}
+                    } else {
+                        // family not supported by unicode/unknown scripts
+                        continue;
+                    }
 	    }
 
 	    QtFontFoundry *try_foundry = 0;
@@ -1134,7 +1184,12 @@ QFontDatabase::findFont( QFont::Script script, const QFontPrivate *fp,
 	}
 
 	if ( fp ) {
-	    QFontCache::Key key( request, script,
+            QFontDef def = request;
+            if (def.family.isEmpty()) {
+                def.family = fp->request.family;
+                def.family = def.family.left(def.family.find(','));
+            }
+	    QFontCache::Key key( def, script,
 #ifdef Q_WS_WIN
 				 (int)fp->paintdevice
 #else
@@ -1142,15 +1197,17 @@ QFontDatabase::findFont( QFont::Script script, const QFontPrivate *fp,
 #endif
 		);
 	    QFontCache::instance->insertEngine( key, fe );
-	    for ( int i = 0; i < QFont::NScripts; ++i ) {
-		if ( i == script ) continue;
+            if (!usesFontConfig) {
+                for ( int i = 0; i < QFont::NScripts; ++i ) {
+                    if ( i == script ) continue;
 
-		if (!canRender(fe, (QFont::Script) i))
-		    continue;
+                    if (!canRender(fe, (QFont::Script) i))
+                        continue;
 
-		key.script = i;
-		QFontCache::instance->insertEngine( key, fe );
-	    }
+                    key.script = i;
+                    QFontCache::instance->insertEngine( key, fe );
+                }
+            }
 	}
     } else {
 	if ( request.family.isEmpty() ) {
@@ -1540,9 +1597,8 @@ bool QFontDatabase::isBitmapScalable( const QString &family,
 	QtFontFoundry *foundry = f->foundries[j];
 	if ( foundryName.isEmpty() || ucstricmp( foundry->name, foundryName ) == 0 ) {
 	    for ( int k = 0; k < foundry->count; k++ )
-		if ( foundry->styles[k]->key == styleKey &&
-		     foundry->styles[k]->bitmapScalable &&
-		     !foundry->styles[k]->smoothScalable ) {
+		if ((style.isEmpty() || foundry->styles[k]->key == styleKey) &&
+                    foundry->styles[k]->bitmapScalable && !foundry->styles[k]->smoothScalable) {
 		    bitmapScalable = TRUE;
 		    goto end;
 		}
@@ -1577,11 +1633,9 @@ bool  QFontDatabase::isSmoothlyScalable( const QString &family,
 
     for ( int j = 0; j < f->count; j++ ) {
 	QtFontFoundry *foundry = f->foundries[j];
-	if ( foundryName.isEmpty() ||
-	     ucstricmp( foundry->name, foundryName ) == 0 ) {
+	if ( foundryName.isEmpty() || ucstricmp( foundry->name, foundryName ) == 0 ) {
 	    for ( int k = 0; k < foundry->count; k++ )
-		if ( foundry->styles[k]->key == styleKey &&
-		     foundry->styles[k]->smoothScalable ) {
+		if ((style.isEmpty() || foundry->styles[k]->key == styleKey) && foundry->styles[k]->smoothScalable) {
 		    smoothScalable = TRUE;
 		    goto end;
 		}
