@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfontdatabase_x11.cpp   3.3.2   edited Mar 25 11:48 $
+** $Id: qt/qfontdatabase_x11.cpp   3.3.3   edited Jul 29 15:37 $
 **
 ** Implementation of platform specific QFontDatabase
 **
@@ -865,6 +865,9 @@ static void loadXft()
 		     XFT_SPACING, XFT_FILE, XFT_INDEX,
 #ifdef QT_XFT2
 		     FC_CHARSET, FC_FOUNDRY, FC_SCALABLE, FC_PIXEL_SIZE,
+#if FC_VERSION >= 20193
+                     FC_WIDTH,
+#endif
 #endif // QT_XFT2
 		     (const char *)0);
 
@@ -928,12 +931,23 @@ static void loadXft()
 	styleKey.italic = (slant_value == XFT_SLANT_ITALIC);
 	styleKey.oblique = (slant_value == XFT_SLANT_OBLIQUE);
 	styleKey.weight = getXftWeight( weight_value );
+#ifdef QT_XFT2
+        if (!scalable) {
+            int width = 100;
+#if FC_VERSION >= 20193
+	    XftPatternGetInteger (fonts->fonts[i], FC_WIDTH, 0, &width);
+#endif
+            styleKey.stretch = width;
+        }
+#endif
 
 	QtFontFoundry *foundry
 	    = family->foundry( foundry_value ? QString::fromUtf8(foundry_value) : QString::null,  TRUE );
 	QtFontStyle *style = foundry->style( styleKey,  TRUE );
 
-	family->fixedPitch = ( spacing_value >= XFT_MONO );
+        if (spacing_value < XFT_MONO )
+            family->fixedPitch = FALSE;
+
 	QtFontSize *size;
 	if (scalable) {
 	    style->smoothScalable = TRUE;
@@ -944,7 +958,7 @@ static void loadXft()
 	    double pixel_size = 0;
 	    XftPatternGetDouble (fonts->fonts[i], FC_PIXEL_SIZE, 0, &pixel_size);
 	    size = style->pixelSize( (int)pixel_size, TRUE );
-	}
+        }
 #endif
 	QtFontEncoding *enc = size->encodingID( -1, 0, 0, 0, 0, TRUE );
 	enc->pitch = ( spacing_value >= XFT_CHARCELL ? 'c' :
@@ -973,8 +987,11 @@ static void loadXft()
 	QtFontFoundry *foundry
 	    = family->foundry( QString::null,  TRUE );
 
-	for ( int i = 0; i < QFont::LastPrivateScript; ++i )
+	for ( int i = 0; i < QFont::LastPrivateScript; ++i ) {
+            if (i == QFont::UnknownScript)
+                continue;
 	    family->scripts[i] = QtFontFamily::Supported;
+        }
 
 	QtFontStyle::Key styleKey;
 	styleKey.oblique = FALSE;
@@ -1394,7 +1411,7 @@ void QFontDatabase::createDatabase()
 #define MAXFONTSIZE_XLFD 128
 #ifndef QT_NO_XFTFREETYPE
 static double addPatternProps(XftPattern *pattern, const QtFontStyle::Key &key, bool fakeOblique,
-			      const QFontPrivate *fp, const QFontDef &request)
+			      bool smoothScalable, const QFontPrivate *fp, const QFontDef &request)
 {
     int weight_value = XFT_WEIGHT_BLACK;
     if ( key.weight == 0 )
@@ -1435,7 +1452,17 @@ static double addPatternProps(XftPattern *pattern, const QtFontStyle::Key &key,
     size_value = size_value*72./QPaintDevice::x11AppDpiY(fp->screen);
     XftPatternAddDouble( pattern, XFT_SIZE, size_value );
 
-#  ifdef XFT_MATRIX
+#ifdef XFT_MATRIX
+#  ifdef QT_XFT2
+    if (!smoothScalable) {
+#    if FC_VERSION >= 20193
+        int stretch = request.stretch;
+        if (!stretch)
+            stretch = 100;
+	XftPatternAddInteger(pattern, FC_WIDTH, stretch);
+#    endif
+    } else
+#  endif
     if ( ( request.stretch > 0 && request.stretch != 100 ) ||
 	 ( key.oblique && fakeOblique ) ) {
 	XftMatrix matrix;
@@ -1448,7 +1475,7 @@ static double addPatternProps(XftPattern *pattern, const QtFontStyle::Key &key,
 
 	XftPatternAddMatrix( pattern, XFT_MATRIX, &matrix );
     }
-#  endif // XFT_MATRIX
+#endif // XFT_MATRIX
 
     if (request.styleStrategy & (QFont::PreferAntialias|QFont::NoAntialias)) {
 	XftPatternAddBool(pattern, XFT_ANTIALIAS,
@@ -1521,7 +1548,8 @@ QFontEngine *loadEngine( QFont::Script script,
 			     ( encoding->pitch == 'm' ? XFT_MONO : XFT_PROPORTIONAL ) );
 	XftPatternAddInteger( pattern, XFT_SPACING, pitch_value );
 
-	double scale = addPatternProps(pattern, style->key, style->fakeOblique, fp, request);
+	double scale = addPatternProps(pattern, style->key, style->fakeOblique,
+                                       style->smoothScalable, fp, request);
 
 	XftResult res;
 	XftPattern *result =
@@ -1701,7 +1729,7 @@ static QFontEngine *loadFontConfigFont(const QFontPrivate *fp, const QFontDef &r
     key.weight = request.weight;
     key.stretch = request.stretch;
 
-    double scale = addPatternProps(pattern, key, false, fp, request);
+    double scale = addPatternProps(pattern, key, false, true, fp, request);
 #ifdef FONT_MATCH_DEBUG
     qDebug("original pattern contains:");
     FcPatternPrint(pattern);
@@ -1797,7 +1825,7 @@ static QFontEngine *loadFontConfigFont(const QFontPrivate *fp, const QFontDef &r
 
 	XftPattern *pattern = XftPatternDuplicate(font);
 	// add properties back in as the font selected from the list doesn't contain them.
-	addPatternProps(pattern, key, false, fp, request);
+	addPatternProps(pattern, key, false, true, fp, request);
 
 	XftPattern *result =
 	    XftFontMatch( QPaintDevice::x11AppDisplay(), fp->screen, pattern, &res );
