@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfontengine_x11.cpp   3.3.2   edited Mar 30 11:48 $
+** $Id: qt/qfontengine_x11.cpp   3.3.3   edited Jul 22 13:36 $
 **
 ** ???
 **
@@ -443,7 +443,7 @@ void QFontEngineXLFD::draw( QPainter *p, int x, int y, const QTextEngine *engine
     int yorig = y;
 
     Qt::HANDLE font_id = _fs->fid;
-    if ( p->txop > QPainter::TxTranslate ) {
+    if ( p->txop > QPainter::TxTranslate || _scale < 0.9999 || _scale > 1.0001  ) {
 	bool degenerate = QABS( p->m11()*p->m22() - p->m12()*p->m21() ) < 0.01;
 	if ( !degenerate && xlfd_transformations != XlfdTrUnsupported ) {
 	    // need a transformed font from the server
@@ -533,53 +533,37 @@ void QFontEngineXLFD::draw( QPainter *p, int x, int y, const QTextEngine *engine
 	}
 	if ( degenerate || xlfd_transformations == XlfdTrUnsupported ) {
 	    // XServer or font don't support server side transformations, need to do it by hand
-            QRect bbox( 0, 0, si->width, si->ascent + si->descent + 1 );
-            int w=bbox.width(), h=bbox.height();
-            int aw = w, ah = h;
-            int tx=-bbox.x(), ty=-bbox.y();    // text position
+            int w = qRound(si->width/_scale), h = qRound((si->ascent + si->descent + 1)/_scale);
             QWMatrix mat1 = p->xmat;
-	    if ( aw == 0 || ah == 0 )
+            mat1.scale(_scale, _scale);
+	    if (w == 0 || h == 0)
 		return;
-	    double rx = (double)w / (double)aw;
-	    double ry = (double)h / (double)ah;
-            QWMatrix mat2 = QPixmap::trueMatrix( QWMatrix( rx, 0, 0, ry, 0, 0 )*mat1, aw, ah );
-	    QBitmap *wx_bm;
-#if 0
-            QString bm_key = gen_text_bitmap_key( mat2, dfont, str, pos, len );
-            wx_bm = get_text_bitmap( bm_key );
-            bool create_new_bm = wx_bm == 0;
-            if ( create_new_bm )
-#endif
-	    { 	        // no such cached bitmap
-                QBitmap bm( aw, ah, TRUE );     // create bitmap
-                QPainter paint;
-                paint.begin( &bm );             // draw text in bitmap
-		draw( &paint, 0, si->ascent, engine, si, textFlags );
-                paint.end();
-                wx_bm = new QBitmap( bm.xForm(mat2) ); // transform bitmap
-                if ( wx_bm->isNull() ) {
-                    delete wx_bm;               // nothing to draw
-                    return;
-                }
-            }
+            float tmp = _scale;
+            _scale = 1;
+            QWMatrix mat2 = QPixmap::trueMatrix(mat1, w, h);
+            QBitmap bm(w, h, TRUE);     // create bitmap
+            QPainter paint;
+            paint.begin( &bm );             // draw text in bitmap
+            draw( &paint, 0, qRound(si->ascent/tmp), engine, si, textFlags );
+            paint.end();
+            _scale = tmp;
+	    QBitmap wx_bm( bm.xForm(mat2) ); // transform bitmap
+            if ( wx_bm.isNull() )
+                return;
+
             double fx=x, fy=y - si->ascent, nfx, nfy;
-            mat1.map( fx,fy, &nfx,&nfy );
-            double tfx=tx, tfy=ty, dx, dy;
+            p->xmat.map( fx,fy, &nfx,&nfy );
+            double tfx=0, tfy=0, dx, dy;
             mat2.map( tfx, tfy, &dx, &dy );     // compute position of bitmap
             x = qRound(nfx-dx);
             y = qRound(nfy-dy);
+
             XSetFillStyle( dpy, gc, FillStippled );
-            XSetStipple( dpy, gc, wx_bm->handle() );
+            XSetStipple( dpy, gc, wx_bm.handle() );
             XSetTSOrigin( dpy, gc, x, y );
-            XFillRectangle( dpy, hd, gc, x, y, wx_bm->width(), wx_bm->height() );
+            XFillRectangle( dpy, hd, gc, x, y, wx_bm.width(), wx_bm.height() );
             XSetTSOrigin( dpy, gc, 0, 0 );
             XSetFillStyle( dpy, gc, FillSolid );
-#if 0
-	    if ( create_new_bm )
-                ins_text_bitmap( bm_key, wx_bm );
-#else
-	    delete wx_bm;
-#endif
             return;
         }
 	transform = TRUE;
@@ -595,7 +579,7 @@ void QFontEngineXLFD::draw( QPainter *p, int x, int y, const QTextEngine *engine
     glyph_metrics_t ci = boundingBox( glyphs, advances, offsets, si->num_glyphs );
     p->drawRect( x + ci.x, y + ci.y, ci.width, ci.height );
     p->drawRect( x + ci.x, y + 100 + ci.y, ci.width, ci.height );
-     qDebug("bounding rect=%d %d (%d/%d)", ci.x, ci.y, ci.width, ci.height );
+    qDebug("bounding rect=%d %d (%d/%d)", ci.x, ci.y, ci.width, ci.height );
     p->restore();
     int xp = x;
     int yp = y;
@@ -702,9 +686,9 @@ glyph_metrics_t QFontEngineXLFD::boundingBox( const glyph_t *glyphs, const advan
 	    overall.y = QMIN( overall.y, y );
 	    xmax = QMAX( xmax, overall.xoff + offsets[i].x + xcs->rbearing );
 	    ymax = QMAX( ymax, y + xcs->ascent + xcs->descent );
-	    overall.xoff += advances[i];
+	    overall.xoff += qRound(advances[i]/_scale);
 	} else {
-	    int size = ascent();
+	    int size = _fs->ascent;
 	    overall.x = QMIN(overall.x, overall.xoff );
 	    overall.y = QMIN(overall.y, overall.yoff - size );
 	    ymax = QMAX( ymax, overall.yoff );
@@ -734,7 +718,7 @@ glyph_metrics_t QFontEngineXLFD::boundingBox( glyph_t glyph )
     if (xcs) {
 	gm = glyph_metrics_t( xcs->lbearing, -xcs->ascent, xcs->rbearing- xcs->lbearing, xcs->ascent + xcs->descent, xcs->width, 0 );
     } else {
-	int size = ascent();
+	int size = _fs->ascent;
 	gm = glyph_metrics_t( 0, size, size, size, size, 0 );
     }
     if ( _scale != 1. ) {
@@ -1395,29 +1379,17 @@ QFontEngineXft::QFontEngineXft( XftFont *font, XftPattern *pattern, int cmap )
 	xftfs->charmap = -1;
     }
 #else
-    int symbol = -1;
-    int charmap = -1;
+    _cmap = -1;
+    // Xft maps Unicode and adobe roman for us.
     for (int i = 0; i < _face->num_charmaps; ++i) {
-	FT_CharMap cm = _face->charmaps[i];
-//  	qDebug("font has charmap %x", cm->encoding);
-	if (charmap == -1 && cm->encoding == ft_encoding_unicode)
-	    charmap = i;
-	// we don't use FT_ENCODING_MS_SYMBOL in 3.3, as it maps to U+0xf0xx. All of the fonts
-	// tested also provide a FT_ENCODING_APPLE_ROMAN table that works for the basic range.
-	if (symbol == -1
-	    && (/*cm->encoding == FT_ENCODING_MS_SYMBOL ||*/
-		cm->encoding == ft_encoding_adobe_custom
-		|| cm->encoding == ft_encoding_apple_roman)) {
-	    symbol = i;
-	}
-    }
-
-    // symbol font
-    if (symbol != -1 && (charmap == -1 || cmap))
-	charmap = symbol;
-    if (charmap != -1) {
-// 	qDebug("using charmap %x", _face->charmaps[charmap]->encoding);
-	FT_Set_Charmap(_face, _face->charmaps[charmap]);
+        FT_CharMap cm = _face->charmaps[i];
+//         qDebug("font has charmap %x", cm->encoding);
+        if (cm->encoding == ft_encoding_adobe_custom
+            || cm->encoding == ft_encoding_symbol) {
+//             qDebug("font has adobe custom or ms symbol charmap");
+            _cmap = i;
+            break;
+        }
     }
 #endif // QT_XFT2
 
@@ -1458,6 +1430,17 @@ QFontEngineXft::~QFontEngineXft()
     }
 }
 
+#ifdef QT_XFT2
+static glyph_t getAdobeCharIndex(XftFont *font, int cmap, uint ucs4)
+{
+    FT_Face _face = XftLockFace( font );
+    FT_Set_Charmap(_face, _face->charmaps[cmap]);
+    glyph_t g = FT_Get_Char_Index(_face, ucs4);
+    XftUnlockFace(font);
+    return g;
+}
+#endif
+
 QFontEngine::Error QFontEngineXft::stringToCMap( const QChar *str, int len, glyph_t *glyphs, advance_t *advances, int *nglyphs, bool mirrored ) const
 {
     if ( *nglyphs < len ) {
@@ -1466,14 +1449,27 @@ QFontEngine::Error QFontEngineXft::stringToCMap( const QChar *str, int len, glyp
     }
 
 #ifdef QT_XFT2
-    if ( mirrored ) {
+    if (_cmap != -1) {
+	for ( int i = 0; i < len; ++i ) {
+	    unsigned short uc = str[i].unicode();
+	    glyphs[i] = uc < cmapCacheSize ? cmapCache[uc] : 0;
+	    if ( !glyphs[i] ) {
+		glyph_t glyph = XftCharIndex(0, _font, uc);
+                if (!glyph)
+                    glyph = getAdobeCharIndex(_font, _cmap, uc);
+		glyphs[i] = glyph;
+		if ( uc < cmapCacheSize )
+		    ((QFontEngineXft *)this)->cmapCache[uc] = glyph;
+	    }
+	}
+    } else if ( mirrored ) {
 	for ( int i = 0; i < len; ++i ) {
 	    unsigned short uc = ::mirroredChar(str[i]).unicode();
 	    glyphs[i] = uc < cmapCacheSize ? cmapCache[uc] : 0;
 	    if ( !glyphs[i] ) {
 		if (uc == 0xa0)
 		    uc = 0x20;
-		glyph_t glyph = FT_Get_Char_Index(_face, uc);
+		glyph_t glyph = XftCharIndex(0, _font, uc);
 		glyphs[i] = glyph;
 		if ( uc < cmapCacheSize )
 		    ((QFontEngineXft *)this)->cmapCache[uc] = glyph;
@@ -1486,7 +1482,7 @@ QFontEngine::Error QFontEngineXft::stringToCMap( const QChar *str, int len, glyp
 	    if ( !glyphs[i] ) {
 		if (uc == 0xa0)
 		    uc = 0x20;
-		glyph_t glyph = FT_Get_Char_Index(_face, uc);
+		glyph_t glyph = XftCharIndex(0, _font, uc);
 		glyphs[i] = glyph;
 		if ( uc < cmapCacheSize )
 		    ((QFontEngineXft *)this)->cmapCache[uc] = glyph;
@@ -1906,27 +1902,37 @@ glyph_metrics_t QFontEngineXft::boundingBox( const glyph_t *glyphs, const advanc
     glyph_metrics_t overall;
     int ymax = 0;
     int xmax = 0;
-    for (int i = 0; i < numGlyphs; i++) {
-	getGlyphInfo( &xgi, _font, glyphs[i] );
-	int x = overall.xoff + offsets[i].x - xgi.x;
-	int y = overall.yoff + offsets[i].y - xgi.y;
-	overall.x = QMIN( overall.x, x );
-	overall.y = QMIN( overall.y, y );
-	xmax = QMAX( xmax, x + xgi.width );
-	ymax = QMAX( ymax, y + xgi.height );
-	overall.xoff += advances[i];
+    if (_scale != 1) {
+        for (int i = 0; i < numGlyphs; i++) {
+            getGlyphInfo( &xgi, _font, glyphs[i] );
+            int x = overall.xoff + offsets[i].x - xgi.x;
+            int y = overall.yoff + offsets[i].y - xgi.y;
+            overall.x = QMIN( overall.x, x );
+            overall.y = QMIN( overall.y, y );
+            xmax = QMAX( xmax, x + xgi.width );
+            ymax = QMAX( ymax, y + xgi.height );
+            overall.xoff += qRound(advances[i]/_scale);
+        }
+	overall.x = qRound(overall.x * _scale);
+	overall.y = qRound(overall.y * _scale);
+	overall.xoff = qRound(overall.xoff * _scale);
+	overall.yoff = qRound(overall.yoff * _scale);
+	xmax = qRound(xmax * _scale);
+	ymax = qRound(ymax * _scale);
+    } else {
+        for (int i = 0; i < numGlyphs; i++) {
+            getGlyphInfo( &xgi, _font, glyphs[i] );
+            int x = overall.xoff + offsets[i].x - xgi.x;
+            int y = overall.yoff + offsets[i].y - xgi.y;
+            overall.x = QMIN( overall.x, x );
+            overall.y = QMIN( overall.y, y );
+            xmax = QMAX( xmax, x + xgi.width );
+            ymax = QMAX( ymax, y + xgi.height );
+            overall.xoff += advances[i];
+        }
     }
     overall.height = ymax - overall.y;
     overall.width = xmax - overall.x;
-
-    if ( _scale != 1. ) {
-	overall.x = qRound(overall.x * _scale);
-	overall.y = qRound(overall.y * _scale);
-	overall.height = qRound(overall.height * _scale);
-	overall.width = qRound(overall.width * _scale);
-	overall.xoff = qRound(overall.xoff * _scale);
-	overall.yoff = qRound(overall.yoff * _scale);
-    }
     return overall;
 }
 
@@ -2067,13 +2073,22 @@ bool QFontEngineXft::canRender( const QChar *string, int len )
     bool allExist = TRUE;
 
 #ifdef QT_XFT2
-    for ( int i = 0; i < len; i++ ) {
-	if (!FT_Get_Char_Index(_face, string[i].unicode())) {
-	    allExist = FALSE;
-	    break;
-	}
+    if (_cmap != -1) {
+        for ( int i = 0; i < len; i++ ) {
+            if (!XftCharExists(0, _font, string[i].unicode())
+                && getAdobeCharIndex(_font, _cmap, string[i].unicode()) == 0) {
+                allExist = FALSE;
+                break;
+            }
+        }
+    } else {
+        for ( int i = 0; i < len; i++ ) {
+            if (!XftCharExists(0, _font, string[i].unicode())) {
+                allExist = FALSE;
+                break;
+            }
+        }
     }
-
 #else
     glyph_t glyphs[256];
     int nglyphs = 255;
