@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qmovie.cpp   3.3.2   edited Dec 2 12:51 $
+** $Id: qt/qmovie.cpp   3.3.3   edited Apr 20 17:22 $
 **
 ** Implementation of movie classes
 **
@@ -467,11 +467,12 @@ void QMoviePrivate::frameDone(const QPoint& p,
 {
     preFrameDone();
     const QImage& gimg = decoder->image();
+    QPoint point = p - gimg.offset();
     if (framenumber==0)
 	emit sizeChanged(gimg.size());
-    valid_area = valid_area.unite(QRect(p,rect.size()));
-    updatePixmapFromImage(p,rect);
-    emit areaChanged(QRect(p,rect.size()));
+    valid_area = valid_area.unite(QRect(point,rect.size()));
+    updatePixmapFromImage(point,rect);
+    emit areaChanged(QRect(point,rect.size()));
     emit dataStatus(QMovie::EndOfFrame);
     framenumber++;
 }
