@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qobject.cpp   3.3.1   edited Feb 12 14:26 $
+** $Id: qt/qobject.cpp   3.3.3   edited Jun 14 12:27 $
 **
 ** Implementation of QObject class
 **
@@ -991,7 +991,8 @@ void QObject::blockSignals( bool block )
     The QTimer class provides a high-level programming interface with
     one-shot timers and timer signals instead of events.
 
-    \sa timerEvent(), killTimer(), killTimers()
+    \sa timerEvent(), killTimer(), killTimers(), QEventLoop::awake(),
+        QEventLoop::aboutToBlock()
 */
 
 int QObject::startTimer( int interval )
