@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qobjectdefs.h   3.2.2   edited Jun 11 12:03 $
+** $Id: qt/qobjectdefs.h   3.3.3   edited Nov 7 2003 $
 **
 ** Macros and definitions related to QObject
 **
@@ -168,19 +168,7 @@ Q_EXPORT void *qt_find_obj_child( QObject *, const char *, const char * );
 
 Q_EXPORT void *qt_inheritedBy( QMetaObject *super, const QObject *cls );
 
-#if defined(Q_CC_MIPS) && defined(_MIPS_SIM) && (_MIPS_SIM == _ABIO32)
-#define QT_CAST(type, object) ::qt_cast(object, (type)0)
-template <class T>
-Q_INLINE_TEMPLATES T qt_cast(const QObject *object, T)
-{ return (T)qt_inheritedBy( ((T)0)->staticMetaObject(), object ); }
-#elif defined(Q_CC_SUN) && (__SUNPRO_CC <= 0x500)
-#define QT_CAST(type, object) ::qt_cast(object, (type)0)
-template <typename T>
-Q_INLINE_TEMPLATES T qt_cast(const QObject *object, T)
-{ return (T)qt_inheritedBy( ((T)0)->staticMetaObject(), object ); }
-#else
 template <typename T>
 Q_INLINE_TEMPLATES T qt_cast(const QObject *object)
 { return (T)qt_inheritedBy( ((T)0)->staticMetaObject(), object ); }
-#endif
 #endif // QOBJECTDEFS_H
