@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qpaintdevice_x11.cpp   3.3.2   edited Apr 2 13:55 $
+** $Id: qt/qpaintdevice_x11.cpp   3.3.3   edited Apr 27 14:10 $
 **
 ** Implementation of QPaintDevice class for X11
 **
@@ -796,7 +796,8 @@ static GC cache_mask_gc( Display *dpy, Drawable hd, int mask_no, Pixmap mask )
     \relates QPaintDevice
 
     Copies a block of pixels from \a src to \a dst, perhaps merging
-    each pixel according to the raster operation \a rop. \a sx, \a sy
+    each pixel according to the \link Qt::RasterOp raster operation \endlink
+    \a rop. \a sx, \a sy
     is the top-left pixel in \a src (0, 0) by default, \a dx, \a dy is
     the top-left position in \a dst and \a sw, \a sh is the size of
     the copied block (all of \a src by default).
