@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qpainter.h   3.3.1   edited Feb 3 23:50 $
+** $Id: qt/qpainter.h   3.3.3   edited Jun 1 14:27 $
 **
 ** Definition of QPainter class
 **
@@ -60,6 +60,10 @@ class QMacSavedPortInfo;
 #endif
 class QPainterPrivate;
 
+#if defined(Q_WS_QWS)
+class QScreen;
+#endif
+
 class Q_EXPORT QPainter : public Qt
 {
 public:
@@ -77,6 +81,9 @@ public:
 
 #ifdef Q_WS_QWS
     QGfx * internalGfx();
+#ifdef QT_QWS_EXPERIMENTAL_SCREENPAINTER
+    bool begin(QScreen *screen);
+#endif
 #endif
 
     static void redirect( QPaintDevice *pdev, QPaintDevice *replacement );
