@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qpainter_x11.cpp   3.3.2   edited Apr 15 14:02 $
+** $Id: qt/qpainter_x11.cpp   3.3.3   edited Jul 26 12:10 $
 **
 ** Implementation of QPainter class for X11
 **
@@ -373,6 +373,9 @@ static void free_gc( Display *dpy, GC gc, bool privateGC = FALSE )
             p++;
         }
     }
+
+    // not found in gc_array
+    XFreeGC(dpy, gc);
 }
 
 
@@ -645,8 +648,10 @@ void QPainter::updateFont()
 {
     clearf(DirtyFont);
     if ( testf(ExtDev) ) {
-	if ( pfont ) delete pfont;
-	pfont = new QFont( cfont.d, pdev );
+        if (pdev->devType() == QInternal::Printer) {
+            if ( pfont ) delete pfont;
+            pfont = new QFont( cfont.d, pdev );
+        }
         QPDevCmdParam param[1];
         param[0].font = &cfont;
         if ( !pdev->cmd( QPaintDevice::PdcSetFont, this, param ) || !hd )
@@ -1349,7 +1354,8 @@ static const short ropCodes[] = {                     // ROP translation table
 
 
 /*!
-    Sets the raster operation to \a r. The default is \c CopyROP.
+    Sets the \link Qt::RasterOp raster operation \endlink to \a r.
+    The default is \c CopyROP.
 
     \sa rasterOp() Qt::RasterOp
 */
