@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qpixmap.cpp   3.3.2   edited Feb 11 18:07 $
+** $Id: qt/qpixmap.cpp   3.3.3   edited Jul 27 13:08 $
 **
 ** Implementation of QPixmap class
 **
@@ -128,7 +128,7 @@
 	QPixmap::setDefaultOptimization( QPixmap::NormalOptim );
     \endcode
 
-    In general it is recommended to make as much use of QPixmap's 
+    In general it is recommended to make as much use of QPixmap's
     implicit sharing and the QPixmapCache as possible.
 
     \sa QBitmap, QImage, QImageIO, \link shclass.html Shared Classes\endlink
@@ -164,7 +164,7 @@
     \value NoOptim  No optimization (currently the same as \c
 	MemoryOptim).
 
-    \value MemoryOptim  Optimize for minimal memory use on Windows 
+    \value MemoryOptim  Optimize for minimal memory use on Windows
 	9x and X11 systems.
 
     \value NormalOptim  Optimize for typical usage. Often uses more
@@ -1378,15 +1378,15 @@ bool qt_xForm_helper( const QWMatrix &trueMat, int xoffset,
 	uchar *sptr, int sbpl, int sWidth, int sHeight
 	)
 {
-    int m11 = (int)(trueMat.m11()*65536.0);
-    int m12 = (int)(trueMat.m12()*65536.0);
-    int m21 = (int)(trueMat.m21()*65536.0);
-    int m22 = (int)(trueMat.m22()*65536.0);
-    int dx  = (int)(trueMat.dx() *65536.0);
-    int dy  = (int)(trueMat.dy() *65536.0);
+    int m11 = int(trueMat.m11()*65536.0 + 1.);
+    int m12 = int(trueMat.m12()*65536.0 + 1.);
+    int m21 = int(trueMat.m21()*65536.0 + 1.);
+    int m22 = int(trueMat.m22()*65536.0 + 1.);
+    int dx  = qRound(trueMat.dx() *65536.0);
+    int dy  = qRound(trueMat.dy() *65536.0);
 
-    int m21ydx = dx + (xoffset<<16) + QABS(m11)/2;
-    int m22ydy = dy + QABS(m22)/2;
+    int m21ydx = dx + (xoffset<<16);
+    int m22ydy = dy;
     uint trigx;
     uint trigy;
     uint maxws = sWidth<<16;
