@@ -1,5 +1,5 @@
 /**********************************************************************
-** $Id: qt/qprinter.cpp   3.3.2   edited Mar 23 18:17 $
+** $Id: qt/qprinter.cpp   3.3.3   edited Jul 23 12:05 $
 **
 ** Implementation of QPrinter class
 **
@@ -113,9 +113,10 @@
     Once you start printing, calling newPage() is essential. You will
     probably also need to look at the QPaintDeviceMetrics for the
     printer (see the \link simple-application.html#printersimple print
-    function\endlink in the Application walk-through). Note that the
-    paint device metrics are valid only after the QPrinter has been
-    set up, i.e. after setup() has returned successfully.
+    function\endlink in the Application walk-through). In previous versions,
+    paint device metrics were valid only after the QPrinter has been set
+    up, i.e. after setup() has returned successfully. This is no longer
+    the case and paint device metrics can be requested safely before set up.
 
     If you want to abort the print job, abort() will try its best to
     stop printing. It may cancel the entire job or just some of it.
@@ -124,8 +125,8 @@
     \endomit
 
     If your current locale converts "," to ".", you will need to set
-    a locale that doen't do this (e.g. the "C" locale) before using
-    QPrinter.
+    a locale (via the standard C setlocale() function) that doen't do this
+    before using QPrinter. The "C" locale works well for this.
 
     The TrueType font embedding for Qt's postscript driver uses code
     by David Chappell of Trinity College Computing Center.
