@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qregion.cpp   3.3.2   edited May 27 2003 $
+** $Id: qt/qregion.cpp   3.3.3   edited Jun 1 14:30 $
 **
 ** Implementation of QRegion class
 **
@@ -85,7 +85,7 @@
 
     \warning Due to window system limitations, the whole coordinate
     space for a region is limited to the points between -32767 and
-    32767 on Windows 95/98/ME.
+    32767 on Mac OS X and Windows 95/98/ME.
 
     \sa QPainter::setClipRegion(), QPainter::setClipRect()
 */
