@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qscriptengine.cpp   3.3.2   edited Jan 23 09:30 $
+** $Id: qt/qscriptengine.cpp   3.3.3   edited Aug 3 17:30 $
 **
 ** ???
 **
@@ -559,7 +559,7 @@ static const ushort arabicUnicodeMapping[256][2] = {
     { 0xFEE5, 3 }, // 0x0646    D       NOON
     { 0xFEE9, 3 }, // 0x0647    D       HEH
     { 0xFEED, 1 }, // 0x0648    R       WAW
-    { 0x0649, 0 }, // 0x0649            ALEF MAKSURA // ### Dual, glyphs not consecutive, handle in code.
+    { 0x0649, 3 }, // 0x0649            ALEF MAKSURA // ### Dual, glyphs not consecutive, handle in code.
     { 0xFEF1, 3 }, // 0x064A    D       YEH
     { 0x064B, 0 }, // 0x064B
     { 0x064C, 0 }, // 0x064C
@@ -679,7 +679,7 @@ static const ushort arabicUnicodeMapping[256][2] = {
     { 0x06B7, 0 }, // 0x06B7
     { 0x06B8, 0 }, // 0x06B8
     { 0x06B9, 0 }, // 0x06B9
-    { 0x06BA, 0 }, // 0x06BA
+    { 0xfb9e, 1 }, // 0x06BA    R       NOON GHUNNA
     { 0xFBA0, 3 }, // 0x06BB    D       RNOON
     { 0x06BC, 0 }, // 0x06BC
     { 0x06BD, 0 }, // 0x06BD
@@ -772,6 +772,9 @@ static const ushort arabicUnicodeLamAlefMapping[6][4] = {
 
 static inline int getShape( uchar cell, int shape )
 {
+    if (arabicUnicodeMapping[cell][1] < shape)
+        return 0x600+cell;
+
 #ifdef Q_OS_MAC
     // the arabicUnicodeMapping does not work for U+0649 ALEF MAKSURA, handle this here
     uint ch = ( cell != 0x49 )
@@ -819,7 +822,7 @@ static void shapedString(const QString& uc, int from, int len, QChar *shapeBuffe
 	    uchar c = ch->cell();
 	    int pos = i + from;
 	    int shape = glyphVariantLogical( uc, pos );
-//  	    qDebug("mapping U+%x to shape %d glyph=0x%x", ch->unicode(), shape, getShape(c, shape));
+//   	    qDebug("mapping U+%x to shape %d glyph=0x%x", ch->unicode(), shape, getShape(c, shape));
 	    // take care of lam-alef ligatures (lam right of alef)
 	    ushort map;
 	    switch ( c ) {
