@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qscriptengine_x11.cpp   3.3.2   edited Jan 22 13:44 $
+** $Id: qt/qscriptengine_x11.cpp   3.3.3   edited Apr 30 16:20 $
 **
 ** Continuation of middle eastern languages
 **
@@ -1533,7 +1533,8 @@ static void indic_shape_syllable( int script, const QString &string, int from, i
 
 	openType->applyGSUBFeature(FT_MAKE_TAG( 'c', 'c', 'm', 'p' ));
 
-	where[0] = TRUE;
+	where[0] = (from == 0
+                    || !(string.unicode()[from-1].isLetter() ||  string.unicode()[from-1].isMark()));
 	openType->applyGSUBFeature(FT_MAKE_TAG( 'i', 'n', 'i', 't' ), where);
 	openType->applyGSUBFeature(FT_MAKE_TAG( 'n', 'u', 'k', 't' ));
 
@@ -1720,7 +1721,7 @@ static int indic_nextSyllableBoundary( int script, const QString &s, int start,
 	switch( newState ) {
 	case Control:
 	    newState = state;
-	    if (state == Halant)
+	    if (state == Halant && uc[pos].unicode() == 0x200d /* ZWJ */)
 		break;
 	    goto finish;
 	case Consonant:
@@ -2257,8 +2258,8 @@ static int khmer_nextSyllableBoundary(const QString &s, int start, int end, bool
     KHDEBUG("state[%d]=%d (uc=%4x)", pos, state, uc[pos].unicode() );
     pos++;
 
-    if (state != Khmer_Cons) {
-	if (state != Khmer_IndV && state != Khmer_Other)
+    if (state != Khmer_Cons && state != Khmer_IndV) {
+	if (state != Khmer_Other)
 	    *invalid = TRUE;
 	goto finish;
     }
