@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qsharedmemory_p.h   3.2.1   edited May 13 09:08 $
+** $Id: qt/qsharedmemory_p.h   3.3.3   edited Oct 13 2003 $
 **
 ** Includes system files for shared memory
 **
@@ -45,7 +45,9 @@
 //
 //
 
+#ifndef QT_H
 #include "qstring.h"
+#endif // QT_H
 
 #if !defined (QT_QWS_NO_SHM)
 
