@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qstyle.h   3.3.1   edited Jan 21 09:21 $
+** $Id: qt/qstyle.h   3.3.3   edited Apr 2 14:04 $
 **
 ** Definition of QStyle class
 **
@@ -412,7 +412,11 @@ public:
 				     const QRect &r,
 				     const QColorGroup &cg,
 				     SFlags how = Style_Default,
+#ifdef Q_QDOC
+				     SCFlags sub = SC_All,
+#else
 				     SCFlags sub = (uint)SC_All,
+#endif
 				     SCFlags subActive = SC_None,
 				     const QStyleOption& = QStyleOption::Default ) const = 0;
     virtual void drawComplexControlMask( ComplexControl control,
