@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qtextengine.cpp   3.3.2   edited Nov 29 17:38 $
+** $Id: qt/qtextengine.cpp   3.3.3   edited May 18 17:44 $
 **
 ** Text engine classes
 **
@@ -53,6 +53,7 @@
 #define BIDI_DEBUG 0//2
 #if (BIDI_DEBUG >= 1)
 #include <iostream>
+using namespace std;
 
 static const char *directions[] = {
     "DirL", "DirR", "DirEN", "DirES", "DirET", "DirAN", "DirCS", "DirB", "DirS", "DirWS", "DirON",
@@ -419,7 +420,8 @@ static void bidiItemize( QTextEngine *engine, bool rightToLeft, int mode )
 		case QChar::DirON:
 		    if( status.eor != QChar::DirR && status.eor != QChar::DirAL ) {
 			//last stuff takes embedding dir
-			if(control.direction() == QChar::DirR || status.lastStrong == QChar::DirR) {
+			if(control.direction() == QChar::DirR
+                           || status.lastStrong == QChar::DirR || status.lastStrong == QChar::DirAL) {
 			    appendItems(engine, sor, eor, control, dir);
 			    dir = QChar::DirON; status.eor = QChar::DirON;
 			    dir = QChar::DirR;
@@ -927,9 +929,17 @@ const QCharAttributes *QTextEngine::attributes()
 	QScriptItem &si = items[i];
 	int from = si.position;
 	int len = length( i );
-	int script = si.analysis.script;
+#ifdef Q_WS_WIN
+        int script = uspScriptForItem(this, i);
+        if(script >= QFont::Devanagari && script <= QFont::Khmer)
+            ScriptBreak( (WCHAR *)string.ucs2()+from, len, &si.analysis, charAttributes + from);
+        else
+	    scriptEngines[script].charAttributes( script, string, from, len, charAttributes );
+#else
+        int script = si.analysis.script;
 	Q_ASSERT( script < QFont::NScripts );
-	scriptEngines[si.analysis.script].charAttributes( script, string, from, len, charAttributes );
+	scriptEngines[script].charAttributes( script, string, from, len, charAttributes );
+#endif
     }
 
     calcLineBreaks(string, charAttributes);
