@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qtranslator.cpp   3.3.2   edited Nov 11 18:47 $
+** $Id: qt/qtranslator.cpp   3.3.3   edited May 19 09:11 $
 **
 ** Localization database support.
 **
@@ -364,7 +364,8 @@ extern bool qt_detectRTLLanguage();
 /*!
     Loads \a filename, which may be an absolute file name or relative
     to \a directory. The previous contents of this translator object
-    is discarded.
+    is discarded. Returns TRUE if the file is loaded successfully;
+    otherwise returns FALSE.
 
     If the full file name does not exist, other file names are tried
     in the following order:
@@ -516,7 +517,8 @@ bool QTranslator::load( const QString & filename, const QString & directory,
   \fn bool QTranslator::load( const uchar *data, int len )
 
   Loads the .qm file data \a data of length \a len into the
-  translator.
+  translator. Returns TRUE if the data is loaded successfully;
+  otherwise returns FALSE.
 
   The data is not copied. The caller must be able to guarantee that \a data
   will not be deleted or modified.
@@ -1050,9 +1052,11 @@ QTranslatorMessage QTranslator::findMessage( const char* context,
 bool QTranslator::isEmpty() const
 {
     return !( d->unmapPointer || d->unmapLength || d->messageArray ||
-	      d->offsetArray || d->contextArray || 
-	      (d->messages && d->messages->count())
-	    );
+	      d->offsetArray || d->contextArray
+#ifndef QT_NO_TRANSLATION_BUILDER
+              || (d->messages && d->messages->count())
+#endif
+        );
 }
 
 
