@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qvariant.cpp   3.3.2   edited Mar 2 18:11 $
+** $Id: qt/qvariant.cpp   3.3.3   edited Apr 21 22:19 $
 **
 ** Implementation of QVariant class
 **
 ** Created : 990414
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2004 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -1042,7 +1042,7 @@ const char* QVariant::typeToName( Type typ )
 
 
 /*!
-    Converts the string representation of the storage type gven in \a
+    Converts the string representation of the storage type given in \a
     name, to its enum representation.
 
     If the string representation cannot be converted to any enum
