@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qwidget_x11.cpp   3.3.2   edited Mar 4 16:04 $
+** $Id: qt/qwidget_x11.cpp   3.3.3   edited Jul 27 15:45 $
 **
 ** Implementation of QWidget and QWindow classes for X11
 **
@@ -629,16 +629,22 @@ void QWidget::create( WId window, bool initializeWindow, bool destroyOldWindow)
         if ( mwmhints.flags != 0l )
             XChangeProperty(dpy, id, qt_xa_motif_wm_hints, qt_xa_motif_wm_hints, 32,
                             PropModeReplace, (unsigned char *) &mwmhints, 5);
+        else
+            XDeleteProperty(dpy, id, qt_xa_motif_wm_hints);
 
 	// set _NET_WM_WINDOW_TYPE
 	if (curr_wintype > 0)
 	    XChangeProperty(dpy, id, qt_net_wm_window_type, XA_ATOM, 32, PropModeReplace,
 			    (unsigned char *) net_wintypes, curr_wintype);
+        else
+            XDeleteProperty(dpy, id, qt_net_wm_window_type);
 
 	// set _NET_WM_WINDOW_STATE
 	if (curr_winstate > 0)
 	    XChangeProperty(dpy, id, qt_net_wm_state, XA_ATOM, 32, PropModeReplace,
 			    (unsigned char *) net_winstates, curr_winstate);
+        else
+            XDeleteProperty(dpy, id, qt_net_wm_state);
 
 	// set _NET_WM_PID
 	long curr_pid = getpid();
@@ -846,7 +852,17 @@ void QWidget::reparentSys( QWidget *parent, WFlags f, const QPoint &p, bool show
     else
 	XSetWindowBackground( dpy, winid, bgc.pixel(x11Screen()) );
 
-    setGeometry( p.x(), p.y(), s.width(), s.height() );
+    if (isTopLevel()) {
+        // preserve maximized/fullscreen flags and the normal geometry
+        uint save_state = widget_state & (WState_Maximized | WState_FullScreen);
+        const QRect r = topData()->normalGeometry;
+        setGeometry(p.x(), p.y(), s.width(), s.height());
+        widget_state |= save_state;
+        topData()->normalGeometry = r;
+    } else {
+        setGeometry(p.x(), p.y(), s.width(), s.height());
+    }
+
     setEnabled( enable );
     setFocusPolicy( fp );
     if ( !capt.isNull() ) {
@@ -1169,9 +1185,10 @@ void QWidget::setIcon( const QPixmap &pixmap )
 
 void QWidget::setIconText( const QString &iconText )
 {
-    createTLExtra();
-    extra->topextra->iconText = iconText;
-    XSetIconName( x11Display(), winId(), iconText.utf8() );
+    if (QWidget::iconText() == iconText)
+        return;
+
+    topData()->iconText = iconText;
     XSetWMIconName( x11Display(), winId(), qstring_to_xtp(iconText) );
 
     QCString net_wm_icon_name = iconText.utf8();
@@ -1625,29 +1642,33 @@ void QWidget::setWindowState(uint newstate)
     bool needShow = FALSE;
     uint oldstate = windowState();
     if (isTopLevel()) {
+        QTLWExtra *top = topData();
+
 	if ((oldstate & WindowMaximized) != (newstate & WindowMaximized)) {
 	    if (qt_net_supports(qt_net_wm_state_max_h) && qt_net_supports(qt_net_wm_state_max_v)) {
 		qt_net_change_wm_state(this, (newstate & WindowMaximized),
 				       qt_net_wm_state_max_h, qt_net_wm_state_max_v);
-	    } else {
+	    } else if (! (newstate & WindowFullScreen)) {
 		if (newstate & WindowMaximized) {
-		    QTLWExtra *top = topData();
-
 		    // save original geometry
-		    if (top->normalGeometry.width() < 0)
-			top->normalGeometry = geometry();
+                    const QRect normalGeometry = geometry();
 
 		    if (isVisible()) {
 			updateFrameStrut();
-			QRect maxRect = QApplication::desktop()->availableGeometry(this);
+			const QRect maxRect = QApplication::desktop()->availableGeometry(this);
+			const QRect r = top->normalGeometry;
 			setGeometry(maxRect.x() + top->fleft,
 				    maxRect.y() + top->ftop,
 				    maxRect.width() - top->fleft - top->fright,
 				    maxRect.height() - top->ftop - top->fbottom);
+                        top->normalGeometry = r;
 		    }
+
+                    if (top->normalGeometry.width() < 0)
+			top->normalGeometry = normalGeometry;
 		} else {
 		    // restore original geometry
-		    setGeometry(topData()->normalGeometry);
+		    setGeometry(top->normalGeometry);
 		}
 	    }
 	}
@@ -1657,28 +1678,39 @@ void QWidget::setWindowState(uint newstate)
 		qt_net_change_wm_state(this, (newstate & WindowFullScreen),
 				       qt_net_wm_state_fullscreen);
 	    } else {
-		needShow = isVisible();
+                needShow = isVisible();
 
 		if (newstate & WindowFullScreen) {
-		    if ( topData()->normalGeometry.width() < 0 )
-			topData()->normalGeometry = QRect( pos(), size() );
-		    topData()->savedFlags = getWFlags();
-		    reparent(0, WType_TopLevel | WStyle_Customize | WStyle_NoBorder |
+                    const QRect normalGeometry = QRect(pos(), size());
+
+		    top->savedFlags = getWFlags();
+                    reparent(0, WType_TopLevel | WStyle_Customize | WStyle_NoBorder |
 			     // preserve some widget flags
 			     (getWFlags() & 0xffff0000),
 			     mapToGlobal(QPoint(0, 0)));
-		    QRect r = qApp->desktop()->screenGeometry(this);
-		    move( r.topLeft() );
-		    resize( r.size() );
-		} else {
-		    reparent( 0, topData()->savedFlags, QPoint(0,0) );
-		    QRect r = topData()->normalGeometry;
-		    if ( r.width() >= 0 ) {
-			// the widget has been maximized
-			topData()->normalGeometry = QRect(0,0,-1,-1);
-			move( r.topLeft() );
-			resize( r.size() );
-		    }
+                    const QRect r = top->normalGeometry;
+                    setGeometry(qApp->desktop()->screenGeometry(this));
+                    top->normalGeometry = r;
+
+                    if ( top->normalGeometry.width() < 0 )
+			top->normalGeometry = normalGeometry;
+                } else {
+		    reparent( 0, top->savedFlags, mapToGlobal(QPoint(0, 0)) );
+
+                    if (newstate & WindowMaximized) {
+                        // from fullscreen to maximized
+			updateFrameStrut();
+			const QRect maxRect = QApplication::desktop()->availableGeometry(this);
+			const QRect r = top->normalGeometry;
+			setGeometry(maxRect.x() + top->fleft,
+				    maxRect.y() + top->ftop,
+				    maxRect.width() - top->fleft - top->fright,
+				    maxRect.height() - top->ftop - top->fbottom);
+                        top->normalGeometry = r;
+                    } else {
+                        // restore original geometry
+                        setGeometry(top->normalGeometry);
+                    }
 		}
 	    }
 	}
@@ -1946,8 +1978,11 @@ void QWidget::internalSetGeometry( int x, int y, int w, int h, bool isMove )
 
     if ( testWFlags(WType_Desktop) )
 	return;
-    clearWState(WState_Maximized);
-    clearWState(WState_FullScreen);
+    if (!qt_net_supports(qt_net_wm_state_max_h)
+        && !qt_net_supports(qt_net_wm_state_max_v))
+        clearWState(WState_Maximized);
+    if (!qt_net_supports(qt_net_wm_state_fullscreen))
+        clearWState(WState_FullScreen);
     if (isTopLevel())
 	topData()->normalGeometry = QRect(0, 0, -1, -1);
     if ( extra ) {				// any size restrictions?
