@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qftp.cpp   3.3.2   edited Jan 12 16:35 $
+** $Id: qt/qftp.cpp   3.3.3   edited Jul 31 23:18 $
 **
 ** Implementation of QFtp class.
 **
@@ -40,6 +40,7 @@
 #ifndef QT_NO_NETWORKPROTOCOL_FTP
 
 #include "qsocket.h"
+#include "qsocketdevice.h"
 #include "qurlinfo.h"
 #include "qurloperator.h"
 #include "qstringlist.h"
@@ -48,6 +49,10 @@
 #include "qfileinfo.h"
 #include "qptrdict.h" // binary compatibility
 
+#ifndef QT_NO_TEXTCODEC
+#include "qtextcodec.h"
+#endif
+
 //#define QFTPPI_DEBUG
 //#define QFTPDTP_DEBUG
 
@@ -465,6 +470,7 @@ bool QFtpDTP::parseDir( const QString &buffer, const QString &userName, QUrlInfo
     QTime time;
     QString dateStr;
     dateStr += "Sun ";
+    lst[ 5 ][ 0 ] = lst[ 5 ][ 0 ].upper();
     dateStr += lst[ 5 ];
     dateStr += ' ';
     dateStr += lst[ 6 ];
@@ -506,6 +512,15 @@ bool QFtpDTP::parseDir( const QString &buffer, const QString &userName, QUrlInfo
 
 void QFtpDTP::socketConnected()
 {
+#if !defined (Q_WS_QWS)
+    // Use a large send buffer to reduce the number
+    // of writeBlocks when download and uploading files.
+    // The actual size used here (128k) is default on most
+    // Unixes.
+    socket.socketDevice()->setSendBufferSize(128 * 1024);
+    socket.socketDevice()->setReceiveBufferSize(128 * 1024);
+#endif
+
     bytesDone = 0;
 #if defined(QFTPDTP_DEBUG)
     qDebug( "QFtpDTP::connectState( CsConnected )" );
@@ -916,6 +931,10 @@ bool QFtpPI::processReply()
     return TRUE;
 }
 
+#ifndef QT_NO_TEXTCODEC
+QTextCodec *qt_ftp_filename_codec = 0;
+#endif
+
 /*
   Starts next pending command. Returns FALSE if there are no pending commands,
   otherwise it returns TRUE.
@@ -941,7 +960,16 @@ bool QFtpPI::startNextCmd()
     qDebug( "QFtpPI send: %s", currentCmd.left( currentCmd.length()-2 ).latin1() );
 #endif
     state = Waiting;
-    commandSocket.writeBlock( currentCmd.latin1(), currentCmd.length() );
+#ifndef QT_NO_TEXTCODEC
+    if ( qt_ftp_filename_codec ) {
+	int len;
+	QCString enc = qt_ftp_filename_codec->fromUnicode(currentCmd,len);
+	commandSocket.writeBlock( enc.data(), len );
+    } else
+#endif
+    {
+	commandSocket.writeBlock( currentCmd.latin1(), currentCmd.length() );
+    }
     return TRUE;
 }
 
@@ -1533,7 +1561,7 @@ int QFtp::cd( const QString &dir )
     of the operation (it is safe to delete it when the
     commandFinished() signal is emitted). In this case the readyRead()
     signal is \e not emitted and you cannot read data with the
-    readBlcok or readAll() functions.
+    readBlock() or readAll() functions.
 
     If you don't read the data immediately it becomes available, i.e.
     when the readyRead() signal is emitted, it is still available
