@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qsocket.cpp   3.3.2   edited Mar 30 11:45 $
+** $Id: qt/qsocket.cpp   3.3.3   edited Jul 26 14:19 $
 **
 ** Implementation of QSocket class.
 **
@@ -201,7 +201,7 @@ void QSocketPrivate::setSocketDevice( QSocket *q, QSocketDevice *device )
     if ( device ) {
 	socket = device;
     } else {
-	socket = new QSocketDevice( QSocketDevice::Stream, 
+	socket = new QSocketDevice( QSocketDevice::Stream,
 				    ( addr.isIPv4Address() ?
 				      QSocketDevice::IPv4 :
 				      QSocketDevice::IPv6 ), 0 );
@@ -1386,9 +1386,12 @@ void QSocket::setSocketIntern( int socket )
 	clearPendingData();
         close();
     }
+    Q_ULONG oldBufferSize = d ? d->readBufferSize : 0;
     delete d;
 
     d = new QSocketPrivate;
+    if (oldBufferSize)
+        d->readBufferSize = oldBufferSize;
     if ( socket >= 0 ) {
 	QSocketDevice *sd = new QSocketDevice( socket, QSocketDevice::Stream );
 	sd->setBlocking( FALSE );
