@@ -35,14 +35,50 @@
 **********************************************************************/
 
 #include "qsql_mysql.h"
+#include <private/qsqlextension_p.h>
 
 #include <qdatetime.h>
-#include <qmap.h>
+#include <qvaluevector.h>
 #include <qsqlrecord.h>
-#include <qregexp.h>
 
 #define QMYSQL_DRIVER_NAME "QMYSQL3"
 
+#ifdef Q_OS_WIN32
+// comment the next line out if you want to use MySQL/embedded on Win32 systems.
+// note that it will crash if you don't statically link to the mysql/e library!
+# define Q_NO_MYSQL_EMBEDDED
+#endif
+
+QPtrDict<QSqlOpenExtension> *qSqlOpenExtDict();
+
+class QMYSQLOpenExtension : public QSqlOpenExtension
+{
+public:
+    QMYSQLOpenExtension( QMYSQLDriver *dri )
+	: QSqlOpenExtension(), driver(dri) {}
+    ~QMYSQLOpenExtension() {}
+
+    bool open( const QString& db,
+	       const QString& user,
+	       const QString& password,
+	       const QString& host,
+	       int port,
+	       const QString& connOpts );
+    
+private:
+    QMYSQLDriver *driver;
+};
+
+bool QMYSQLOpenExtension::open( const QString& db,
+				const QString& user,
+				const QString& password,
+				const QString& host,
+				int port,
+				const QString& connOpts )
+{
+    return driver->open( db, user, password, host, port, connOpts );
+}
+
 class QMYSQLDriverPrivate
 {
 public:
@@ -56,15 +92,15 @@ public:
     QMYSQLResultPrivate() : QMYSQLDriverPrivate(), result(0) {}
     MYSQL_RES* result;
     MYSQL_ROW  row;
-    QMap< int, int > fieldTypes;
+    QValueVector<QVariant::Type> fieldTypes;
 };
 
 QSqlError qMakeError( const QString& err, int type, const QMYSQLDriverPrivate* p )
 {
-    return QSqlError(QMYSQL_DRIVER_NAME ": " + err, QString(mysql_error( p->mysql )), type);
+    return QSqlError(QMYSQL_DRIVER_NAME ": " + err, QString(mysql_error( p->mysql )), type, mysql_errno( p->mysql ));
 }
 
-QVariant::Type qDecodeMYSQLType( int mysqltype )
+QVariant::Type qDecodeMYSQLType( int mysqltype, uint flags )
 {
     QVariant::Type type;
     switch ( mysqltype ) {
@@ -72,10 +108,14 @@ QVariant::Type qDecodeMYSQLType( int mysqltype )
     case FIELD_TYPE_SHORT :
     case FIELD_TYPE_LONG :
     case FIELD_TYPE_INT24 :
-    case FIELD_TYPE_LONGLONG :
+	type = (flags & UNSIGNED_FLAG) ? QVariant::UInt : QVariant::Int;
+	break;
     case FIELD_TYPE_YEAR :
 	type = QVariant::Int;
 	break;
+    case FIELD_TYPE_LONGLONG :
+	type = (flags & UNSIGNED_FLAG) ? QVariant::ULongLong : QVariant::LongLong;
+	break;
     case FIELD_TYPE_DECIMAL :
     case FIELD_TYPE_FLOAT :
     case FIELD_TYPE_DOUBLE :
@@ -95,7 +135,7 @@ QVariant::Type qDecodeMYSQLType( int mysqltype )
     case FIELD_TYPE_TINY_BLOB :
     case FIELD_TYPE_MEDIUM_BLOB :
     case FIELD_TYPE_LONG_BLOB :
-	type = QVariant::ByteArray;
+	type = (flags & BINARY_FLAG) ? QVariant::ByteArray : QVariant::CString;
 	break;
     default:
     case FIELD_TYPE_ENUM :
@@ -141,8 +181,8 @@ bool QMYSQLResult::fetch( int i )
 {
     if ( isForwardOnly() ) { // fake a forward seek
 	if ( at() < i ) {
-	    int x = i;
-	    while ( x-- && fetchNext() );
+	    int x = i - at();
+	    while ( --x && fetchNext() );
 	    return fetchNext();
 	} else {
 	    return FALSE;
@@ -194,20 +234,18 @@ QVariant QMYSQLResult::data( int field )
 	return QVariant();
     }
     
-    QString val( ( d->row[field] ) );
-    QVariant::Type type = qDecodeMYSQLType( d->fieldTypes[ field ] );
-    switch ( type ) {
+    QString val( d->row[field] );
+    switch ( d->fieldTypes.at( field ) ) {
+    case QVariant::LongLong:
+	return QVariant( val.toLongLong() );
+    case QVariant::ULongLong:
+	return QVariant( val.toULongLong() );
     case QVariant::Int: 
-	if ( d->fieldTypes[ field ] == FIELD_TYPE_LONGLONG )
-	    // keep these as strings so that we don't loose precision
-	    return QVariant( val );
 	return QVariant( val.toInt() );
+    case QVariant::UInt:
+	return QVariant( val.toUInt() );
     case QVariant::Double:
-	if ( d->fieldTypes[ field ] == FIELD_TYPE_DECIMAL )
-	    // keep these as strings so that we don't loose precision
-	    return QVariant( val );
 	return QVariant( val.toDouble() );
-	return QVariant( val );
     case QVariant::Date:
 	if ( val.isEmpty() ) {
 	    return QVariant( QDate() );
@@ -221,20 +259,14 @@ QVariant QMYSQLResult::data( int field )
 	    return QVariant( QTime::fromString( val, Qt::ISODate ) );
 	}
     case QVariant::DateTime:
-	if ( d->fieldTypes[ field ] == FIELD_TYPE_TIMESTAMP ) {
+	if ( val.isEmpty() )
+	    return QVariant( QDateTime() );
+	if ( val.length() == 14u )
 	    // TIMESTAMPS have the format yyyyMMddhhmmss
 	    val.insert(4, "-").insert(7, "-").insert(10, 'T').insert(13, ':').insert(16, ':');
-	}
-	if ( val.isEmpty() ) {
-	    return QVariant( QDateTime() );
-	} else {
-	    return QVariant( QDateTime::fromString( val, Qt::ISODate ) );
-	}
+	return QVariant( QDateTime::fromString( val, Qt::ISODate ) );
     case QVariant::ByteArray: {
-	MYSQL_FIELD* f = mysql_fetch_field_direct( d->result, field );
-	if ( ! ( f->flags & BLOB_FLAG ) )
-	    return QVariant( QByteArray() );
-	unsigned long * fl = mysql_fetch_lengths( d->result );
+	unsigned long* fl = mysql_fetch_lengths( d->result );
 	QByteArray ba;
 	ba.duplicate( d->row[field], fl[field] );
 	return QVariant( ba );
@@ -281,11 +313,14 @@ bool QMYSQLResult::reset ( const QString& query )
     }
     int numFields = mysql_field_count( d->mysql );
     setSelect( !( numFields == 0) );
-    d->fieldTypes.clear();
+    d->fieldTypes.resize( numFields );
     if ( isSelect() ) {
 	for( int i = 0; i < numFields; i++) {
 	    MYSQL_FIELD* field = mysql_fetch_field_direct( d->result, i );
-	    d->fieldTypes[i] = field->type;
+	    if ( field->type == FIELD_TYPE_DECIMAL )
+		d->fieldTypes[i] = QVariant::String;
+	    else
+		d->fieldTypes[i] = qDecodeMYSQLType( field->type, field->flags );
 	}
     }
     setActive( TRUE );
@@ -304,14 +339,54 @@ int QMYSQLResult::numRowsAffected()
 
 /////////////////////////////////////////////////////////
 
+static void qServerInit()
+{
+#ifndef Q_NO_MYSQL_EMBEDDED
+# if MYSQL_VERSION_ID >= 40000
+    static bool init = FALSE;
+    if ( init )
+	return;
+
+    // this should only be called once
+    // has no effect on client/server library
+    // but is vital for the embedded lib
+    if ( mysql_server_init( 0, 0, 0 ) ) {
+#  ifdef QT_CHECK_RANGE
+	qWarning( "QMYSQLDriver::qServerInit: unable to start server." );
+#  endif
+    }
+    init = TRUE;    
+# endif // MYSQL_VERSION_ID
+#endif // Q_NO_MYSQL_EMBEDDED
+}
+
 QMYSQLDriver::QMYSQLDriver( QObject * parent, const char * name )
-: QSqlDriver(parent, name ? name : QMYSQL_DRIVER_NAME)
+    : QSqlDriver( parent, name ? name : QMYSQL_DRIVER_NAME )
 {
     init();
+    qServerInit();
+}
+
+/*!
+    Create a driver instance with an already open connection handle.
+*/
+
+QMYSQLDriver::QMYSQLDriver( MYSQL * con, QObject * parent, const char * name )
+    : QSqlDriver( parent, name ? name : QMYSQL_DRIVER_NAME )
+{
+    init();
+    if ( con ) {
+	d->mysql = (MYSQL *) con;
+	setOpen( TRUE );
+	setOpenError( FALSE );
+    } else {
+	qServerInit();
+    }
 }
 
 void QMYSQLDriver::init()
 {
+    qSqlOpenExtDict()->insert( this, new QMYSQLOpenExtension(this) );
     d = new QMYSQLDriverPrivate();
     d->mysql = 0;
 }
@@ -319,6 +394,15 @@ void QMYSQLDriver::init()
 QMYSQLDriver::~QMYSQLDriver()
 {
     delete d;
+    if ( !qSqlOpenExtDict()->isEmpty() ) {
+	QSqlOpenExtension *ext = qSqlOpenExtDict()->take( this );
+	delete ext;
+    }
+#ifndef Q_NO_MYSQL_EMBEDDED
+# if MYSQL_VERSION_ID > 40000
+    mysql_server_end();
+# endif
+#endif
 }
 
 bool QMYSQLDriver::hasFeature( DriverFeature f ) const
@@ -344,23 +428,77 @@ bool QMYSQLDriver::hasFeature( DriverFeature f ) const
     }
 }
 
-bool QMYSQLDriver::open( const QString & db,
-			 const QString & user,
-			 const QString & password,
-			 const QString & host,
-			 int port  )
+bool QMYSQLDriver::open( const QString&,
+			 const QString&,
+			 const QString&,
+			 const QString&,
+			 int )
+{
+    qWarning("QMYSQLDriver::open(): This version of open() is no longer supported." );
+    return FALSE;
+}
+
+bool QMYSQLDriver::open( const QString& db,
+			 const QString& user,
+			 const QString& password,
+			 const QString& host,
+			 int port,
+			 const QString& connOpts )
 {
     if ( isOpen() )
 	close();
+ 
+    unsigned int optionFlags = 0;
+    
+    QStringList raw = QStringList::split( ';', connOpts );
+    QStringList opts;
+    QStringList::ConstIterator it;
+    
+    // extract the real options from the string
+    for ( it = raw.begin(); it != raw.end(); ++it ) {
+	QString tmp( *it );
+	int idx;
+	if ( (idx = tmp.find( '=' )) != -1 ) {
+	    QString val( tmp.mid( idx + 1 ) );
+	    val.simplifyWhiteSpace();
+	    if ( val == "TRUE" || val == "1" )
+		opts << tmp.left( idx );
+	    else
+		qWarning( "QMYSQLDriver::open: Illegal connect option value '%s'", tmp.latin1() );
+	} else {
+	    opts << tmp;
+	}
+    }
+    
+    for ( it = opts.begin(); it != opts.end(); ++it ) {
+	QString opt( (*it).upper() );
+	if ( opt == "CLIENT_COMPRESS" )
+	    optionFlags |= CLIENT_COMPRESS;
+	else if ( opt == "CLIENT_FOUND_ROWS" )
+	    optionFlags |= CLIENT_FOUND_ROWS;
+	else if ( opt == "CLIENT_IGNORE_SPACE" )
+	    optionFlags |= CLIENT_IGNORE_SPACE;
+	else if ( opt == "CLIENT_INTERACTIVE" )
+	    optionFlags |= CLIENT_INTERACTIVE;
+	else if ( opt == "CLIENT_NO_SCHEMA" )
+	    optionFlags |= CLIENT_NO_SCHEMA;
+	else if ( opt == "CLIENT_ODBC" )
+	    optionFlags |= CLIENT_ODBC;
+	else if ( opt == "CLIENT_SSL" )
+	    optionFlags |= CLIENT_SSL;
+	else 
+	    qWarning( "QMYSQLDriver::open: Unknown connect option '%s'", (*it).latin1() );
+    }
+
     if ( (d->mysql = mysql_init((MYSQL*) 0)) &&
 	    mysql_real_connect( d->mysql,
 				host,
 				user,
 				password,
-				db,
+				db.isNull() ? QString("") : db,
 				(port > -1) ? port : 0,
 				NULL,
-				0))
+				optionFlags ) )
     {
 	if ( mysql_select_db( d->mysql, db )) {
 	    setLastError( qMakeError("Unable open database '" + db + "'", QSqlError::Connection, d ) );
@@ -370,7 +508,8 @@ bool QMYSQLDriver::open( const QString & db,
 	}
     } else {
 	    setLastError( qMakeError( "Unable to connect", QSqlError::Connection, d ) );
-	    mysql_close( d->mysql ) ;
+	    mysql_close( d->mysql );
+	    setOpenError( TRUE );
 	    return FALSE;
     }
     setOpen( TRUE );
@@ -392,11 +531,14 @@ QSqlQuery QMYSQLDriver::createQuery() const
     return QSqlQuery( new QMYSQLResult( this ) );
 }
 
-QStringList QMYSQLDriver::tables( const QString& ) const
+QStringList QMYSQLDriver::tables( const QString& typeName ) const
 {
     QStringList tl;
     if ( !isOpen() )
 	return tl;
+    if ( !typeName.isEmpty() && !(typeName.toInt() & (int)QSql::Tables) )
+	return tl;
+
     MYSQL_RES* tableRes = mysql_list_tables( d->mysql, NULL );
     MYSQL_ROW	row;
     int i = 0;
@@ -420,7 +562,7 @@ QSqlIndex QMYSQLDriver::primaryIndex( const QString& tablename ) const
     QSqlQuery i = createQuery();
     QString stmt( "show index from %1;" );
     QSqlRecord fil = record( tablename );
-    i.exec( stmt.arg( tablename.lower() ) );
+    i.exec( stmt.arg( tablename ) );
     while ( i.isActive() && i.next() ) {
 	if ( i.value(2).toString() == "PRIMARY" ) {
 	    idx.append( *fil.field( i.value(4).toString() ) );
@@ -436,13 +578,13 @@ QSqlRecord QMYSQLDriver::record( const QString& tablename ) const
     QSqlRecord fil;
     if ( !isOpen() )
 	return fil;
-    MYSQL_RES* r = mysql_list_fields( d->mysql, tablename.lower().local8Bit().data(), 0);
+    MYSQL_RES* r = mysql_list_fields( d->mysql, tablename.local8Bit().data(), 0);
     if ( !r ) {
 	return fil;
     }
     MYSQL_FIELD* field;
     while ( (field = mysql_fetch_field( r ))) {
-	QSqlField f ( QString( field->name ) , qDecodeMYSQLType( (int)field->type ) );
+	QSqlField f ( QString( field->name ) , qDecodeMYSQLType( (int)field->type, field->flags ) );
 	fil.append ( f );
     }
     mysql_free_result( r );
@@ -454,14 +596,14 @@ QSqlRecord QMYSQLDriver::record( const QSqlQuery& query ) const
     QSqlRecord fil;
     if ( !isOpen() )
 	return fil;
-    if ( query.isActive() && query.driver() == this ) {
+    if ( query.isActive() && query.isSelect() && query.driver() == this ) {
 	QMYSQLResult* result =  (QMYSQLResult*)query.result();
 	QMYSQLResultPrivate* p = result->d;
 	if ( !mysql_errno( p->mysql ) ) {
 	    for ( ;; ) {
 		MYSQL_FIELD* f = mysql_fetch_field( p->result );
 		if ( f ) {
-		    QSqlField fi( QString((const char*)f->name), qDecodeMYSQLType( f->type ) );
+		    QSqlField fi( QString((const char*)f->name), qDecodeMYSQLType( f->type, f->flags ) );
 		    fil.append( fi  );
 		} else
 		    break;
@@ -477,14 +619,14 @@ QSqlRecordInfo QMYSQLDriver::recordInfo( const QString& tablename ) const
     QSqlRecordInfo info;
     if ( !isOpen() )
 	return info;
-    MYSQL_RES* r = mysql_list_fields( d->mysql, tablename.lower().local8Bit().data(), 0);
+    MYSQL_RES* r = mysql_list_fields( d->mysql, tablename.local8Bit().data(), 0);
     if ( !r ) {
 	return info;
     }
     MYSQL_FIELD* field;
     while ( (field = mysql_fetch_field( r ))) {
 	info.append ( QSqlFieldInfo( QString( field->name ),
-				qDecodeMYSQLType( (int)field->type ),
+				qDecodeMYSQLType( (int)field->type, field->flags ),
 				IS_NOT_NULL( field->flags ),
 				(int)field->length,
 				(int)field->decimals,
@@ -500,7 +642,7 @@ QSqlRecordInfo QMYSQLDriver::recordInfo( const QSqlQuery& query ) const
     QSqlRecordInfo info;
     if ( !isOpen() )
 	return info;
-    if ( query.isActive() && query.driver() == this ) {
+    if ( query.isActive() && query.isSelect() && query.driver() == this ) {
 	QMYSQLResult* result =  (QMYSQLResult*)query.result();
 	QMYSQLResultPrivate* p = result->d;
 	if ( !mysql_errno( p->mysql ) ) {
@@ -508,7 +650,7 @@ QSqlRecordInfo QMYSQLDriver::recordInfo( const QSqlQuery& query ) const
 		MYSQL_FIELD* field = mysql_fetch_field( p->result );
 		if ( field ) {
 		    info.append ( QSqlFieldInfo( QString( field->name ),
-				qDecodeMYSQLType( (int)field->type ),
+				qDecodeMYSQLType( (int)field->type, field->flags ),
 				IS_NOT_NULL( field->flags ),
 				(int)field->length,
 				(int)field->decimals,
@@ -596,7 +738,7 @@ QString QMYSQLDriver::formatValue( const QSqlField* field, bool trimStrings ) co
 	    // buffer has to be at least length*2+1 bytes
 	    char* buffer = new char[ ba.size() * 2 + 1 ];
 	    /*uint escapedSize =*/ mysql_escape_string( buffer, ba.data(), ba.size() );
-            r = QString( "'%1'" ).arg( buffer );
+	    r.append("'").append(buffer).append("'");
 	    delete[] buffer;
 	}
 	break;
