@@ -1877,7 +1877,9 @@ QSqlIndex QODBCDriver::primaryIndex( const QString& tablename ) const
 	    cName = qGetStringData( hStmt, 3, -1, isNull, d->unicode ); // column name
 	    idxName = qGetStringData( hStmt, 5, -1, isNull, d->unicode ); // pk index name
 	}
-	index.append( *(rec.field( cName )) );
+        QSqlField *fld = rec.field(cName);
+        if (fld)
+	    index.append(*fld);
 	index.setName( idxName );
 	r = SQLFetchScroll( hStmt,
 			    SQL_FETCH_NEXT,
