@@ -740,16 +740,25 @@ QStringList QPSQLDriver::tables( const QString& typeName ) const
     t.setForwardOnly( TRUE );
 
     if ( typeName.isEmpty() || ((type & (int)QSql::Tables) == (int)QSql::Tables) ) {
-        t.exec( "select relname from pg_class where ( relkind = 'r' ) "
-                "and ( relname !~ '^Inv' ) "
-                "and ( relname !~ '^pg_' ) " );
+
+        QString query("select relname from pg_class where (relkind = 'r') "
+                      "and (relname !~ '^Inv') "
+                      "and (relname !~ '^pg_') ");
+        if (pro >= QPSQLDriver::Version73)
+            query.append("and (relnamespace not in "
+                         "(select oid from pg_namespace where nspname = 'information_schema')) ");
+        t.exec(query);
 	while ( t.next() )
 	    tl.append( t.value(0).toString() );
     }
     if ( (type & (int)QSql::Views) == (int)QSql::Views ) {
-        t.exec( "select relname from pg_class where ( relkind = 'v' ) "
+        QString query("select relname from pg_class where ( relkind = 'v' ) "
                 "and ( relname !~ '^Inv' ) "
-                "and ( relname !~ '^pg_' ) " );
+                "and ( relname !~ '^pg_' ) ");
+        if (pro >= QPSQLDriver::Version73)
+            query.append("and (relnamespace not in "
+                         "(select oid from pg_namespace where nspname = 'information_schema')) ");
+        t.exec(query);
 	while ( t.next() )
 	    tl.append( t.value(0).toString() );
     }
