@@ -83,7 +83,7 @@ public:
 
     uint skippedStatus: 1; // the status of the fetchNext() that's skipped
     QtSqlCachedResult::RowCache *skipRow;
-    
+
     uint utf8: 1;
     QSqlRecordInfo rInf;
 };
@@ -237,7 +237,7 @@ bool QSQLiteResult::reset (const QString& query)
     setSelect(FALSE);
     char *err = 0;
     int res = sqlite_compile(d->access,
-                                d->utf8 ? query.utf8() : query.local8Bit(),
+                                d->utf8 ? (const char*)query.utf8().data() : query.ascii(),
                                 &(d->currentTail),
                                 &(d->currentMachine),
                                 &err);
