@@ -720,25 +720,22 @@ void QDataBrowser::update()
     QSql::Confirm conf = QSql::Yes;
     switch ( d->dat.mode() ){
     case QSql::Insert:
-	if ( autoEdit() ) {
-	    if ( confirmInsert() )
-		conf = confirmEdit( QSql::Insert );
-	    switch ( conf ) {
+	if ( confirmInsert() )
+	    conf = confirmEdit( QSql::Insert );		
+	switch ( conf ) {
 	    case QSql::Yes:
 		if ( insertCurrent() )
 		    d->dat.setMode( QSql::Update );
-		break;
+	    break;
 	    case QSql::No:
 		d->dat.setMode( QSql::Update );
-		cur->editBuffer( TRUE );
-		readFields();
-		break;
-	    case QSql::Cancel:
-		break;
-	    }
-	} else
+	    cur->editBuffer( TRUE );
 	    readFields();
-	break;
+	    break;
+	    case QSql::Cancel:
+	    break;
+	}
+    break;
     default:
 	d->dat.setMode( QSql::Update );
 	if ( confirmUpdate() )
@@ -765,7 +762,7 @@ void QDataBrowser::update()
     The current form's record is deleted from the database, providing
     that the data browser is not in insert mode. If the data browser
     is actively inserting a record (see insert()), the insert action
-    is cancelled, and the browser navigates to the last valid record
+    is canceled, and the browser navigates to the last valid record
     that was current. If there is an error, handleError() is called.
 */
 
