@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qmotifplusstyle.h   3.3.1   edited Jan 21 09:57 $
+** $Id: qt/qmotifplusstyle.h   3.3.3   edited Apr 2 14:20 $
 **
 ** Definition of QMotifPlusStyle class
 **
@@ -89,7 +89,11 @@ public:
 			    const QRect &r,
 			    const QColorGroup &cg,
 			    SFlags how = Style_Default,
+#ifdef Q_QDOC
+			    SCFlags controls = SC_All,
+#else
 			    SCFlags controls = (uint)SC_All,
+#endif
 			    SCFlags active = SC_None,
 			    const QStyleOption& = QStyleOption::Default ) const;
 
