@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qmotifstyle.h   3.3.1   edited Jan 21 09:57 $
+** $Id: qt/qmotifstyle.h   3.3.3   edited Apr 2 14:14 $
 **
 ** Definition of Motif-like style class
 **
@@ -91,7 +91,11 @@ public:
 			     const QRect& r,
 			     const QColorGroup& cg,
 			     SFlags how = Style_Default,
+#ifdef Q_QDOC
+			     SCFlags sub = SC_All,
+#else
 			     SCFlags sub = (uint)SC_All,
+#endif
 			     SCFlags subActive = SC_None,
 			     const QStyleOption& = QStyleOption::Default ) const;
 
