@@ -38,16 +38,16 @@
 #define QTABLE_H
 
 #ifndef QT_H
-#include <qscrollview.h>
-#include <qpixmap.h>
-#include <qptrvector.h>
-#include <qheader.h>
-#include <qmemarray.h>
-#include <qptrlist.h>
-#include <qguardedptr.h>
-#include <qshared.h>
-#include <qintdict.h>
-#include <qstringlist.h>
+#include "qscrollview.h"
+#include "qpixmap.h"
+#include "qptrvector.h"
+#include "qheader.h"
+#include "qmemarray.h"
+#include "qptrlist.h"
+#include "qguardedptr.h"
+#include "qshared.h"
+#include "qintdict.h"
+#include "qstringlist.h"
 #endif // QT_H
 
 
@@ -93,8 +93,11 @@ public:
     int rightCol() const { return rCol; }
     int anchorRow() const { return aRow; }
     int anchorCol() const { return aCol; }
+    int numRows() const;
+    int numCols() const;
 
     bool isActive() const { return active; }
+    bool isEmpty() const { return numRows() == 0; }
 
 private:
     uint active : 1;
@@ -103,10 +106,8 @@ private:
     int aRow, aCol;
 };
 
-#ifdef QT_QWINEXPORT
 #define Q_DEFINED_QTABLE_SELECTION
 #include "qwinexport.h"
-#endif /* QT_QWINEXPORT */
 
 class QM_EXPORT_TABLE QTableItem : public Qt
 {
@@ -115,6 +116,7 @@ class QM_EXPORT_TABLE QTableItem : public Qt
 public:
     enum EditType { Never, OnTyping, WhenCurrent, Always };
 
+    QTableItem( QTable *table, EditType et );
     QTableItem( QTable *table, EditType et, const QString &text );
     QTableItem( QTable *table, EditType et, const QString &text,
                 const QPixmap &p );
@@ -169,17 +171,19 @@ private:
     uint enabled : 1;
     int rw, cl;
     int rowspan, colspan;
-
+#if (QT_VERSION >= 0x040000)
+#error "Add a setAlignment() function in 4.0 (but no d pointer)"
+#endif
 };
 
-#ifdef QT_QWINEXPORT
 #define Q_DEFINED_QTABLE_ITEM
 #include "qwinexport.h"
-#endif /* QT_QWINEXPORT */
+
 class QM_EXPORT_TABLE QComboTableItem : public QTableItem
 {
 public:
     QComboTableItem( QTable *table, const QStringList &list, bool editable = FALSE );
+    ~QComboTableItem();
     virtual QWidget *createEditor() const;
     virtual void setContentFromEditor( QWidget *w );
     virtual void paint( QPainter *p, const QColorGroup &cg,
@@ -208,6 +212,8 @@ private:
     int current;
     bool edit;
     static QComboBox *fakeCombo;
+    static QWidget *fakeComboWidget;
+    static int fakeRef;
 
 };
 
@@ -215,6 +221,7 @@ class QM_EXPORT_TABLE QCheckTableItem : public QTableItem
 {
 public:
     QCheckTableItem( QTable *table, const QString &txt );
+    void setText( const QString &t );
     virtual QWidget *createEditor() const;
     virtual void setContentFromEditor( QWidget *w );
     virtual void paint( QPainter *p, const QColorGroup &cg,
@@ -233,18 +240,6 @@ private:
 
 };
 
-#ifndef QT_QWINEXPORT
-#if defined(Q_TEMPLATEDLL)
-// MOC_SKIP_BEGIN
-QM_TEMPLATE_EXTERN_TABLE template class QM_EXPORT_TABLE QPtrVector<QTableItem>;
-QM_TEMPLATE_EXTERN_TABLE template class QM_EXPORT_TABLE QPtrVector<QWidget>;
-QM_TEMPLATE_EXTERN_TABLE template class QM_EXPORT_TABLE QPtrList<QTableSelection>;
-QM_TEMPLATE_EXTERN_TABLE template class QM_EXPORT_TABLE QIntDict<int>;
-// MOC_SKIP_END
-#endif
-#endif /* QT_QWINEXPORT */
-
-
 class QM_EXPORT_TABLE QTable : public QScrollView
 {
     Q_OBJECT
@@ -365,6 +360,8 @@ public slots:
     virtual void hideColumn( int col );
     virtual void showRow( int row );
     virtual void showColumn( int col );
+    bool isRowHidden( int row ) const;
+    bool isColumnHidden( int col ) const;
 
     virtual void setColumnWidth( int col, int w );
     virtual void setRowHeight( int row, int h );
@@ -496,7 +493,7 @@ private:
     void updateRowWidgets( int row );
     void updateColWidgets( int col );
     bool isSelected( int row, int col, bool includeCurrent ) const;
-    void setCurrentCell( int row, int col, bool updateSelections );
+    void setCurrentCell( int row, int col, bool updateSelections, bool ensureVisible = FALSE );
     void fixCell( int &row, int &col, int key );
     void delayedUpdateGeometries();
     struct TableWidget
@@ -531,7 +528,7 @@ private:
     bool mCols : 1;
     bool asc : 1;
     bool doSort : 1;
-    bool mousePressed : 1;
+    bool unused : 1;
     bool readOnly : 1;
     bool shouldClearSelection : 1;
     bool dEnabled : 1;
@@ -551,15 +548,13 @@ private:
     FocusStyle focusStl;
     QSize unused_cachedSizeHint; // ### remove in 4.0
 
-#if defined(Q_DISABLE_COPY) // Disabled copy constructor and operator=
+#if defined(Q_DISABLE_COPY)
     QTable( const QTable & );
     QTable &operator=( const QTable & );
 #endif
 };
 
-#ifdef QT_QWINEXPORT
 #define Q_DEFINED_QTABLE
 #include "qwinexport.h"
-#endif /* QT_QWINEXPORT */
 #endif // QT_NO_TABLE
 #endif // TABLE_H
