@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qcstring.cpp   3.3.2   edited Mar 31 10:40 $
+** $Id: qt/qcstring.cpp   3.3.3   edited May 5 11:52 $
 **
 ** Implementation of extended char array operations, and QByteArray and
 ** QCString classes
@@ -366,7 +366,7 @@ QByteArray qCompress( const uchar* data, int nbytes )
 	return QByteArray();
     }
 
-    ulong len = nbytes * 2;
+    ulong len = nbytes * 101 / 100 + 13;
     QByteArray bazip;
     int res;
     do {
