@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qdatastream.h   3.1.2   edited Nov 7 16:55 $
+** $Id: qt/qdatastream.h   3.3.3   edited Sep 24 2003 $
 **
 ** Definition of QDataStream class
 **
@@ -75,8 +75,12 @@ public:
     QDataStream &operator>>( Q_UINT16 &i );
     QDataStream &operator>>( Q_INT32 &i );
     QDataStream &operator>>( Q_UINT32 &i );
+    QDataStream &operator>>( Q_INT64 &i );
+    QDataStream &operator>>( Q_UINT64 &i );
+#if !defined(Q_OS_WIN64)
     QDataStream &operator>>( Q_LONG &i );
     QDataStream &operator>>( Q_ULONG &i );
+#endif
 
     QDataStream &operator>>( float &f );
     QDataStream &operator>>( double &f );
@@ -88,8 +92,12 @@ public:
     QDataStream &operator<<( Q_UINT16 i );
     QDataStream &operator<<( Q_INT32 i );
     QDataStream &operator<<( Q_UINT32 i );
+    QDataStream &operator<<( Q_INT64 i );
+    QDataStream &operator<<( Q_UINT64 i );
+#if !defined(Q_OS_WIN64)
     QDataStream &operator<<( Q_LONG i );
     QDataStream &operator<<( Q_ULONG i );
+#endif
     QDataStream &operator<<( float f );
     QDataStream &operator<<( double f );
     QDataStream &operator<<( const char *str );
@@ -153,8 +161,13 @@ inline QDataStream &QDataStream::operator>>( Q_UINT16 &i )
 inline QDataStream &QDataStream::operator>>( Q_UINT32 &i )
 { return *this >> (Q_INT32&)i; }
 
+inline QDataStream &QDataStream::operator>>( Q_UINT64 &i )
+{ return *this >> (Q_INT64&)i; }
+
+#if !defined(Q_OS_WIN64)
 inline QDataStream &QDataStream::operator>>( Q_ULONG &i )
 { return *this >> (Q_LONG&)i; }
+#endif
 
 inline QDataStream &QDataStream::operator<<( Q_UINT8 i )
 { return *this << (Q_INT8)i; }
@@ -165,9 +178,13 @@ inline QDataStream &QDataStream::operator<<( Q_UINT16 i )
 inline QDataStream &QDataStream::operator<<( Q_UINT32 i )
 { return *this << (Q_INT32)i; }
 
+inline QDataStream &QDataStream::operator<<( Q_UINT64 i )
+{ return *this << (Q_INT64)i; }
+
+#if !defined(Q_OS_WIN64)
 inline QDataStream &QDataStream::operator<<( Q_ULONG i )
 { return *this << (Q_LONG)i; }
-
+#endif
 
 #endif // QT_NO_DATASTREAM
 #endif // QDATASTREAM_H
