@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qglobal.h   3.3.2   edited Apr 19 11:35 $
+** $Id: qt/qglobal.h   3.3.3   edited Aug 5 16:41 $
 **
 ** Global type declarations and definitions
 **
@@ -38,11 +38,11 @@
 #ifndef QGLOBAL_H
 #define QGLOBAL_H
 
-#define QT_VERSION_STR   "3.3.2"
+#define QT_VERSION_STR   "3.3.3"
 /*
    QT_VERSION is (major << 16) + (minor << 8) + patch.
  */
-#define QT_VERSION 0x030302
+#define QT_VERSION 0x030303
 
 /*
    The operating system, must be one of: (Q_OS_x)
@@ -81,7 +81,7 @@
 
 #if defined(__DARWIN_X11__)
 #  define Q_OS_DARWIN
-#elif defined(__APPLE__) && defined(__GNUC__)
+#elif defined(__APPLE__) && (defined(__GNUC__) || defined(__xlC__))
 #  define Q_OS_MACX
 #elif defined(__MACOSX__)
 #  define Q_OS_MACX
