@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qintcache.h   3.2.2   edited May 13 09:08 $
+** $Id: qt/qintcache.h   3.3.3   edited Apr 6 12:52 $
 **
 ** Definition of QIntCache template class
 **
@@ -44,7 +44,12 @@
 
 
 template<class type> 
-class QIntCache : public QGCache
+class QIntCache
+#ifdef Q_QDOC
+	: public QPtrCollection
+#else
+	: public QGCache
+#endif
 {
 public:
     QIntCache( const QIntCache<type> &c ) : QGCache(c) {}
