@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qsettings.cpp   3.3.2   edited Mar 27 17:27 $
+** $Id: qt/qsettings.cpp   3.3.3   edited Apr 30 11:52 $
 **
 ** Implementation of QSettings class
 **
@@ -132,13 +132,13 @@ static inline int qt_open( const char *pathname, int flags, mode_t mode )
     QSettings settings;
 
     settings.beginGroup( "/MainWindow" );
-	settings.beginGroup( "/Geometry" );
-	    int x = settings.readEntry( "/x" );
-	    // ...
-	settings.endGroup();
-	settings.beginGroup( "/Toolbars" );
-	    // ...
-	settings.endGroup();
+        settings.beginGroup( "/Geometry" );
+            int x = settings.readEntry( "/x" );
+            // ...
+        settings.endGroup();
+        settings.beginGroup( "/Toolbars" );
+            // ...
+        settings.endGroup();
     settings.endGroup();
     \endcode
 
@@ -1529,7 +1529,7 @@ bool QSettings::removeEntry(const QString &key)
 
 /*!
   Returns a list of the keys which contain entries under \a key. Does \e
-  not return any keys that contain keys.
+  not return any keys that contain subkeys.
 
     Example settings:
     \code
@@ -1543,11 +1543,13 @@ bool QSettings::removeEntry(const QString &key)
     \code
     QStringList keys = entryList( "/MyCompany/MyApplication" );
     \endcode
-    \c keys contains 'background color' and 'foreground color'. It does
-    not contain 'geometry' because this key contains keys not entries.
 
-    To access the geometry values could either use subkeyList() to read
-    the keys and then read each entry, or simply read each entry
+    In the above example, \c keys will contain 'background color' and
+    'foreground color'. It will not contain 'geometry' because this key
+    contains subkeys not entries.
+
+    To access the geometry values, you could either use subkeyList()
+    to read the keys then read each entry, or simply read each entry
     directly by specifying its full key, e.g.
     "/MyCompany/MyApplication/geometry/y".
 
@@ -1624,7 +1626,7 @@ QStringList QSettings::entryList(const QString &key) const
 
 
 /*!
-  Returns a list of the keys which contain keys under \a key. Does \e
+  Returns a list of the keys which contain subkeys under \a key. Does \e
   not return any keys that contain entries.
 
     Example settings:
@@ -1642,10 +1644,12 @@ QStringList QSettings::entryList(const QString &key) const
     \code
     QStringList keys = subkeyList( "/MyCompany/MyApplication" );
     \endcode
-    \c keys contains 'geometry' and 'recent files'. It does not contain
-    'background color' or 'foreground color' because they are keys which
-    contain entries not keys. To get a list of keys that have values
-    rather than subkeys use entryList().
+
+    In the above example, \c keys will contain 'geometry' and
+    'recent files'. It will not contain 'background color' or
+    'foreground color' because those keys contain entries not
+    subkeys. To get a list of keys that contain entries rather than
+    subkeys use entryList() instead.
 
   \sa entryList()
 */
