@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qtextstream.cpp   3.3.2   edited Oct 30 14:47 $
+** $Id: qt/qtextstream.cpp   3.3.3   edited Apr 20 18:04 $
 **
 ** Implementation of QTextStream class
 **
@@ -1073,7 +1073,18 @@ QTextStream &QTextStream::writeBlock( const char* p, uint len )
 	    u[i] = p[i];
 	dev->writeBlock( (char*)u, len * sizeof(QChar) );
 	delete [] u;
-    } else {
+    }
+#ifndef QT_NO_TEXTCODEC
+    else if (mapper) {
+        if (!d->encoder)
+            d->encoder = mapper->makeEncoder();
+        QString s = QString::fromLatin1(p, len);
+        int l = len;
+        QCString block = d->encoder->fromUnicode(s, l);
+        dev->writeBlock(block, l);
+    }
+#endif
+    else {
 	for ( uint i = 0; i < len; i++ )
 	    ts_putc( (uchar)p[i] );
     }
