@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qaction.cpp   3.3.1   edited Feb 13 16:34 $
+** $Id: qt/qaction.cpp   3.3.3   edited Jun 18 12:43 $
 **
 ** Implementation of QAction class
 **
@@ -141,6 +141,7 @@ public:
     uint toggleaction : 1;
     uint on : 1;
     uint forceDisabled : 1;
+    uint forceInvisible : 1;
 #ifndef QT_NO_TOOLTIP
     QToolTipGroup tipGroup;
 #endif
@@ -178,7 +179,7 @@ QActionPrivate::QActionPrivate(QAction *act)
       key( 0 ), accel( 0 ), accelid( 0 ),
 #endif
       enabled( TRUE ), visible( TRUE ), toggleaction( FALSE ), on( FALSE ),
-      forceDisabled( FALSE ),
+      forceDisabled( FALSE ), forceInvisible( FALSE ),
 #ifndef QT_NO_TOOLTIP
       tipGroup( 0 ),
 #endif
@@ -947,6 +948,8 @@ void QAction::setDisabled( bool disable )
 */
 void QAction::setVisible( bool visible )
 {
+    d->forceInvisible = !visible;
+
     if ( (bool)d->visible == visible )
 	return;
     d->visible = visible;
@@ -1288,13 +1291,18 @@ void QAction::objectDestroyed()
 void QActionGroupPrivate::update( const QActionGroup* that )
 {
     for ( QPtrListIterator<QAction> it( actions ); it.current(); ++it ) {
-	if ( that->isEnabled() && !it.current()->d->forceDisabled )
+	if ( that->isEnabled() && !it.current()->d->forceDisabled ) {
 	    it.current()->setEnabled( TRUE );
-	else if ( !that->isEnabled() && it.current()->isEnabled() ) {
+	} else if ( !that->isEnabled() && it.current()->isEnabled() ) {
 	    it.current()->setEnabled( FALSE );
 	    it.current()->d->forceDisabled = FALSE;
 	}
-	it.current()->setVisible( that->isVisible() );
+	if ( that->isVisible() && !it.current()->d->forceInvisible ) {
+	    it.current()->setVisible( TRUE );
+	} else if ( !that->isVisible() && it.current()->isVisible() ) {
+	    it.current()->setVisible( FALSE );
+	    it.current()->d->forceInvisible = FALSE;
+	}
     }
     for ( QPtrListIterator<QComboBox> cb( comboboxes ); cb.current(); ++cb ) {
 	QComboBox *combobox = cb.current();
@@ -1570,8 +1578,11 @@ void QActionGroup::add( QAction* action )
 	action->setWhatsThis( whatsThis() );
     if ( action->toolTip().isNull() )
 	action->setToolTip( toolTip() );
-    action->d->enabled = isEnabled();
-    action->d->visible = isVisible();
+
+    if (!action->d->forceDisabled)
+	action->d->enabled = isEnabled();
+    if (!action->d->forceInvisible)
+	action->d->visible = isVisible();
 
     connect( action, SIGNAL( destroyed() ), this, SLOT( childDestroyed() ) );
     connect( action, SIGNAL( activated() ), this, SIGNAL( activated() ) );
@@ -2063,6 +2074,8 @@ void QActionGroup::objectDestroyed()
 }
 
 /*!
+    \internal
+    
     This function is called from the addTo() function when it has
     created a widget (\a actionWidget) for the child action \a a in
     the \a container.
@@ -2077,7 +2090,8 @@ void QActionGroup::addedTo( QWidget *actionWidget, QWidget *container, QAction *
 
 /*!
     \overload
-
+    \internal
+    
     This function is called from the addTo() function when it has
     created a menu item for the child action at the index position \a
     index in the popup menu \a menu.
