@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qbuttongroup.cpp   3.3.2   edited Nov 17 20:47 $
+** $Id: qt/qbuttongroup.cpp   3.3.3   edited Jul 23 16:16 $
 **
 ** Implementation of QButtonGroup class
 **
@@ -585,6 +585,22 @@ void QButtonGroup::moveFocus( int key )
 	buttoncand->animateTimeout(); // ### crude l&f hack
     }
 
+    // loop
+    if (!candidate && buttons->count()) {
+        switch (key) {
+        case Key_Up:
+        case Key_Left:
+            candidate = buttons->last()->button;
+            break;
+        case Key_Down:
+        case Key_Right:
+            candidate = buttons->first()->button;
+            break;
+        default:
+            break;
+        }
+    }
+
     if ( candidate ) {
 	if (key == Key_Up || key == Key_Left)
 	    QFocusEvent::setReason(QFocusEvent::Backtab);
