@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qdatetimeedit.cpp   3.3.2   edited Mar 30 08:02 $
+** $Id: qt/qdatetimeedit.cpp   3.3.3   edited Jun 2 17:20 $
 **
 ** Implementation of date and time edit classes
 **
@@ -379,7 +379,7 @@ class QDateTimeEditor : public QWidget
 {
     Q_OBJECT
 public:
-    QDateTimeEditor( QDateTimeEditBase * parent=0,
+    QDateTimeEditor( QDateTimeEditBase * widget, QWidget *parent,
 		       const char * name=0 );
     ~QDateTimeEditor();
 
@@ -441,12 +441,12 @@ protected:
     Constructs an empty datetime editor with parent \a parent and
     called \a name.
 */
-QDateTimeEditor::QDateTimeEditor( QDateTimeEditBase * parent,
+QDateTimeEditor::QDateTimeEditor( QDateTimeEditBase * widget, QWidget *parent,
 				  const char * name )
     : QWidget( parent, name, WNoAutoErase )
 {
     d = new QDateTimeEditorPrivate();
-    cw = parent;
+    cw = widget;
     init();
 }
 
@@ -934,7 +934,7 @@ void QDateEdit::init()
 {
     d = new QDateEditPrivate();
     d->controls = new QDateTimeSpinWidget( this, qstrcmp( name(), "qt_datetime_dateedit" ) == 0 ? "qt_spin_widget" : "date edit controls" );
-    d->ed = new QDateTimeEditor( this, "date editor" );
+    d->ed = new QDateTimeEditor( this, d->controls, "date editor" );
     d->controls->setEditWidget( d->ed );
     setFocusProxy( d->ed );
     connect( d->controls, SIGNAL( stepUpPressed() ), SLOT( stepUp() ) );
@@ -1835,8 +1835,8 @@ QTimeEdit::QTimeEdit( const QTime& time, QWidget * parent, const char * name )
 void QTimeEdit::init()
 {
     d = new QTimeEditPrivate();
-    d->ed = new QDateTimeEditor( this, "time edit base" );
     d->controls = new QDateTimeSpinWidget( this, qstrcmp( name(), "qt_datetime_timeedit" ) == 0 ? "qt_spin_widget" : "time edit controls" );
+    d->ed = new QDateTimeEditor( this, d->controls, "time edit base" );
     d->controls->setEditWidget( d->ed );
     setFocusProxy( d->ed );
     connect( d->controls, SIGNAL( stepUpPressed() ), SLOT( stepUp() ) );
