@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qdial.cpp   3.3.2   edited May 27 2003 $
+** $Id: qt/qdial.cpp   3.3.3   edited Jun 25 14:55 $
 **
 ** Implementation of the dial widget
 **
@@ -529,8 +529,10 @@ void QDial::rangeChange()
 
 int QDial::valueFromPoint( const QPoint & p ) const
 {
-    double a = atan2( (double)height()/2.0 - p.y(),
-		      (double)p.x() - width()/2.0 );
+    double yy = (double)height()/2.0 - p.y();
+    double xx = (double)p.x() - width()/2.0;
+    double a = (xx || yy) ? atan2(yy, xx) : 0;
+        
     if ( a < m_pi/-2 )
 	a = a + m_pi*2;
 
