@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qdockwindow.cpp   3.3.2   edited Dec 23 13:06 $
+** $Id: qt/qdockwindow.cpp   3.3.3   edited Jun 4 12:14 $
 **
 ** Implementation of the QDockWindow class
 **
@@ -731,10 +731,10 @@ void QDockWindowTitleBar::mouseDoubleClickEvent( QMouseEvent * )
     Single clicking the minimized handle will restore the dock window
     to the last dock area that it was docked in.
     \endomit
-    If the user clicks the close button (which appears on floating
-    dock windows by default) the dock window will disappear. You can
-    control whether or not a dock window has a close button with
-    setCloseMode().
+    If the user clicks the close button (which does not appear on
+    dock windows by default - see \l closeMode) the dock window will
+    disappear. You can control whether or not a dock window has a
+    close button with setCloseMode().
 
     QMainWindow provides four dock areas (top, left, right and bottom)
     which can be used by dock windows. For many applications using the
@@ -1625,6 +1625,9 @@ int QDockWindow::closeMode() const
     setHorizontallyStretchable(TRUE) or setResizeEnabled(TRUE).
 
     \sa setResizeEnabled()
+
+    \bug Strecthability is broken. You must call setResizeEnabled(TRUE) to get
+    proper behavior and even then QDockWindow does not limit stretchablilty.
 */
 
 void QDockWindow::setHorizontallyStretchable( bool b )
@@ -1640,6 +1643,9 @@ void QDockWindow::setHorizontallyStretchable( bool b )
     setVerticallyStretchable(TRUE) or setResizeEnabled(TRUE).
 
     \sa setResizeEnabled()
+
+    \bug Strecthability is broken. You must call setResizeEnabled(TRUE) to get
+    proper behavior and even then QDockWindow does not limit stretchablilty.
 */
 
 void QDockWindow::setVerticallyStretchable( bool b )
@@ -1666,6 +1672,9 @@ bool QDockWindow::isVerticallyStretchable() const
     setVerticallyStretchable(), or with setResizeEnabled().
 
     \sa setResizeEnabled()
+
+    \bug Strecthability is broken. You must call setResizeEnabled(TRUE) to get
+    proper behavior and even then QDockWindow does not limit stretchablilty.
 */
 
 bool QDockWindow::isStretchable() const
