@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qheader.cpp   3.3.2   edited Jan 7 14:23 $
+** $Id: qt/qheader.cpp   3.3.3   edited Jul 19 16:29 $
 **
 ** Implementation of QHeader widget class (table header)
 **
@@ -1102,13 +1102,18 @@ QSize QHeader::sectionSizeHint( int section, const QFontMetrics& fm ) const
     QString *label = d->labels[section];
     if ( label ) {
 	int lines = label->contains( '\n' ) + 1;
-	bound.setHeight( fm.height() +  fm.lineSpacing() * (lines - 1) );
 	int w = 0;
-	for ( int i = 0; i < lines; ++i ) {
-	    QString s = label->section( '\n', i, i );
-	    int tmpw = fm.width( s );
-	    w = QMAX( w, tmpw );
-	}
+        if (lines > 1) {
+            bound.setHeight(fm.height() + fm.lineSpacing() * (lines - 1));
+            QStringList list = QStringList::split('\n', *label);
+            for (int i=0; i <(int)list.count(); ++i) {
+                int tmpw = fm.width(*(list.at(i)));
+                w = QMAX(w, tmpw);
+            }
+        } else {
+            bound.setHeight(fm.height());
+            w = fm.width(*label);
+        }
 	bound.setWidth( w );
     }
     int arrowWidth = 0;
@@ -1459,7 +1464,7 @@ void QHeader::paintSection( QPainter *p, int index, const QRect& fr )
     if ( sectionSize( section ) <= 0 )
 	return;
 
-    QStyle::SFlags flags = ( orient == Horizontal ? QStyle::Style_Horizontal : 0 );
+    QStyle::SFlags flags = (orient == Horizontal ? QStyle::Style_Horizontal : QStyle::Style_Default);
     //pass in some hint about the sort indicator if it is used
     if(d->sortSection != section)
 	flags |= QStyle::Style_Off;
@@ -1468,10 +1473,11 @@ void QHeader::paintSection( QPainter *p, int index, const QRect& fr )
     if(isEnabled())
 	flags |= QStyle::Style_Enabled;
     if(isClickEnabled(section)) {
-	if(index == oldHandleIdx)
+	if(section == oldHandleIdx) // this is "more correct"
 	    flags |= QStyle::Style_Sunken; //currently selected
 	if((state == Pressed || state == Moving) && index == handleIdx)
 	    flags |= QStyle::Style_Down; //currently pressed
+
     }
     if(!(flags & QStyle::Style_Down))
 	flags |= QStyle::Style_Raised;
