@@ -1,5 +1,5 @@
 /**********************************************************************
-** $Id: qt/qlineedit.cpp   3.3.2   edited Apr 6 13:46 $
+** $Id: qt/qlineedit.cpp   3.3.3   edited Jul 20 11:44 $
 **
 ** Implementation of QLineEdit widget class
 **
@@ -437,6 +437,7 @@ QLineEdit::QLineEdit( const QString& contents, const QString &inputMask, QWidget
 
 QLineEdit::~QLineEdit()
 {
+    delete [] d->maskData;
     delete d;
 }
 
@@ -456,9 +457,10 @@ QLineEdit::~QLineEdit()
 */
 QString QLineEdit::text() const
 {
+    QString res = d->text;
     if ( d->maskData )
-	return d->stripString( d->text );
-    return ( d->text.isNull() ? QString::fromLatin1("") : d->text );
+	res = d->stripString( d->text );
+    return ( res.isNull() ? QString::fromLatin1("") : res );
 }
 
 void QLineEdit::setText( const QString& text)
@@ -1897,6 +1899,8 @@ void QLineEdit::drawContents( QPainter *p )
 	d->hscroll = cix;
     } else if ( widthUsed - d->hscroll < lineRect.width() ) {
 	d->hscroll = widthUsed - lineRect.width() + 1;
+    } else if (d->hscroll < 0) {
+        d->hscroll = 0;
     }
     // the y offset is there to keep the baseline constant in case we have script changes in the text.
     QPoint topLeft = lineRect.topLeft() - QPoint(d->hscroll, d->ascent-fm.ascent());
