@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qpopupmenu.cpp   3.3.2   edited Mar 15 09:37 $
+** $Id: qt/qpopupmenu.cpp   3.3.3   edited Jul 16 17:02 $
 **
 ** Implementation of QPopupMenu class
 **
@@ -1200,6 +1200,7 @@ QSize QPopupMenu::updateSize(bool force_update, bool do_resize)
 
     if( do_resize && size() != d->calcSize ) {
 	setMaximumSize( d->calcSize );
+        d->calcSize = maximumSize(); //let the max size adjust it (virtual)
 	resize( d->calcSize );
     }
     return d->calcSize;
@@ -2526,9 +2527,6 @@ void QPopupMenu::setActiveItem( int i )
 QSize QPopupMenu::sizeHint() const
 {
     constPolish();
-    if(style().styleHint(QStyle::SH_PopupMenu_Scrollable, this))
-	return minimumSize(); //can be any size..
-
     QPopupMenu* that = (QPopupMenu*) this;
     //We do not need a resize here, just the sizeHint..
     return that->updateSize(FALSE, FALSE).expandedTo( QApplication::globalStrut() );
