@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qpushbutton.cpp   3.3.2   edited Oct 8 2003 $
+** $Id: qt/qpushbutton.cpp   3.3.3   edited Apr 16 15:57 $
 **
 ** Implementation of QPushButton class
 **
@@ -639,8 +639,8 @@ void QPushButton::focusOutEvent( QFocusEvent *e )
 
 #ifndef QT_NO_POPUPMENU
 /*!
-    Associates the popup menu \a popup with this push button and thus
-    turns it into a menu button.
+    Associates the popup menu \a popup with this push button. This
+    turns the button into a menu button.
 
     Ownership of the popup menu is \e not transferred to the push
     button.
