@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qslider.cpp   3.3.2   edited Nov 8 19:46 $
+** $Id: qt/qslider.cpp   3.3.3   edited Jul 21 17:48 $
 **
 ** Implementation of QSlider class
 **
@@ -446,7 +446,7 @@ void QSlider::mousePressEvent( QMouseEvent *e )
 	clickOffset = slideLength / 2;
     } else if ( orient == Horizontal && e->pos().x() < r.left() //### goodPart
 		|| orient == Vertical && e->pos().y() < r.top() ) {
-	if ( QApplication::reverseLayout() ) {
+	if ( orient == Horizontal && QApplication::reverseLayout() ) {
 	    state = TimingUp;
 	    addPage();
 	} else {
@@ -459,7 +459,7 @@ void QSlider::mousePressEvent( QMouseEvent *e )
 	timer->start( thresholdTime, TRUE );
     } else if ( orient == Horizontal && e->pos().x() > r.right() //### goodPart
 		|| orient == Vertical && e->pos().y() > r.bottom() ) {
-	if ( QApplication::reverseLayout() ) {
+	if ( orient == Horizontal && QApplication::reverseLayout() ) {
 	    state = TimingDown;
 	    subtractPage();
 	} else {
