@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qtooltip.cpp   3.3.2   edited Jan 28 13:52 $
+** $Id: qt/qtooltip.cpp   3.3.3   edited May 18 20:35 $
 **
 ** Tool Tips (or Balloon Help) for any widget or rectangle
 **
@@ -261,7 +261,7 @@ void QTipManager::remove( QWidget *w, const QRect & r, bool delayhide )
 	if (!delayhide)
 	    hideTip();
 	else
-	    currentTip->autoDelete = true;
+	    currentTip->autoDelete = TRUE;
 
     if ( t == previousTip )
 	previousTip = 0;
