@@ -30,19 +30,25 @@
 
 #include <qapplication.h>
 #include <qdir.h>
-#include <qfileinfo.h>
 #include <qfile.h>
+#include <qfileinfo.h>
 #include <qsettings.h>
 #include <qxml.h>
 
 static Config *static_configuration = 0;
 
+inline QString getVersionString()
+{
+    return QString::number( (QT_VERSION >> 16) & 0xff )
+	+ "." + QString::number( (QT_VERSION >> 8) & 0xff );
+}
+
 Config::Config()
-    : hideSidebar( FALSE ), profil( 0 )
+    : hideSidebar( FALSE ), profil( 0 ), fontSiz(-1), maximized(FALSE)
 {
     if( !static_configuration ) {
 	static_configuration = this;
-    } else { 
+    } else {
 	qWarning( "Multiple configurations not allowed!" );
     }
 }
@@ -50,14 +56,14 @@ Config::Config()
 Config *Config::loadConfig(const QString &profileFileName)
 {
     Config *config = new Config();
-    
+
     if (profileFileName.isEmpty()) { // no profile
 	config->profil = Profile::createDefaultProfile();
 	config->load();
-	config->loadDefaultProfile();	
+	config->loadDefaultProfile();
 	return config;
     }
-    
+
     QFile file(profileFileName);
     if (!file.exists()) {
 	qWarning( "File does not exist: " + profileFileName );
@@ -70,12 +76,12 @@ Config *Config::loadConfig(const QString &profileFileName)
     }
     if (parser->parserVersion() < DocuParser::Qt320) {
 	qWarning( "File does not contain profile information" );
-	return 0;	
+	return 0;
     }
     DocuParser320 *profileParser = static_cast<DocuParser320*>(parser);
     parser->parse(&file);
     config->profil = profileParser->profile();
-    if (!config->profil) {	
+    if (!config->profil) {
 	qWarning( "Config::loadConfig(), no profile in: " + profileFileName );
 	return 0;
     }
@@ -93,7 +99,7 @@ Config *Config::configuration()
 
 void Config::load()
 {
-    const QString key = "/Qt Assistant/" + QString(QT_VERSION_STR) + "/";
+    const QString key = "/Qt Assistant/" + getVersionString() + "/";
     const QString profkey = key + "Profile/" + profil->props["name"] + "/";
 
     QSettings settings;
@@ -102,23 +108,25 @@ void Config::load()
     webBrows = settings.readEntry( key + "Webbrowser" );
     home = settings.readEntry( profkey + "Homepage" );
     pdfApp = settings.readEntry( key + "PDFApplication" );
-    fontFam = settings.readEntry( key + "Family", qApp->font().family() );
-
-    fontFix = settings.readEntry( key + "FixedFamily", "courier" );
-    fontSiz = settings.readNumEntry( key + "Size", -1 );
-    if ( fontSiz == -1 ) {
-	QFontInfo fi( qApp->font() );
-	fontSiz = fi.pointSize();
-    }
     linkUnder = settings.readBoolEntry( key + "LinkUnderline", TRUE );
     linkCol = settings.readEntry( key + "LinkColor", "#0000FF" );
-    src = settings.readEntry( profkey + "Source" );
-    sideBar = settings.readNumEntry( key + "SideBarPage" );    
-    geom.setRect( settings.readNumEntry( key + "GeometryX", 0 ),
-		  settings.readNumEntry( key + "GeometryY", 0 ),
-		  settings.readNumEntry( key + "GeometryWidth", 800 ),
-		  settings.readNumEntry( key + "GeometryHeight", 600 ) );
-    maximized = settings.readBoolEntry( key + "GeometryMaximized", FALSE );
+    src = settings.readListEntry( profkey + "Source" );
+    sideBar = settings.readNumEntry( key + "SideBarPage" );
+    if (qApp->type() != QApplication::Tty) {
+	fontFam = settings.readEntry( key + "Family", qApp->font().family() );
+
+	fontFix = settings.readEntry( key + "FixedFamily", "courier" );
+	fontSiz = settings.readNumEntry( key + "Size", -1 );
+	if ( fontSiz == -1 ) {
+	    QFontInfo fi( qApp->font() );
+	    fontSiz = fi.pointSize();
+	}
+	geom.setRect( settings.readNumEntry( key + "GeometryX", QApplication::desktop()->availableGeometry().x() ),
+		      settings.readNumEntry( key + "GeometryY", QApplication::desktop()->availableGeometry().y() ),
+		      settings.readNumEntry( key + "GeometryWidth", 800 ),
+		      settings.readNumEntry( key + "GeometryHeight", 600 ) );
+	maximized = settings.readBoolEntry( key + "GeometryMaximized", FALSE );
+    }
     mainWinLayout = settings.readEntry( key + "MainwindowLayout" );
     rebuildDocs = settings.readBoolEntry( key + "RebuildDocDB", TRUE );
 
@@ -133,26 +141,29 @@ void Config::save()
 
 void Config::saveSettings()
 {
-    const QString key = "/Qt Assistant/" + QString(QT_VERSION_STR) + "/";
+    const QString key = "/Qt Assistant/" + getVersionString() + "/";
     const QString profkey = key + "Profile/" + profil->props["name"] + "/";
+
     QSettings settings;
     settings.insertSearchPath( QSettings::Windows, "/Trolltech" );
 
     settings.writeEntry( key + "Webbrowser", webBrows );
     settings.writeEntry( profkey + "Homepage", home );
     settings.writeEntry( key + "PDFApplication", pdfApp );
-    settings.writeEntry( key + "Family",  fontFam );
-    settings.writeEntry( key + "Size",  fontSiz );
-    settings.writeEntry( key + "FixedFamily", fontFix );
     settings.writeEntry( key + "LinkUnderline", linkUnder );
     settings.writeEntry( key + "LinkColor", linkCol );
     settings.writeEntry( profkey + "Source", src );
     settings.writeEntry( key + "SideBarPage", sideBarPage() );
-    settings.writeEntry( key + "GeometryX", geom.x() );
-    settings.writeEntry( key + "GeometryY", geom.y() );
-    settings.writeEntry( key + "GeometryWidth", geom.width() );
-    settings.writeEntry( key + "GeometryHeight", geom.height() );
-    settings.writeEntry( key + "GeometryMaximized", maximized );
+    if (qApp->type() != QApplication::Tty) {
+	settings.writeEntry( key + "GeometryX", geom.x() );
+	settings.writeEntry( key + "GeometryY", geom.y() );
+	settings.writeEntry( key + "GeometryWidth", geom.width() );
+	settings.writeEntry( key + "GeometryHeight", geom.height() );
+	settings.writeEntry( key + "GeometryMaximized", maximized );
+	settings.writeEntry( key + "Family",  fontFam );
+	settings.writeEntry( key + "Size",  fontSiz );
+	settings.writeEntry( key + "FixedFamily", fontFix );
+    }
     if ( !hideSidebar )
 	settings.writeEntry( key + "MainwindowLayout", mainWinLayout );
     settings.writeEntry( key + "RebuildDocDB", rebuildDocs );
@@ -187,7 +198,7 @@ void Config::loadDefaultProfile()
     profil->imageDirs.clear();
     profil->docs.clear();
     profil->dcfTitles.clear();
-    
+
     QStringList titles = settings.readListEntry( profKey + "Titles" );
     QStringList iconLst = settings.readListEntry( profKey + "DocIcons" );
     QStringList indexLst = settings.readListEntry( profKey + "IndexPages" );
@@ -202,7 +213,7 @@ void Config::loadDefaultProfile()
     for( ; it != titles.end();
 	++it, ++iconIt, ++indexIt, ++imageIt, ++dcfIt )
     {
-	profil->addDCFIcon( *it, *iconIt );       
+	profil->addDCFIcon( *it, *iconIt );
 	profil->addDCFIndexPage( *it, *indexIt );
 	profil->addDCFImageDir( *it, *imageIt );
 	profil->addDCFTitle( *dcfIt, *it );
@@ -222,7 +233,10 @@ void Config::saveProfile( Profile *profile )
 	return;
     QSettings settings;
     settings.insertSearchPath( QSettings::Windows, "/Trolltech" );
-    const QString key = "/Qt Assistant/" + QString(QT_VERSION_STR) + "/";
+    QString versionString = (profile->props["name"] == "default")
+	? QString(QT_VERSION_STR)
+	: getVersionString();
+    const QString key = "/Qt Assistant/" + versionString + "/";
     const QString profKey = key + "Profile/" + profile->props["name"] + "/";
 
     QStringList indexes, icons, imgDirs, dcfs;
@@ -232,9 +246,9 @@ void Config::saveProfile( Profile *profile )
 	indexes << profile->indexPages[*it];
 	icons << profile->icons[*it];
 	imgDirs << profile->imageDirs[*it];
-	dcfs << profile->dcfTitles[*it];	
+	dcfs << profile->dcfTitles[*it];
     }
- 
+
     settings.writeEntry( profKey + "Titles", titles );
     settings.writeEntry( profKey + "DocFiles", dcfs );
     settings.writeEntry( profKey + "IndexPages", indexes );
@@ -256,17 +270,17 @@ QStringList Config::mimePaths()
 
     if( lst.count() > 0 )
 	return lst;
-    
+
     for (QMap<QString,QString>::ConstIterator it = profil->dcfTitles.begin();
 	 it != profil->dcfTitles.end(); ++it ) {
 
 	// Mime source for .dcf file path
-	QFileInfo info( *it ); 
+	QFileInfo info( *it );
 	QString dcfPath = info.dirPath(TRUE);
 	if (lst.contains(dcfPath) == 0)
 	    lst << dcfPath;
-	
-	// Image dir for .dcf 	
+
+	// Image dir for .dcf
 	QString imgDir = QDir::convertSeparators( dcfPath + QDir::separator()
 						  + profil->imageDirs[it.key()] );
 	if (lst.contains(imgDir) == 0)
@@ -300,9 +314,9 @@ QString Config::homePage() const
     return home.isEmpty() ? profil->props["startpage"] : home;
 }
 
-QString Config::source() const
+QStringList Config::source() const
 {
-    return src.isEmpty() ? profil->props["startpage"] : src;
+    return src.size() == 0 ? QStringList(profil->props["startpage"]) : src;
 }
 
 QStringList Config::docFiles() const
@@ -336,7 +350,7 @@ QString Config::docImageDir( const QString &docfile ) const
 QString Config::indexPage( const QString &title ) const
 {
     return profil->indexPages
-	[title];    
+	[title];
 }
 
 void Config::hideSideBar( bool b )
