@@ -29,9 +29,10 @@
 
 #include <qtextbrowser.h>
 
-class QMouseEvent;
 class MainWindow;
+class QKeyEvent;
 class QMime;
+class QMouseEvent;
 
 class HelpWindow : public QTextBrowser
 {
@@ -45,13 +46,14 @@ public:
     void openLinkInNewPage( const QString &link );
     void addMimePath( const QString &path );
 
+    void contentsMousePressEvent(QMouseEvent *e);
+    void keyPressEvent(QKeyEvent *);
+
 signals:
     void chooseWebBrowser();
 
-protected:
-    void keyPressEvent( QKeyEvent *e );
-    void keyReleaseEvent( QKeyEvent *e );
-
+public slots:
+    void copy();
 protected slots:
     void ensureCursorVisible();
 
@@ -60,11 +62,11 @@ private slots:
     void openLinkInNewPage();
 
 private:
-    void setCharacterEncoding( const QString &name );
     MainWindow *mw;
-    bool shiftPressed;
     QString lastAnchor;
     bool blockScroll;
+    bool shiftPressed;
+    bool newWindow;
     QMimeSourceFactory *mimeSourceFactory;
 
 };
