@@ -487,8 +487,10 @@ void MainWindow::showSettingsDialog( int page )
 	settingsDia = new SettingsDialog( this );
     }
     QFontDatabase fonts;
+    settingsDia->fontCombo->clear();
     settingsDia->fontCombo->insertStringList( fonts.families() );
     settingsDia->fontCombo->lineEdit()->setText( tabs->browserFont().family() );
+    settingsDia->fixedfontCombo->clear();
     settingsDia->fixedfontCombo->insertStringList( fonts.families() );
     settingsDia->fixedfontCombo->lineEdit()->setText( tabs->styleSheet()->item( "pre" )->fontFamily() );
     settingsDia->linkUnderlineCB->setChecked( tabs->linkUnderline() );
