@@ -362,13 +362,18 @@ DeleteCommand::DeleteCommand( const QString &n, FormWindow *fw,
     : Command( n, fw ), widgets( wl )
 {
     widgets.setAutoDelete( FALSE );
-
+    QWidgetList copyOfWidgets = widgets;
+    copyOfWidgets.setAutoDelete(FALSE);
+    
     // Include the children of the selected items when deleting
     for ( QWidget *w = widgets.first(); w; w = widgets.next() ) {
 	QObjectList *children = w->queryList( "QWidget" );
 	for ( QWidget *c = (QWidget *)children->first(); c; c = (QWidget *)children->next() ) {
-	    if ( widgets.find( c ) == -1 && formWindow()->widgets()->find( c ) )
-		widgets.append( c );
+	    if ( copyOfWidgets.find( c ) == -1 && formWindow()->widgets()->find( c ) ) {
+		widgets.insert(widgets.at() + 1, c);
+		widgets.prev();
+		copyOfWidgets.append(c);
+	    }
 	}
 	delete children;
     }
@@ -1890,6 +1895,7 @@ void AddToolBarCommand::unexecute()
 
 // ------------------------------------------------------------
 
+#ifdef QT_CONTAINER_CUSTOM_WIDGETS
 AddContainerPageCommand::AddContainerPageCommand( const QString &n, FormWindow *fw,
 						  QWidget *c, const QString &label )
     : Command( n, fw ), container( c ), index( -1 ), pageLabel( label ), page( 0 )
@@ -2022,7 +2028,7 @@ void RenameContainerPageCommand::unexecute()
     formWindow()->emitUpdateProperties( formWindow()->currentWidget() );
     // #### show and update pages in object hierarchy view
 }
-
+#endif // QT_CONTAINER_CUSTOM_WIDGETS
 // ------------------------------------------------------------
 
 AddActionToPopupCommand::AddActionToPopupCommand( const QString &n,
@@ -2305,7 +2311,8 @@ QString RenameMenuCommand::makeLegal( const QString &str )
 	c = str.at(i).latin1();
 	if ( c == '-' || c == ' ' )
 	    d += '_';
-	else if ( ( c > 47 && c < 91 ) || c == 95 || ( c > 96 && c < 123 ) )
+	else if ( ( c >= '0' && c <= '9') || ( c >= 'A' && c <= 'Z' )
+                  || c == '_' || ( c >= 'a' && c <= 'z' ) )
 	    d += c;
 	++i;
     }
