@@ -8,10 +8,16 @@
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
+** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
+** licenses may use this file in accordance with the Qt Commercial License
+** Agreement provided with the Software.
+**
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
+** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
+**   information about Qt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -21,8 +27,7 @@
 #ifndef DESIGNERAPP_H
 #define DESIGNERAPP_H
 
-class QLabel;
-
+class QSplashScreen;
 
 #include <qapplication.h>
 
@@ -33,7 +38,7 @@ public:
 
     DesignerApplication( int &argc, char **argv );
 
-    QLabel *showSplash();
+    QSplashScreen *showSplash();
     static void closeSplash();
 
     static QString settingsKey();
@@ -50,5 +55,4 @@ protected:
 
 };
 
-
 #endif
