@@ -484,10 +484,13 @@ QString FormFile::codeComment() const
     return QString( "/****************************************************************************\n"
     "** ui.h extension file, included from the uic-generated form implementation.\n"
     "**\n"
-    "** If you wish to add, delete or rename functions or slots use\n"
-    "** Qt Designer which will update this file, preserving your code. Create an\n"
-    "** init() function in place of a constructor, and a destroy() function in\n"
-    "** place of a destructor.\n"
+    "** If you want to add, delete, or rename functions or slots, use\n"
+    "** Qt Designer to update this file, preserving your code.\n"
+    "**\n"
+    "** You should not define a constructor or destructor in this file.\n"
+    "** Instead, write your code in functions called init() and destroy().\n"
+    "** These will automatically be called by the form's constructor and\n"
+    "** destructor.\n"
     "*****************************************************************************/\n" );
 }
 
