@@ -117,7 +117,7 @@ PopupMenuEditorItem::PopupMenuEditorItem( QAction * action, PopupMenuEditor * me
       removable( TRUE )
 {
     init();
-    if ( /*a->name() == "qt_separator_action" ||*/ a->inherits( "QSeparatorAction" ) )
+    if ( /*a->name() == "qt_separator_action" ||*/ ::qt_cast<QSeparatorAction*>(a) )
 	separator = TRUE;
     if ( a && a->children() )
  	a->installEventFilter( this );
@@ -148,7 +148,7 @@ void PopupMenuEditorItem::init()
 	QObject::connect( a, SIGNAL( destroyed() ), this, SLOT( selfDestruct() ) );
 	if ( m && !isSeparator() ) {
 	    s = new PopupMenuEditor( m->formWindow(), m );
-	    QString n = "PopupMenuEditor";
+	    QString n = "popupMenu";
 	    m->formWindow()->unify( s, n, TRUE );
 	    s->setName( n );
 	    MetaDataBase::addEntry( s );
@@ -361,7 +361,7 @@ void PopupMenuEditor::insert( QActionGroup * actionGroup, int index )
     for ( ; it.current(); ++it ) {
 	g = ::qt_cast<QActionGroup*>(it.current());
 	if ( g ) {
-	    if ( dropdown )	    
+	    if ( dropdown )
 		i->s->insert( g );
 	    else
 		insert( g );
@@ -619,7 +619,12 @@ void PopupMenuEditor::remove( int index )
 PopupMenuEditorItem * PopupMenuEditor::createItem( QAction * a )
 {
     ActionEditor * ae = (ActionEditor *) formWindow()->mainWindow()->child( 0, "ActionEditor" );
-    PopupMenuEditorItem * i = new PopupMenuEditorItem( a ? a : ae->newActionEx(), this );
+    if ( !a )
+	a = ae->newActionEx();
+    PopupMenuEditorItem * i = new PopupMenuEditorItem( a, this );
+    QString n = QString( a->name() ) + "Item";
+    formWindow()->unify( i, n, FALSE );
+    i->setName( n );
     AddActionToPopupCommand * cmd =
 	new AddActionToPopupCommand( "Add Item", formWnd, this, i );
     formWnd->commandHistory()->addCommand( cmd );
@@ -850,10 +855,12 @@ void PopupMenuEditor::dropEvent( QDropEvent * e )
 	PopupMenuEditorItemPtrDrag::decode( e, &i );
     } else {
 	if ( e->provides( "application/x-designer-actiongroup" ) ) {
-	    QString s( e->encodedData( "application/x-designer-actiongroup" ) );
-	    QActionGroup * g = (QDesignerActionGroup*)s.toLong();
+	    QActionGroup * g = ::qt_cast<QDesignerActionGroup*>(ActionDrag::action());
 	    if ( g->usesDropDown() ) {
 		i = new PopupMenuEditorItem( g, this );
+		QString n = QString( g->name() ) + "Item";
+		formWindow()->unify( i, n, FALSE );
+		i->setName( n );
 		QObjectList *l = g->queryList( "QAction", 0, FALSE, FALSE );
 		QObjectListIterator it( *l );
 		for ( ; it.current(); ++it ) {
@@ -868,8 +875,7 @@ void PopupMenuEditor::dropEvent( QDropEvent * e )
 		dropInPlace( g, e->pos().y() );
 	    }
 	} else if ( e->provides( "application/x-designer-actions" ) ) {
-	    QString s( e->encodedData( "application/x-designer-actions" ) );
-	    QAction * a = (QDesignerAction*)s.toLong();
+	    QAction *a = ::qt_cast<QDesignerAction*>(ActionDrag::action());
 	    i = new PopupMenuEditorItem( a, this );
 	}
     }
@@ -878,7 +884,7 @@ void PopupMenuEditor::dropEvent( QDropEvent * e )
 	dropInPlace( i, e->pos().y() );
 	QTimer::singleShot( 0, this, SLOT( resizeToContents() ) );
     }
-    
+
     QTimer::singleShot( 0, this, SLOT( showSubMenu() ) );
     QTimer::singleShot( 0, this, SLOT( setFocus() ) );
     dropLine->hide();
@@ -1004,12 +1010,12 @@ void PopupMenuEditor::focusInEvent( QFocusEvent * )
 void PopupMenuEditor::focusOutEvent( QFocusEvent * )
 {
     QWidget * fw = qApp->focusWidget();
-    if ( !fw || ( !fw->inherits( "PopupMenuEditor" ) && fw != lineEdit ) ) {
+    if ( !fw || ( !::qt_cast<PopupMenuEditor*>(fw) && fw != lineEdit ) ) {
 	hideSubMenu();
-	if ( fw && fw->inherits( "MenuBarEditor" ) )
+	if ( fw && ::qt_cast<MenuBarEditor*>(fw) )
 	    return;
 	QWidget * w = this;
-	while ( w && w != fw && w->inherits( "PopupMenuEditor" ) ) { // hide all popups
+	while ( w && w != fw && ::qt_cast<PopupMenuEditor*>(w) ) { // hide all popups
 	    w->hide();
 	    w = ((PopupMenuEditor *)w)->parentEditor();
 	}
@@ -1083,7 +1089,7 @@ void PopupMenuEditor::drawItems( QPainter * p )
 {
     int flags = 0;
     int idx = 0;
-    
+
     QColorGroup enabled = colorGroup();
     QColorGroup disabled = palette().disabled();
     QRect focus;
@@ -1231,12 +1237,15 @@ void PopupMenuEditor::dropInPlace( PopupMenuEditorItem * i, int y )
 
 void PopupMenuEditor::dropInPlace( QActionGroup * g, int y )
 {
+    if (!g->children())
+	return;
     QObjectList l = *g->children();
-    for ( QAction *a = (QAction *)l.last(); a; a = (QAction *)l.prev() ) {
-	QActionGroup *g = ::qt_cast<QActionGroup*>(a);
-	if ( g ) 
+    for ( int i = 0; i < (int)l.count(); ++i ) {
+	QAction *a = ::qt_cast<QAction*>(l.at(i));
+	QActionGroup *g = ::qt_cast<QActionGroup*>(l.at(i));
+	if ( g )
 	    dropInPlace( g, y );
-	else 
+	else if ( a )
 	    dropInPlace( new PopupMenuEditorItem( a, this ), y );
     }
 }
@@ -1394,17 +1403,21 @@ void PopupMenuEditor::leaveEditMode( QKeyEvent * e )
  	update();
 	return;
     }
-	
+
     if ( currentIndex >= (int)itemList.count() ) {
 	// new item was created
 	QAction * a = formWnd->mainWindow()->actioneditor()->newActionEx();
-	a->setText( lineEdit->text() );
-	a->setMenuText( lineEdit->text() );
+	QString actionText = lineEdit->text();
+	actionText.replace("&&", "&");
+	QString menuText = lineEdit->text();
+	a->setText( actionText );
+	a->setMenuText( menuText );
 	i = createItem( a );
 	QString n = constructName( i );
 	formWindow()->unify( a, n, TRUE );
 	a->setName( n );
 	MetaDataBase::addEntry( a );
+	MetaDataBase::setPropertyChanged( a, "menuText", TRUE );
 	ActionEditor *ae = (ActionEditor*)formWindow()->mainWindow()->child( 0, "ActionEditor" );
 	if ( ae )
 	    ae->updateActionName( a );
@@ -1448,7 +1461,7 @@ QString PopupMenuEditor::constructName( PopupMenuEditorItem *item )
 	}
     }
     // replace illegal characters
- 
+
     return ( RenameMenuCommand::makeLegal( s ) +
 	     RenameMenuCommand::makeLegal( name ) + "Action" );
 }
