@@ -337,6 +337,8 @@ QStringList parse_multiline_part( const QString &contents, const QString &key, i
     if ( start )
 	*start = -1;
     QString lastWord;
+    // Account for things like win32: SOURCES
+    int extraWhiteSpaceCount = 0;
     int braceCount = 0;
     for ( int i = 0; i < (int)contents.length(); ++i ) {
 	QChar c( contents[ i ] );
@@ -349,9 +351,20 @@ QStringList parse_multiline_part( const QString &contents, const QString &key, i
 	    braceCount--;
 	    lastWord = "";
 	    break;
-	case ' ': case '\t': case '\\': case '\n':
+	case ' ': case '\t':
+	    if (!key.startsWith(lastWord)) {
+		lastWord = "";
+		extraWhiteSpaceCount = 0;
+	    } else {
+		extraWhiteSpaceCount++;
+	    }
+	    break;
+	case '\\': case '\n':
 	    lastWord = "";
 	    break;
+        case '#':
+            while ( contents[ i ] != '\n' && i < contents.length() )
+                ++i;
 	default:
 	    lastWord += c;
 	}
@@ -359,7 +372,7 @@ QStringList parse_multiline_part( const QString &contents, const QString &key, i
 	// ### we should read the 'bla { SOURCES= ... }' stuff as well (braceCount > 0)
 	if ( lastWord == key && braceCount == 0 ) {
 	    if ( start )
-		*start = i - lastWord.length() + 1;
+		*start = i - lastWord.length() - extraWhiteSpaceCount + 1;
 	    QStringList lst;
 	    bool inName = FALSE;
 	    QString currName;
@@ -372,9 +385,26 @@ QStringList parse_multiline_part( const QString &contents, const QString &key, i
 		    hadEqual = TRUE;
 		    continue;
 		}
-		if ( ( c.isLetter() || c.isDigit() || c == '.' || c == '/' || c == '_' || c == '\\' ||
-		       c == '\"' || c == '\'' || c == '=' ||
-		       c == '$' || c == '-' || c == '(' || c == ')' || c == ':'  || c == '+' || c == ',' || c == '~' ) &&
+		if ( ( c.isLetter() ||
+                       c.isDigit() ||
+                       c == '.' ||
+                       c == '/' ||
+                       c == '_' ||
+                       c == '\\' ||
+		       c == '\"' ||
+                       c == '\'' ||
+                       c == '=' ||
+                       c == '$' ||
+                       c == '-' ||
+                       c == '(' ||
+                       c == ')' ||
+                       c == ':' ||
+                       c == '+' ||
+                       c == ',' ||
+                       c == '~' ||
+                       c == '{' ||
+                       c == '}' ||
+                       c == '@' ) &&
 		     c != ' ' && c != '\t' && c != '\n' ) {
 		    if ( !inName )
 			currName = QString::null;
@@ -448,6 +478,8 @@ void Project::parse()
     readPlatformSettings( contents, "LIBS", lbs );
     readPlatformSettings( contents, "INCLUDEPATH", inclPath );
     readPlatformSettings( contents, "DEFINES", defs );
+    readPlatformSettings( contents, "SOURCES", sources );
+    readPlatformSettings( contents, "HEADERS", headers );
 
     LanguageInterface *iface = MetaDataBase::languageInterface( lang );
     if ( iface ) {
@@ -572,7 +604,7 @@ static void remove_multiline_contents( QString &contents, const QString &s, int
     if ( strt )
 	*strt = i;
     int start = i;
-    bool lastWasBackspash = FALSE;
+    bool lastWasBackspash = TRUE;
     if ( i != -1 && ( i == 0 || contents[ i - 1 ] != '{' || contents[ i - 1 ] != ':' ) ) {
 	for ( ; i < (int)contents.length(); ++i ) {
 	    if ( contents[ i ] == '\n' && !lastWasBackspash )
@@ -619,30 +651,41 @@ void Project::save( bool onlyProjectFile )
     }
 
     QFile f( filename );
-    QString contents = "";
+    QString original = "";
 
     // read the existing file
     bool hasPreviousContents = FALSE;
     if ( f.open( IO_ReadOnly ) ) {
 	QTextStream ts( &f );
-	contents = ts.read();
+	original = ts.read();
 	f.close();
 	hasPreviousContents = TRUE;
-	remove_contents( contents, "{SOURCES+=" ); // ### compatibility with early 3.0 betas
-	remove_contents( contents, "DBFILE" );
-	remove_contents( contents, "LANGUAGE" );
-	remove_contents( contents, "TEMPLATE" );
-	removePlatformSettings( contents, "CONFIG" );
-	removePlatformSettings( contents, "DEFINES" );
-	removePlatformSettings( contents, "LIBS" );
-	removePlatformSettings( contents, "INCLUDEPATH" );
-	remove_multiline_contents( contents, "FORMS" );
-	remove_multiline_contents( contents, "INTERFACES" ); // compatibility
-	remove_multiline_contents( contents, "IMAGES" );
+	remove_contents( original, "{SOURCES+=" ); // ### compatibility with early 3.0 betas
+	remove_contents( original, "DBFILE" );
+	remove_contents( original, "LANGUAGE" );
+	remove_contents( original, "TEMPLATE" );
+	removePlatformSettings( original, "CONFIG" );
+	removePlatformSettings( original, "DEFINES" );
+	removePlatformSettings( original, "LIBS" );
+	removePlatformSettings( original, "INCLUDEPATH" );
+	removePlatformSettings( original, "SOURCES" );
+	removePlatformSettings( original, "HEADERS" );
+	remove_multiline_contents( original, "FORMS" );
+	remove_multiline_contents( original, "INTERFACES" ); // compatibility
+	remove_multiline_contents( original, "IMAGES" );
 	for ( QStringList::Iterator it = csList.begin(); it != csList.end(); ++it )
-	    remove_contents( contents, *it );
+	    remove_contents( original, *it );
     }
 
+    if (!original.isEmpty()) {
+	// Removes any new lines at the beginning of the file
+	while (original.startsWith("\n"))
+	    original.remove(0, 1);
+    }
+
+    // the contents of the saved file
+    QString contents;
+
     // template
     contents += "TEMPLATE\t= " + templ + "\n";
 
@@ -659,12 +702,13 @@ void Project::save( bool onlyProjectFile )
 	for ( QStringList::Iterator spit = sourceKeys.begin(); spit != sourceKeys.end(); ++spit )
 	    remove_multiline_contents( contents, *spit );
     }
-    contents += "\n";
 
     // libs, defines, includes
     writePlatformSettings( contents, "LIBS", lbs );
     writePlatformSettings( contents, "DEFINES", defs );
     writePlatformSettings( contents, "INCLUDEPATH", inclPath );
+    writePlatformSettings( contents, "SOURCES", sources );
+    writePlatformSettings( contents, "HEADERS", headers );
 
     // unix
     if ( !hasPreviousContents ) {
@@ -673,9 +717,8 @@ void Project::save( bool onlyProjectFile )
  	    "  UI_DIR = .ui\n"
  	    "  MOC_DIR = .moc\n"
  	    "  OBJECTS_DIR = .obj\n"
- 	    "}\n";
+ 	    "}\n\n";
     }
-    contents += "\n";
 
     // sources
     if ( !sourcefiles.isEmpty() && iface ) {
@@ -696,7 +739,7 @@ void Project::save( bool onlyProjectFile )
 		part += ++sit != lst.end() ? " \\\n\t" : "";
 		--sit;
 	    }
-	    part += "\n";
+	    part += "\n\n";
 	    contents += part;
 	}
     }
@@ -708,7 +751,7 @@ void Project::save( bool onlyProjectFile )
 	    contents += fit.current()->fileName() +
 		 (fit != formfiles.last() ? " \\\n\t" : "");
 	}
-	contents += "\n";
+	contents += "\n\n";
     }
 
     // images
@@ -721,13 +764,12 @@ void Project::save( bool onlyProjectFile )
 		  contents += ++it != pixmaps.end() ? " \\\n\t" : "";
 		  --it;
 	}
-	contents += "\n";
+	contents += "\n\n";
     }
 
     // database
     if ( !dbFile.isEmpty() )
 	contents += "DBFILE\t= " + dbFile + "\n";
-    contents += "\n";
 
     // custom settings
     for ( QStringList::Iterator it = csList.begin(); it != csList.end(); ++it ) {
@@ -744,6 +786,8 @@ void Project::save( bool onlyProjectFile )
 
     QTextStream os( &f );
     os << contents;
+    if (hasPreviousContents)
+        os << original;
 
     f.close();
 
@@ -1230,7 +1274,12 @@ void Project::writePlatformSettings( QString &contents, const QString &setting,
 				     const QMap<QString, QString> &input )
 {
     const QString platforms[] = { "", "win32", "unix", "mac", QString::null };
-    for ( int i = 0; platforms[ i ] != QString::null; ++i ) {
+    int i;
+    if (setting == "SOURCES" || setting == "HEADERS") // The (all) part will be saved later on
+	i = 1;
+    else
+	i = 0;
+    for (; platforms[ i ] != QString::null; ++i ) {
 	QString p = platforms[ i ];
 	if ( !p.isEmpty() )
 	    p += ":";
@@ -1240,7 +1289,7 @@ void Project::writePlatformSettings( QString &contents, const QString &setting,
 	QMap<QString, QString>::ConstIterator it = input.find( key );
 	if ( it == input.end() || (*it).isEmpty() )
 	    continue;
-	contents += p + setting + "\t+= " + *it + "\n";
+	contents += p + setting + "\t+= " + *it + "\n\n";
     }
 }
 
