@@ -42,7 +42,7 @@ class FileDialog : public QFileDialog
     Q_OBJECT
 
 public:
-    FileDialog( QWidget *parent );
+    FileDialog( const QString &dir, QWidget *parent );
 
 protected slots:
     void accept();
