@@ -1409,7 +1409,12 @@ void WidgetFactory::editWidget( int id, QWidget *parent, QWidget *editWidget, Fo
 	if ( !::qt_cast<QComboBox*>(editWidget) )
 	    return;
 	QComboBox *cb = (QComboBox*)editWidget;
-	ListBoxEditor *e = new ListBoxEditor( parent, cb->listBox(), fw );
+        QListBox *lb = cb->listBox();
+        if (!lb) {
+            lb = new QListBox(cb);
+            cb->setListBox(lb);
+        }
+	ListBoxEditor *e = new ListBoxEditor( parent, lb, fw );
 	e->exec();
 	delete e;
 	cb->update();
@@ -1740,6 +1745,24 @@ QWidget *CustomWidgetFactory::createWidget( const QString &className, QWidget *p
     return WidgetFactory::createCustomWidget( parent, name, w );
 }
 
+void QDesignerRadioButton::setFocusPolicy( FocusPolicy policy )
+{
+    // Make sure we only set a policy that has a key.
+    // If we set a policy that is a combination of enums, it will be imposible to save
+    // We need this check because QButtonGroup::buttonToggled(...) will remove TabFocus,
+    // making the policy StrongFocus & ~TabFocus
+    
+    switch ( policy ) {
+    case NoFocus:
+    case TabFocus:
+    case ClickFocus:
+    case StrongFocus:
+    case WheelFocus:
+        QRadioButton::setFocusPolicy( policy );
+        return;
+    }
+    QRadioButton::setFocusPolicy( NoFocus );
+}
 
 QDesignerToolBox::QDesignerToolBox( QWidget *parent, const char *name )
     : QToolBox( parent, name )
