@@ -9,10 +9,16 @@
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
+** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
+** licenses may use this file in accordance with the Qt Commercial License
+** Agreement provided with the Software.
+**
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
+** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
+**   information about Qt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -208,7 +214,7 @@ static int getToken()
 	    case HASH( 's', 6 ):
 		CHECK( "signed" );
 		return Tok_signed;
-	    case 'u':
+	    case HASH( 'u', 8 ):
 		CHECK( "unsigned" );
 		return Tok_unsigned;
 	    }
@@ -474,6 +480,12 @@ static void prependToType( QString *type, const QString& prefix )
     type->prepend( prefix );
 }
 
+static bool isModifier( int tok )
+{
+    return ( tok == Tok_signed || tok == Tok_unsigned ||
+	     tok == Tok_short || tok == Tok_long );
+}
+
 /*
   Parses a data type (backwards as usual) and returns a textual
   representation of it.
@@ -493,7 +505,7 @@ static QString matchDataType()
       Alpha::Beta::Gamma::...::Omega.
     */
     for ( ;; ) {
-	bool virgin = TRUE;
+	bool modifierMet = FALSE;
 
 	prependToType( &type, matchTemplateAngles() );
 
@@ -502,13 +514,11 @@ static QString matchDataType()
 	      People may write 'const unsigned short' or
 	      'short unsigned const' or any other permutation.
 	    */
-	    while ( yyTok == Tok_const || yyTok == Tok_signed ||
-		    yyTok == Tok_unsigned || yyTok == Tok_short ||
-		    yyTok == Tok_long ) {
+	    while ( yyTok == Tok_const || isModifier(yyTok) ) {
 		prependToType( &type, yyLex );
 		yyTok = getToken();
 		if ( yyTok != Tok_const )
-		    virgin = FALSE;
+		    modifierMet = TRUE;
 	    }
 
 	    if ( yyTok == Tok_Tilde ) {
@@ -517,7 +527,7 @@ static QString matchDataType()
 	    }
 	}
 
-	if ( virgin ) {
+	if ( !modifierMet ) {
 	    if ( yyTok == Tok_Ellipsis || yyTok == Tok_Ident ||
 		 yyTok == Tok_char || yyTok == Tok_int ||
 		 yyTok == Tok_double ) {
@@ -532,7 +542,7 @@ static QString matchDataType()
 	    yyTok = getToken();
 	}
 
-	while ( yyTok == Tok_const ) {
+	while ( yyTok == Tok_const || isModifier(yyTok) ) {
 	    prependToType( &type, yyLex );
 	    yyTok = getToken();
 	}
