@@ -302,8 +302,12 @@ QString Uic::createObjectImpl( const QDomElement &e, const QString& parentClass,
 	for ( n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
 	    if ( tags.contains( n.tagName()  ) ) {
 		QString page = createObjectImpl( n, objClass, objName );
-		QString label = DomTool::readAttribute( n, "label", "" ).toString();
-		out << indent << objName << "->addItem( " << page << ", \"" << label << "\" );" << endl;
+		QString comment;
+		QString label = DomTool::readAttribute( n, "label", "", comment ).toString();
+		out << indent << objName << "->addItem( " << page << ", QString(\"\") );" << endl;
+		trout << indent << objName << "->setItemLabel( " << objName 
+		      << "->indexOf(" << page << "), " << trcall( label, comment ) 
+		      << " );" << endl;
 	    }
 	}
      } else if ( objClass != "QToolBar" && objClass != "QMenuBar" ) { // standard widgets
