@@ -372,7 +372,7 @@ void Uic::createMenuBarDecl( const QDomElement &e )
 void Uic::createPopupMenuDecl( const QDomElement &e )
 {
     for ( QDomElement n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
-	if ( n.tagName() == "action" ) {
+	if ( n.tagName() == "action" || n.tagName() == "actiongroup" ) {
 	    QDomElement n2 = n.nextSibling().toElement();
 	    if ( n2.tagName() == "item" ) { // the action has a sub menu
 		out << "    " << "QPopupMenu *" << n2.attribute( "name" ) << ";" << endl;
@@ -515,7 +515,7 @@ void Uic::createPopupMenuImpl( const QDomElement &e, const QString &parentClass,
 {
     int i = 0;
     for ( QDomElement n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
-	if ( n.tagName() == "action" ) {
+	if ( n.tagName() == "action" || n.tagName() == "actiongroup" ) {
 	    QDomElement n2 = n.nextSibling().toElement();
 	    if ( n2.tagName() == "item" ) { // the action has a sub menu
 		QString itemName = n2.attribute( "name" );
@@ -530,8 +530,6 @@ void Uic::createPopupMenuImpl( const QDomElement &e, const QString &parentClass,
 	    } else {
 		out << indent << n.attribute( "name" ) << "->addTo( " << parent << " );" << endl;
 	    }
-	} else if (n.tagName() == "actiongroup") {
-	    out << indent << n.attribute( "name" ) << "->addTo( " << parent << " );" << endl;
 	} else if ( n.tagName() == "separator" ) {
 	    out << indent << parent << "->insertSeparator();" << endl;
 	}
