@@ -2335,10 +2335,16 @@ void QWidgetFactory::createItem( const QDomElement &e, QWidget *widget, QListVie
 	QString txt;
 	loadItem( n, pix, txt, hasPixmap );
 	QListBox *lb = 0;
-	if ( widget->inherits( "QListBox" ) )
+	if ( widget->inherits( "QListBox" ) ) {
 	    lb = (QListBox*)widget;
-	else
-	    lb = ( (QComboBox*)widget)->listBox();
+	} else {
+            QComboBox *cb = (QComboBox*)widget;
+	    lb = cb->listBox();
+            if (!lb) {
+                lb = new QListBox(cb);
+                cb->setListBox(lb);
+            }
+        }
 	if ( hasPixmap ) {
 	    new QListBoxPixmap( lb, pix, txt );
 	} else {
@@ -2512,7 +2518,7 @@ void QWidgetFactory::loadPopupMenu( QPopupMenu *p, const QDomElement &e )
     QMainWindow *mw = ( (QMainWindow*)toplevel );
     QDomElement n = e.firstChild().toElement();
     while ( !n.isNull() ) {
-	if ( n.tagName() == "action" ) {
+	if ( n.tagName() == "action" || n.tagName() == "actiongroup" ) {
 	    QAction *a = findAction( n.attribute( "name" ) );
 	    QDomElement n2 = n.nextSibling().toElement();
 	    if ( n2.tagName() == "item") { // load submenu
