@@ -89,7 +89,6 @@ QString richText( const QString& text )
 	QT_TRANSLATE_NOOP( "MessageEditor", "tab" )
     };
     QString rich;
-    int lastSpace = -2;
 
     for ( int i = 0; i < (int) text.length(); i++ ) {
 	int ch = text[i].unicode();
@@ -107,11 +106,11 @@ QString richText( const QString& text )
 	} else if ( ch == '&' ) {
 	    rich += QString( "&amp;" );
 	} else if ( ch == ' ' ) {
-	    if ( lastSpace == i - 1 )
-		rich += QChar( 0x00a0 );
-	    else
+	    if ( text[i - 1] == ' ' || text[i + 1] == ' ' ) {
+		rich += richMeta( MessageEditor::tr("sp") );
+	    } else {
 		rich += ' ';
-	    lastSpace = i;
+	    }
 	} else {
 	    rich += QChar( ch );
 	}
@@ -678,7 +677,7 @@ void MessageEditor::showMessage( const QString& text,
     for ( p = phrases.begin(); p != phrases.end(); ++p )
  	(void) new PhraseLVI( phraseLv, *p );
 
-    if ( doGuesses ) {
+    if ( doGuesses && !sourceText.isEmpty() ) {
 	CandidateList cl = similarTextHeuristicCandidates( tor,
 							   sourceText.latin1(),
 							   MaxCandidates );
