@@ -205,7 +205,6 @@ CandidateList similarTextHeuristicCandidates( const MetaTranslator *tor,
 	int score = ( (intersection(cm, cmTarget).worth() + 1) << 10 ) /
 		    ( reunion(cm, cmTarget).worth() + (delta << 1) + 1 );
 
-	bool goOn = FALSE; // ### revert this for 4.0 - IRIX o32 compat.
 	if ( (int) candidates.count() == maxCandidates &&
 	     score > scores[maxCandidates - 1] )
 	    candidates.remove( candidates.last() );
@@ -216,20 +215,18 @@ CandidateList similarTextHeuristicCandidates( const MetaTranslator *tor,
 	    for ( i = 0; i < (int) candidates.count(); i++ ) {
 		if ( score >= scores[i] ) {
 		    if ( score == scores[i] ) {
-			if ( candidates[i] == cand ) {
-			    goOn = TRUE;  // ### revert this for 4.0 - IRIX o32 compat.
-			    break;
-			}
+			if ( candidates[i] == cand )
+			    goto continue_outer_loop;
 		    } else {
 			break;
 		    }
 		}
 	    }
-	    if ( goOn )  // ### revert this for 4.0 - IRIX o32 compat.
-		continue;
 	    scores.insert( scores.at(i), score );
 	    candidates.insert( candidates.at(i), cand );
 	}
+    continue_outer_loop:
+	;
     }
     return candidates;
 }
