@@ -8,10 +8,16 @@
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
+** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
+** licenses may use this file in accordance with the Qt Commercial License
+** Agreement provided with the Software.
+**
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
+** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
+**   information about Qt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -31,6 +37,7 @@
 #include "printout.h"
 #include "about.h"
 #include "phraselv.h"
+#include "statistics.h"
 
 #include <qaccel.h>
 #include <qaction.h>
@@ -286,10 +293,7 @@ TrWindow::TrWindow()
     foundWhere = 0;
     foundOffset = 0;
 
-    connect( lv, SIGNAL(currentChanged(QListViewItem *)),
-	     this, SLOT(showNewScope(QListViewItem *)) );
-
-    connect( lv, SIGNAL(clicked(QListViewItem *, const QPoint&, int)),
+    connect( lv, SIGNAL(selectionChanged(QListViewItem *)),
 	     this, SLOT(showNewScope(QListViewItem *)) );
 
     connect( slv, SIGNAL(currentChanged(QListViewItem *)),
@@ -322,11 +326,16 @@ TrWindow::TrWindow()
     as -= QSize( 30, 30 );
     resize( QSize( 1000, 800 ).boundedTo( as ) );
     readConfig();
+    stats = 0;
+    srcWords = 0;
+    srcChars = 0;
+    srcCharsSpc = 0;
 }
 
 TrWindow::~TrWindow()
 {
     writeConfig();
+    delete stats;
 }
 
 void TrWindow::openFile( const QString& name )
@@ -334,6 +343,7 @@ void TrWindow::openFile( const QString& name )
     if ( !name.isEmpty() ) {
 	statusBar()->message( tr("Loading...") );
 	qApp->processEvents();
+	tor.clear();
 	if ( tor.load(name) ) {
 	    slv->clear();
 	    slv->repaint();
@@ -355,6 +365,9 @@ void TrWindow::openFile( const QString& name )
 	    TML::Iterator it;
 	    QDict<ContextLVI> contexts( 1009 );
 
+	    srcWords = 0;
+	    srcChars = 0;
+	    srcCharsSpc = 0;
 	    for ( it = all.begin(); it != all.end(); ++it ) {
 		qApp->processEvents();
 		ContextLVI *c = contexts.find( QString((*it).context()) );
@@ -363,7 +376,7 @@ void TrWindow::openFile( const QString& name )
 							  (*it).utf8()) );
 		    contexts.insert( QString((*it).context()), c );
 		}
-		if ( (*it).sourceText()[0] == '\0' ) {
+		if ( QCString((*it).sourceText()) == ContextComment ) {
 		    c->appendToComment( tor.toUnicode((*it).comment(),
 						      (*it).utf8()) );
 		} else {
@@ -377,11 +390,11 @@ void TrWindow::openFile( const QString& name )
 				    tmp->message().type() ==
 				    MetaTranslatorMessage::Finished );
 		    c->instantiateMessageItem( slv, tmp );
-
 		    if ( (*it).type() != MetaTranslatorMessage::Obsolete ) {
 			numNonobsolete++;
 			if ( (*it).type() == MetaTranslatorMessage::Finished )
 			    numFinished++;
+			doCharCounting( tmp->sourceText(), srcWords, srcChars, srcCharsSpc );
 		    } else {
 			c->incrementObsoleteCount();
 		    }
@@ -421,6 +434,7 @@ void TrWindow::openFile( const QString& name )
 		lv->setCurrentItem( lv->firstChild() );
 	    }
 	    addRecentlyOpenedFile( name, recentFiles );
+	    updateStatistics();
 	} else {
 	    statusBar()->clear();
 	    QMessageBox::warning( this, tr("Qt Linguist"),
@@ -831,13 +845,8 @@ void TrWindow::revertSorting()
 
 void TrWindow::manual()
 {
-    QString path = QDir::cleanDirPath( QString( qInstallPath() ) +
-				       QDir::separator() + "bin/" );
-#if defined(Q_OS_MACX)
-    path += QDir::separator() + ".app/Contents/MacOS/";
-#endif
-    QAssistantClient *ac = new QAssistantClient( path, this );
-    ac->showPage( QString( qInstallPath() ) + "/doc/html/linguist-manual.html" );
+    QAssistantClient *ac = new QAssistantClient( qInstallPathBins(), this );
+    ac->showPage( QString( qInstallPathDocs() ) + "/html/linguist-manual.html" );
 }
 
 void TrWindow::about()
@@ -882,7 +891,7 @@ bool TrWindow::maybeSave()
 		return FALSE;
 	    case QMessageBox::Yes:
 		save();
-		break;
+                return !dirty;
 	    case QMessageBox::No:
 		break;
 	}
@@ -1048,6 +1057,7 @@ void TrWindow::doneAndNext()
 	}
 	qApp->beep();
     }
+    updateStatistics();
 }
 
 void TrWindow::toggleFinished( QListViewItem *item, const QPoint& /* p */,
@@ -1076,6 +1086,7 @@ void TrWindow::toggleFinished( QListViewItem *item, const QPoint& /* p */,
 		updateCaption();
 	    }
 	}
+	updateStatistics();
     }
 }
 
@@ -1104,7 +1115,7 @@ void TrWindow::nextUnfinished()
 		}
 		setCurrentContextItem( cItem );
 		if( mItem ) {
-		    setCurrentMessageItem( cItem );
+		    setCurrentMessageItem( mItem );
 		} else {
 		    statusBar()->message( tr("No phrase to translate."),
 					  MessageMS );
@@ -1149,6 +1160,7 @@ void TrWindow::nextUnfinished()
 		    n = (MessageLVI *) n->nextSibling();
 		if ( n && q ) {
 		    setCurrentMessageItem( n );
+		    showNewCurrent( n );
 		    return;
 		}
 	    }
@@ -1527,6 +1539,8 @@ void TrWindow::setupMenuBar()
 			       this, SLOT(toggleGuessing()) );
     doGuessesAct->setToggleAction( TRUE );
     doGuessesAct->setOn( TRUE );
+    toggleStats = new Action( viewp, tr("&Statistics"), this, SLOT(toggleStatistics()) );
+    toggleStats->setToggleAction( TRUE );
     viewp->insertSeparator();
     viewp->insertItem( tr("Vie&ws"), createDockWindowMenu( NoToolBars ) );
     viewp->insertItem( tr("&Toolbars"), createDockWindowMenu( OnlyToolBars ) );
@@ -1821,13 +1835,15 @@ bool TrWindow::danger( const QString& source, const QString& translation,
 
 void TrWindow::readConfig()
 {
-    QString   keybase("/Qt Linguist/3.1/");
+    QString keybase( "/Qt Linguist/" +
+		     QString::number( (QT_VERSION >> 16) & 0xff ) +
+		     "." + QString::number( (QT_VERSION >> 8) & 0xff ) + "/" );
     QSettings config;
 
     config.insertSearchPath( QSettings::Windows, "/Trolltech" );
 
     QRect r( pos(), size() );
-    recentFiles = config.readListEntry( keybase + "RecentlyOpenedFiles", ',' );
+    recentFiles = config.readListEntry( keybase + "RecentlyOpenedFiles" );
     if ( !config.readBoolEntry( keybase + "Geometry/MainwindowMaximized", FALSE ) ) {
 	r.setX( config.readNumEntry( keybase + "Geometry/MainwindowX", r.x() ) );
 	r.setY( config.readNumEntry( keybase + "Geometry/MainwindowY", r.y() ) );
@@ -1890,11 +1906,13 @@ void TrWindow::readConfig()
 
 void TrWindow::writeConfig()
 {
-    QString   keybase("/Qt Linguist/3.1/");
+    QString keybase( "/Qt Linguist/" +
+		     QString::number( (QT_VERSION >> 16) & 0xff ) +
+		     "." + QString::number( (QT_VERSION >> 8) & 0xff ) + "/" );
     QSettings config;
 
     config.insertSearchPath( QSettings::Windows, "/Trolltech" );
-    config.writeEntry( keybase + "RecentlyOpenedFiles", recentFiles, ',' );
+    config.writeEntry( keybase + "RecentlyOpenedFiles", recentFiles );
     config.writeEntry( keybase + "Geometry/MainwindowMaximized", isMaximized() );
     config.writeEntry( keybase + "Geometry/MainwindowX", x() );
     config.writeEntry( keybase + "Geometry/MainwindowY", y() );
@@ -1976,3 +1994,67 @@ void TrWindow::updateClosePhraseBook()
 	dirtyItem = -1;
     }
 }
+
+void TrWindow::toggleStatistics()
+{
+    if ( toggleStats->isOn() ) {
+	if ( !stats ) {
+	    stats = new Statistics( this, "linguist_stats" );
+	    connect( this, SIGNAL(statsChanged(int,int,int,int,int,int)), stats,
+		     SLOT(updateStats(int,int,int,int,int,int)) );
+	    connect( stats, SIGNAL(closed()), toggleStats, SLOT(toggle()) );
+	}
+	updateStatistics();
+	stats->show();
+    } else if ( stats ) {
+	stats->close();
+    }
+}
+
+void TrWindow::updateStatistics()
+{
+    QListViewItem * ci = lv->firstChild();
+    int trW = 0;
+    int trC = 0;
+    int trCS = 0;
+    while ( ci ) {
+ 	countStats( ci, ((ContextLVI *)ci)->firstMessageItem(), trW, trC, trCS );
+	ci = ci->nextSibling();
+    }
+    // ..and the items in the source list
+    countStats( 0, slv->firstChild(), trW, trC, trCS );
+    emit statsChanged( srcWords, srcChars, srcCharsSpc, trW, trC, trCS );
+}
+
+
+void TrWindow::countStats( QListViewItem* ci, QListViewItem* mi, int& trW, int& trC, int& trCS )
+{
+    MessageLVI * m;
+    while ( mi ) {
+	m = (MessageLVI *) mi;
+	if ( m->finished() && !(m->message().type() == MetaTranslatorMessage::Obsolete) )
+	    doCharCounting( m->translation(), trW, trC, trCS );
+	if ( ci )
+	    mi = ((ContextLVI *)ci)->nextMessageItem();
+	else
+	    mi = mi->nextSibling();
+    }
+}
+
+void TrWindow::doCharCounting( const QString& text, int& trW, int& trC, int& trCS )
+{
+    trCS += text.length();
+    bool inWord = FALSE;
+    for ( int i = 0; i < (int) text.length(); i++ ) {
+	if ( text[i].isLetterOrNumber() || text[i] == QChar('_') ) {
+	    if ( !inWord ) {
+		trW++;
+		inWord = TRUE;
+	    }
+	} else {
+	    inWord = FALSE;
+	}
+	if ( !text[i].isSpace() )
+	    trC++;
+    }
+}
